/* cg_arith.c.  Generated automatically by treecc */
#line 3 "cg_arith.tc"

/*
 * cg_arith.tc - Arithmetic operator nodes.
 *
 * Copyright (C) 2001  Southern Storm Software, Pty Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <codegen/cg_nodes.h>

/*
 * Bit count stuff to get the correct power of 2 for stuff
 */
static int IsPowOfTwo(ILEvalValue evalValue)
{
	int bitpos=-1;
	int bitcount=0;
	ILUInt32 word;
	ILUInt64 longWord;
	switch(evalValue.valueType)
	{
		case ILMachineType_Int8:
		case ILMachineType_Int16:
		case ILMachineType_Int32:
		{
			if(evalValue.un.i4Value<0)
			{
				return -1;
			}
		}
		/* fall through */
		case ILMachineType_UInt8:
		case ILMachineType_UInt16:
		case ILMachineType_UInt32:
		{
			for(word=evalValue.un.i4Value;word!=0;word=word>>1)
			{
				if(word & 0x01)bitcount++;
				bitpos++;
			}
		}
		break;
		
		case ILMachineType_Int64:
		{
			if(evalValue.un.i8Value<0)
			{
				return -1;
			}
		}
		/* fall through */
		
		case ILMachineType_UInt64:
		{
			for(longWord=evalValue.un.i8Value;longWord!=0;longWord=longWord>>1)
			{
				if(longWord & 0x01)bitcount++;
				bitpos++;
			}
		}
		break;
		default:
			return -1;
	}
	if(bitcount==1)return bitpos;
	return -1;
}

/*
 * Reduce operator strength for arithmetic operators
 */
static int ReduceOperator(ILGenInfo *info, ILNode *node,
		ILNode** parent,ILMachineType commonType)
{
	ILEvalValue evalValue;
	ILNode_BinaryExpression *expr;
	int bitpos;
	if(info->overflowInsns || !(info->optimizeFlag))
	{
		return 0;
	}
	if(!yyisa(node,ILNode_BinaryExpression))
	{
		return 0;
	}

	expr=(ILNode_BinaryExpression*)(node);
	if(!ILNode_EvalConst(expr->expr1,info,&evalValue) && 
		!ILNode_EvalConst(expr->expr2,info,&evalValue))
	{
		return 0;
	}
	
	switch(commonType)
	{
		case ILMachineType_Int8:
		case ILMachineType_UInt8:
		case ILMachineType_Int16:
		case ILMachineType_UInt16:
		case ILMachineType_Int32:
		case ILMachineType_UInt32:
		case ILMachineType_Int64:
		case ILMachineType_UInt64:
		{
			if(ILNode_EvalConst(expr->expr1,info,&evalValue))
			{
				if((bitpos=IsPowOfTwo(evalValue))>0)
				{
					if(yyisa(node,ILNode_Mul))
					{
						*parent=ILNode_Shl_create(expr->expr2,
									ILNode_Int32_create(bitpos,0,0));
						return 1;
					}
				}
			}
			else if(ILNode_EvalConst(expr->expr2,info,&evalValue))
			{
				if((bitpos=IsPowOfTwo(evalValue))>0)
				{
					if(yyisa(node,ILNode_Mul))
					{
						*parent=ILNode_Shl_create(expr->expr1,
									ILNode_Int32_create(bitpos,0,0));
						return 1;
					}
					else if(yyisa(node,ILNode_Div))
					{
						*parent=ILNode_Shr_create(expr->expr1,
									ILNode_Int32_create(bitpos,0,0));
						return 1;
					}
				}
			}
		}
		default:
			break;
	}

	return 0;
}
#line 158 "cg_arith.c"

ILMachineType ILNode_Neg_ILNode_GetType__(ILNode_Neg *node, ILGenInfo * info)
#line 275 "cg_arith.tc"
{
	ILMachineType type = ILNode_GetType(node->expr, info);
	return ILCommonType(info, type, type, 0);
}
#line 166 "cg_arith.c"

void ILNode_Neg_ILNode_GenDiscard__(ILNode_Neg *node, ILGenInfo * info)
#line 340 "cg_arith.tc"
{
	ILNode_GenDiscard(node->expr, info);
}
#line 173 "cg_arith.c"

ILMachineType ILNode_Neg_ILNode_GenValue__(ILNode_Neg *node, ILGenInfo * info)
#line 486 "cg_arith.tc"
{
	ILMachineType type;
	ILMachineType commonType;

	/* Determine the common type to use */
	type = ILNode_GetType(node->expr, info);
	commonType = ILCommonType(info, type, type, 0);

	/* Apply the operator */
	ILNegate_ApplyOp(info, node, commonType);

	/* Return the common type to the caller */
	return commonType;
}
#line 191 "cg_arith.c"

int ILNode_Neg_ILNode_EvalConst__(ILNode_Neg *node, ILGenInfo * info, ILEvalValue * value)
#line 774 "cg_arith.tc"
{
	ILMachineType type;
	ILMachineType commonType;

	/* Determine the common type to use */
	type = ILNode_GetType(node->expr, info);
	commonType = ILCommonType(info, type, type, 0);

	/* Evaluate the argument and cast to the common type */
	if(!ILNode_EvalConst(node->expr, info, value) ||
	   !ILGenCastConst(info, value, value->valueType, commonType))
	{
		return 0;
	}

	/* Apply the operator */
	return ILNegate_EvalOp(info, commonType, value);
}
#line 213 "cg_arith.c"

struct ILNode_Neg_vtable__ const ILNode_Neg_vt__ = {
	&ILNode_UnaryExpression_vt__,
	ILNode_Neg_kind,
	"ILNode_Neg",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Neg_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_Neg_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Neg_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_Neg_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

ILMachineType ILNode_UnaryPlus_ILNode_GetType__(ILNode_UnaryPlus *node, ILGenInfo * info)
#line 275 "cg_arith.tc"
{
	ILMachineType type = ILNode_GetType(node->expr, info);
	return ILCommonType(info, type, type, 0);
}
#line 234 "cg_arith.c"

void ILNode_UnaryPlus_ILNode_GenDiscard__(ILNode_UnaryPlus *node, ILGenInfo * info)
#line 340 "cg_arith.tc"
{
	ILNode_GenDiscard(node->expr, info);
}
#line 241 "cg_arith.c"

ILMachineType ILNode_UnaryPlus_ILNode_GenValue__(ILNode_UnaryPlus *node, ILGenInfo * info)
#line 505 "cg_arith.tc"
{
	ILMachineType type;
	ILMachineType commonType;

	/* Determine the common type to use */
	type = ILNode_GetType(node->expr, info);
	commonType = ILCommonType(info, type, type, 0);

	/* Generate code for the sub-expression and cast to the common type */
	ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);

	/* Return the common type to the caller */
	return commonType;
}
#line 259 "cg_arith.c"

int ILNode_UnaryPlus_ILNode_EvalConst__(ILNode_UnaryPlus *node, ILGenInfo * info, ILEvalValue * value)
#line 797 "cg_arith.tc"
{
	ILMachineType type;
	ILMachineType commonType;

	/* Determine the common type to use */
	type = ILNode_GetType(node->expr, info);
	commonType = ILCommonType(info, type, type, 0);

	/* Generate code for the sub-expression and cast to the common type */
	if(!ILNode_EvalConst(node->expr, info, value) ||
	   !ILGenCastConst(info, value, value->valueType, commonType))
	{
		return 0;
	}
	return 1;
}
#line 279 "cg_arith.c"

struct ILNode_UnaryPlus_vtable__ const ILNode_UnaryPlus_vt__ = {
	&ILNode_UnaryExpression_vt__,
	ILNode_UnaryPlus_kind,
	"ILNode_UnaryPlus",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_UnaryPlus_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_UnaryPlus_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_UnaryPlus_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_UnaryPlus_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

ILMachineType ILNode_Not_ILNode_GetType__(ILNode_Not *node, ILGenInfo * info)
#line 284 "cg_arith.tc"
{
	ILMachineType type = ILNode_GetType(node->expr, info);
	return ILCommonType(info, type, type, 1);
}
#line 300 "cg_arith.c"

void ILNode_Not_ILNode_GenDiscard__(ILNode_Not *node, ILGenInfo * info)
#line 340 "cg_arith.tc"
{
	ILNode_GenDiscard(node->expr, info);
}
#line 307 "cg_arith.c"

ILMachineType ILNode_Not_ILNode_GenValue__(ILNode_Not *node, ILGenInfo * info)
#line 524 "cg_arith.tc"
{
	ILMachineType type;
	ILMachineType commonType;

	/* Determine the common type to use */
	type = ILNode_GetType(node->expr, info);
	commonType = ILCommonType(info, type, type, 1);

	/* Generate code for the sub-expression and cast to the common type */
	ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);

	/* Apply the operator */
	ILNot_ApplyOp(info, commonType);

	/* Return the common type to the caller */
	return commonType;
}
#line 328 "cg_arith.c"

int ILNode_Not_ILNode_EvalConst__(ILNode_Not *node, ILGenInfo * info, ILEvalValue * value)
#line 818 "cg_arith.tc"
{
	ILMachineType type;
	ILMachineType commonType;

	/* Determine the common type to use */
	type = ILNode_GetType(node->expr, info);
	commonType = ILCommonType(info, type, type, 1);

	/* Evaluate the sub-expression and cast to the common type */
	if(!ILNode_EvalConst(node->expr, info, value) ||
	   !ILGenCastConst(info, value, value->valueType, commonType))
	{
		return 0;
	}

	/* Apply the operator */
	return ILNot_EvalOp(info, commonType, value);
}
#line 350 "cg_arith.c"

struct ILNode_Not_vtable__ const ILNode_Not_vt__ = {
	&ILNode_UnaryExpression_vt__,
	ILNode_Not_kind,
	"ILNode_Not",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Not_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_Not_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Not_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_Not_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

ILMachineType ILNode_UserUnaryOp_ILNode_GetType__(ILNode_UserUnaryOp *node, ILGenInfo * info)
#line 293 "cg_arith.tc"
{
	return node->machineType;
}
#line 370 "cg_arith.c"

void ILNode_UserUnaryOp_ILNode_GenDiscard__(ILNode_UserUnaryOp *node, ILGenInfo * info)
#line 340 "cg_arith.tc"
{
	ILNode_GenDiscard(node->expr, info);
}
#line 377 "cg_arith.c"

ILMachineType ILNode_UserUnaryOp_ILNode_GenValue__(ILNode_UserUnaryOp *node, ILGenInfo * info)
#line 546 "cg_arith.tc"
{
	/* Generate code to compute the value of the argument */
	ILNode_GenValue(node->expr, info);

	/* Call the operator */
	ILGenCallByMethod(info, node->method);
	return node->machineType;
}
#line 389 "cg_arith.c"

struct ILNode_UserUnaryOp_vtable__ const ILNode_UserUnaryOp_vt__ = {
	&ILNode_UnaryExpression_vt__,
	ILNode_UserUnaryOp_kind,
	"ILNode_UserUnaryOp",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_UserUnaryOp_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_UserUnaryOp_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_UserUnaryOp_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_Expression_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

ILMachineType ILNode_BinaryArith_ILNode_GetType__(ILNode_BinaryArith *node, ILGenInfo * info)
#line 243 "cg_arith.tc"
{
	return ILCommonType(info,
						ILNode_GetType(node->expr1, info),
						ILNode_GetType(node->expr2, info),
						0);
}
#line 412 "cg_arith.c"

void ILNode_BinaryArith_ILNode_GenDiscard__(ILNode_BinaryArith *node, ILGenInfo * info)
#line 332 "cg_arith.tc"
{
	ILNode_GenDiscard(node->expr1, info);
	ILNode_GenDiscard(node->expr2, info);
}
#line 420 "cg_arith.c"

ILMachineType ILNode_BinaryArith_ILNode_GenValue__(ILNode_BinaryArith *node, ILGenInfo * info)
#line 348 "cg_arith.tc"
{
	ILMachineType type1;
	ILMachineType type2;
	ILMachineType commonType;

	/* Get the types of the sub-expressions */
	type1 = ILNode_GetType(node->expr1, info);
	type2 = ILNode_GetType(node->expr2, info);

	/* Determine the common type */
	commonType = ILCommonType(info, type1, type2, 0);

	if(ReduceOperator(info,(ILNode*)node,(ILNode**)(&node),commonType))
	{
		return ILNode_GenValue(node,info);
	}

	/* Evaluate the sub-expressions and cast to the common type */
	ILGenCast(info, ILNode_GenValue(node->expr1, info), commonType);
	ILGenCast(info, ILNode_GenValue(node->expr2, info), commonType);

	/* Apply the operator */
	ILBinary_ApplyOp(info, node, commonType);
	ILGenAdjust(info, -1);

	/* Return the common type to the caller */
	return commonType;
}
#line 452 "cg_arith.c"

int ILNode_BinaryArith_ILNode_EvalConst__(ILNode_BinaryArith *node, ILGenInfo * info, ILEvalValue * value)
#line 663 "cg_arith.tc"
{
	ILMachineType type1;
	ILMachineType type2;
	ILMachineType commonType;
	ILEvalValue value2;

	/* Get the types of the sub-expressions */
	type1 = ILNode_GetType(node->expr1, info);
	type2 = ILNode_GetType(node->expr2, info);

	/* Determine the common type */
	commonType = ILCommonType(info, type1, type2, 0);

	/* Evaluate the sub-expressions and cast to the common type */
	if(!ILNode_EvalConst(node->expr1, info, value) ||
	   !ILGenCastConst(info, value, value->valueType, commonType))
	{
		return 0;
	}
	if(!ILNode_EvalConst(node->expr2, info, &value2) ||
	   !ILGenCastConst(info, &value2, value2.valueType, commonType))
	{
		return 0;
	}

	/* Evaluate the operator */
	return ILBinary_EvalOp(info, node, commonType, value, &value2);
}
#line 484 "cg_arith.c"

struct ILNode_BinaryArith_vtable__ const ILNode_BinaryArith_vt__ = {
	&ILNode_BinaryExpression_vt__,
	ILNode_BinaryArith_kind,
	"ILNode_BinaryArith",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryArith_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryArith_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryArith_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_BinaryArith_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

ILMachineType ILNode_BinaryBitwise_ILNode_GetType__(ILNode_BinaryBitwise *node, ILGenInfo * info)
#line 254 "cg_arith.tc"
{
	return ILCommonType(info,
						ILNode_GetType(node->expr1, info),
						ILNode_GetType(node->expr2, info),
						1);
}
#line 507 "cg_arith.c"

void ILNode_BinaryBitwise_ILNode_GenDiscard__(ILNode_BinaryBitwise *node, ILGenInfo * info)
#line 332 "cg_arith.tc"
{
	ILNode_GenDiscard(node->expr1, info);
	ILNode_GenDiscard(node->expr2, info);
}
#line 515 "cg_arith.c"

ILMachineType ILNode_BinaryBitwise_ILNode_GenValue__(ILNode_BinaryBitwise *node, ILGenInfo * info)
#line 418 "cg_arith.tc"
{
	ILMachineType type1;
	ILMachineType type2;
	ILMachineType commonType;

	/* Get the types of the sub-expressions */
	type1 = ILNode_GetType(node->expr1, info);
	type2 = ILNode_GetType(node->expr2, info);

	/* Determine the common type */
	commonType = ILCommonType(info, type1, type2, 1);

	/* Evaluate the sub-expressions and cast to the common type */
	ILGenCast(info, ILNode_GenValue(node->expr1, info), commonType);
	ILGenCast(info, ILNode_GenValue(node->expr2, info), commonType);

	/* Apply the operator */
	ILBitwise_ApplyOp(info, node, commonType);
	ILGenAdjust(info, -1);

	/* Return the common type to the caller */
	return commonType;
}
#line 542 "cg_arith.c"

int ILNode_BinaryBitwise_ILNode_EvalConst__(ILNode_BinaryBitwise *node, ILGenInfo * info, ILEvalValue * value)
#line 696 "cg_arith.tc"
{
	ILMachineType type1;
	ILMachineType type2;
	ILMachineType commonType;
	ILEvalValue value2;

	/* Get the types of the sub-expressions */
	type1 = ILNode_GetType(node->expr1, info);
	type2 = ILNode_GetType(node->expr2, info);

	/* Determine the common type */
	commonType = ILCommonType(info, type1, type2, 1);

	/* Evaluate the sub-expressions and cast to the common type */
	if(!ILNode_EvalConst(node->expr1, info, value) ||
	   !ILGenCastConst(info, value, value->valueType, commonType))
	{
		return 0;
	}
	if(!ILNode_EvalConst(node->expr2, info, &value2) ||
	   !ILGenCastConst(info, &value2, value2.valueType, commonType))
	{
		return 0;
	}

	/* Evaluate the operator */
	return ILBitwise_EvalOp(info, node, commonType, value, &value2);
}
#line 574 "cg_arith.c"

struct ILNode_BinaryBitwise_vtable__ const ILNode_BinaryBitwise_vt__ = {
	&ILNode_BinaryExpression_vt__,
	ILNode_BinaryBitwise_kind,
	"ILNode_BinaryBitwise",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryBitwise_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryBitwise_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryBitwise_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_BinaryBitwise_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

ILMachineType ILNode_BinaryShift_ILNode_GetType__(ILNode_BinaryShift *node, ILGenInfo * info)
#line 265 "cg_arith.tc"
{
	ILMachineType type = ILNode_GetType(node->expr1, info);
	return ILCommonType(info, type, type, 1);
}
#line 595 "cg_arith.c"

void ILNode_BinaryShift_ILNode_GenDiscard__(ILNode_BinaryShift *node, ILGenInfo * info)
#line 332 "cg_arith.tc"
{
	ILNode_GenDiscard(node->expr1, info);
	ILNode_GenDiscard(node->expr2, info);
}
#line 603 "cg_arith.c"

ILMachineType ILNode_BinaryShift_ILNode_GenValue__(ILNode_BinaryShift *node, ILGenInfo * info)
#line 446 "cg_arith.tc"
{
	ILMachineType type;
	ILMachineType commonType;

	/* Determine the common type */
	type = ILNode_GetType(node->expr1, info);
	commonType = ILCommonType(info, type, type, 1);

	/* Evaluate the first sub-expression and cast to the common type */
	ILGenCast(info, ILNode_GenValue(node->expr1, info), commonType);

	/* If we are doing an unsigned shift right on an 8-bit or
	   16-bit value, we need to mask off the sign bits first */
	if(commonType == ILMachineType_Int8 &&
	   yykind(node) == yykindof(ILNode_UShr))
	{
		ILGenSimple(info, IL_OP_CONV_U1);
	}
	else if(commonType == ILMachineType_Int16 &&
	        yykind(node) == yykindof(ILNode_UShr))
	{
		ILGenSimple(info, IL_OP_CONV_U2);
	}

	/* Evaluate the second sub-expression and cast to "native uint" */
	ILGenCast(info, ILNode_GenValue(node->expr2, info),
			  ILMachineType_NativeUInt);

	/* Apply the operator */
	ILShift_ApplyOp(info, node, commonType);
	ILGenAdjust(info, -1);

	/* Return the common type to the caller */
	return commonType;
}
#line 642 "cg_arith.c"

int ILNode_BinaryShift_ILNode_EvalConst__(ILNode_BinaryShift *node, ILGenInfo * info, ILEvalValue * value)
#line 729 "cg_arith.tc"
{
	ILMachineType type;
	ILMachineType commonType;
	ILEvalValue value2;

	/* Determine the common type */
	type = ILNode_GetType(node->expr1, info);
	commonType = ILCommonType(info, type, type, 1);

	/* Evaluate the first sub-expression and cast to the common type */
	if(!ILNode_EvalConst(node->expr1, info, value) ||
	   !ILGenCastConst(info, value, value->valueType, commonType))
	{
		return 0;
	}

	/* If we are doing an unsigned shift right on an 8-bit or
	   16-bit value, we need to mask off the sign bits first */
	if(commonType == ILMachineType_Int8 &&
	   yykind(node) == yykindof(ILNode_UShr))
	{
		value->un.i4Value &= 0xFF;
	}
	else if(commonType == ILMachineType_Int16 &&
	        yykind(node) == yykindof(ILNode_UShr))
	{
		value->un.i4Value &= 0xFFFF;
	}

	/* Evaluate the second sub-expression and cast to "native uint" */
	if(!ILNode_EvalConst(node->expr2, info, &value2) ||
	   !ILGenCastConst(info, &value2, value2.valueType,
	   				   ILMachineType_NativeUInt))
	{
		return 0;
	}

	/* Apply the operator */
	return ILShift_EvalOp(info, node, commonType, value, &value2);
}
#line 686 "cg_arith.c"

struct ILNode_BinaryShift_vtable__ const ILNode_BinaryShift_vt__ = {
	&ILNode_BinaryExpression_vt__,
	ILNode_BinaryShift_kind,
	"ILNode_BinaryShift",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryShift_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryShift_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryShift_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_BinaryShift_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

ILMachineType ILNode_UserBinaryOp_ILNode_GetType__(ILNode_UserBinaryOp *node, ILGenInfo * info)
#line 301 "cg_arith.tc"
{
	return node->machineType;
}
#line 706 "cg_arith.c"

void ILNode_UserBinaryOp_ILNode_GenDiscard__(ILNode_UserBinaryOp *node, ILGenInfo * info)
#line 332 "cg_arith.tc"
{
	ILNode_GenDiscard(node->expr1, info);
	ILNode_GenDiscard(node->expr2, info);
}
#line 714 "cg_arith.c"

ILMachineType ILNode_UserBinaryOp_ILNode_GenValue__(ILNode_UserBinaryOp *node, ILGenInfo * info)
#line 559 "cg_arith.tc"
{
	/* Generate code to compute the value of the arguments */
	ILNode_GenValue(node->expr1, info);
	ILNode_GenValue(node->expr2, info);

	/* Call the operator */
	ILGenCallByMethod(info, node->method);
	ILGenAdjust(info, -1);
	return node->machineType;
}
#line 728 "cg_arith.c"

struct ILNode_UserBinaryOp_vtable__ const ILNode_UserBinaryOp_vt__ = {
	&ILNode_BinaryExpression_vt__,
	ILNode_UserBinaryOp_kind,
	"ILNode_UserBinaryOp",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_UserBinaryOp_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_UserBinaryOp_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_UserBinaryOp_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_Expression_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

ILMachineType ILNode_Concat_ILNode_GetType__(ILNode_Concat *node, ILGenInfo * info)
#line 309 "cg_arith.tc"
{
	return ILMachineType_String;
}
#line 748 "cg_arith.c"

void ILNode_Concat_ILNode_GenDiscard__(ILNode_Concat *node, ILGenInfo * info)
#line 332 "cg_arith.tc"
{
	ILNode_GenDiscard(node->expr1, info);
	ILNode_GenDiscard(node->expr2, info);
}
#line 756 "cg_arith.c"

ILMachineType ILNode_Concat_ILNode_GenValue__(ILNode_Concat *node, ILGenInfo * info)
#line 574 "cg_arith.tc"
{
	ILMachineType type1;
	ILMachineType type2;

	/* Generate code for the two arguments */
	type1 = ILNode_GenValue(node->expr1, info);
	if(type1 >= ILMachineType_Boolean &&
	   type1 <= ILMachineType_Decimal)
	{
		ILGenCast(info, type1, ILMachineType_String);
		type1 = ILMachineType_String;
	}
	else
	{
		ILGenCast(info, type1, ILMachineType_ObjectRef);
	}
	type2 = ILNode_GenValue(node->expr2, info);
	if(type2 >= ILMachineType_Boolean &&
	   type2 <= ILMachineType_Decimal)
	{
		ILGenCast(info, type2, ILMachineType_String);
		type2 = ILMachineType_String;
	}
	else
	{
		ILGenCast(info, type2, ILMachineType_ObjectRef);
	}

	/* Apply either the string or the object concatenation function */
	if(type1 == ILMachineType_String && type2 == ILMachineType_String)
	{
		ILGenCallByName(info,
		  "class [.library]System.String [.library]System.String::Concat"
			"(class [.library]System.String, class [.library]System.String)");
	}
	else
	{
		ILGenCallByName(info,
		  "class [.library]System.String [.library]System.String::Concat"
			"(class [.library]System.Object, class [.library]System.Object)");
	}
	ILGenAdjust(info, -1);
	return ILMachineType_String;
}
#line 804 "cg_arith.c"

int ILNode_Concat_ILNode_EvalConst__(ILNode_Concat *node, ILGenInfo * info, ILEvalValue * value)
#line 838 "cg_arith.tc"
{
	ILMachineType type1;
	ILMachineType type2;
	ILEvalValue value2;
	ILIntString new_string;

	type1 = ILNode_GetType(node->expr1, info);
	type2 = ILNode_GetType(node->expr2, info);
	if(type1 != ILMachineType_String || type2 != ILMachineType_String)
	{
		return 0;
	}
	if(!ILNode_EvalConst(node->expr1,info,value)) 
	{
		return 0;
	}
	if(!ILNode_EvalConst(node->expr2,info,&value2)) 
	{
		return 0;
	}
	new_string = ILInternAppendedString
				(ILInternString(value->un.strValue.str, 
					value->un.strValue.len),
				 ILInternString(value2.un.strValue.str,
				 	value2.un.strValue.len));
	value->un.strValue.str=new_string.string; 
	value->un.strValue.len=new_string.len;
	return 1;
}
#line 837 "cg_arith.c"

struct ILNode_Concat_vtable__ const ILNode_Concat_vt__ = {
	&ILNode_BinaryExpression_vt__,
	ILNode_Concat_kind,
	"ILNode_Concat",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Concat_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_Concat_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Concat_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_Concat_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

ILMachineType ILNode_DelegateAdd_ILNode_GetType__(ILNode_DelegateAdd *node, ILGenInfo * info)
#line 318 "cg_arith.tc"
{
	return ILMachineType_ObjectRef;
}
#line 857 "cg_arith.c"

void ILNode_DelegateAdd_ILNode_GenDiscard__(ILNode_DelegateAdd *node, ILGenInfo * info)
#line 332 "cg_arith.tc"
{
	ILNode_GenDiscard(node->expr1, info);
	ILNode_GenDiscard(node->expr2, info);
}
#line 865 "cg_arith.c"

ILMachineType ILNode_DelegateAdd_ILNode_GenValue__(ILNode_DelegateAdd *node, ILGenInfo * info)
#line 623 "cg_arith.tc"
{
	/* Generate code for the two arguments */
	ILNode_GenValue(node->expr1, info);
	ILNode_GenValue(node->expr2, info);

	/* Call the delegate combination operator in "System.Delegate" */
	ILGenCallByName(info,
	  "class [.library]System.Delegate [.library]System.Delegate::Combine"
		"(class [.library]System.Delegate, class [.library]System.Delegate)");
	ILGenAdjust(info, -1);
	ILGenClassToken(info, IL_OP_CASTCLASS, node->delegateClass);

	/* The result is always an object reference */
	return ILMachineType_ObjectRef;
}
#line 884 "cg_arith.c"

struct ILNode_DelegateAdd_vtable__ const ILNode_DelegateAdd_vt__ = {
	&ILNode_BinaryExpression_vt__,
	ILNode_DelegateAdd_kind,
	"ILNode_DelegateAdd",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_DelegateAdd_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_DelegateAdd_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_DelegateAdd_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_Expression_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

ILMachineType ILNode_DelegateSub_ILNode_GetType__(ILNode_DelegateSub *node, ILGenInfo * info)
#line 318 "cg_arith.tc"
{
	return ILMachineType_ObjectRef;
}
#line 904 "cg_arith.c"

void ILNode_DelegateSub_ILNode_GenDiscard__(ILNode_DelegateSub *node, ILGenInfo * info)
#line 332 "cg_arith.tc"
{
	ILNode_GenDiscard(node->expr1, info);
	ILNode_GenDiscard(node->expr2, info);
}
#line 912 "cg_arith.c"

ILMachineType ILNode_DelegateSub_ILNode_GenValue__(ILNode_DelegateSub *node, ILGenInfo * info)
#line 643 "cg_arith.tc"
{
	/* Generate code for the two arguments */
	ILNode_GenValue(node->expr1, info);
	ILNode_GenValue(node->expr2, info);

	/* Call the delegate removal operator in "System.Delegate" */
	ILGenCallByName(info,
	  "class [.library]System.Delegate [.library]System.Delegate::Remove"
		"(class [.library]System.Delegate, class [.library]System.Delegate)");
	ILGenAdjust(info, -1);
	ILGenClassToken(info, IL_OP_CASTCLASS, node->delegateClass);

	/* The result is always an object reference */
	return ILMachineType_ObjectRef;
}
#line 931 "cg_arith.c"

struct ILNode_DelegateSub_vtable__ const ILNode_DelegateSub_vt__ = {
	&ILNode_BinaryExpression_vt__,
	ILNode_DelegateSub_kind,
	"ILNode_DelegateSub",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_DelegateSub_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_DelegateSub_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_DelegateSub_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_Expression_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

ILMachineType ILNode_Add_ILNode_GenValue__(ILNode_Add *node, ILGenInfo * info)
#line 381 "cg_arith.tc"
{
	ILMachineType type1;
	ILMachineType type2;
	ILMachineType commonType;

	/* Get the types of the sub-expressions */
	type1 = ILNode_GetType(node->expr1, info);
	type2 = ILNode_GetType(node->expr2, info);

	/* Determine the common type */
	if(type1 == ILMachineType_String || type2 == ILMachineType_String)
	{
		/* Perform string concatenation on the arguments */
		commonType = ILMachineType_String;
	}
	else
	{
		/* Numeric addition operator */
		commonType = ILCommonType(info, type1, type2, 0);
	}

	/* Evaluate the sub-expressions and cast to the common type */
	ILGenCast(info, ILNode_GenValue(node->expr1, info), commonType);
	ILGenCast(info, ILNode_GenValue(node->expr2, info), commonType);

	/* Apply the operator */
	ILBinary_ApplyOp(info, (ILNode_BinaryArith *)node, commonType);
	ILGenAdjust(info, -1);

	/* Return the common type to the caller */
	return commonType;
}
#line 980 "cg_arith.c"

struct ILNode_Add_vtable__ const ILNode_Add_vt__ = {
	&ILNode_BinaryArith_vt__,
	ILNode_Add_kind,
	"ILNode_Add",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryArith_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryArith_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Add_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_BinaryArith_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

struct ILNode_Sub_vtable__ const ILNode_Sub_vt__ = {
	&ILNode_BinaryArith_vt__,
	ILNode_Sub_kind,
	"ILNode_Sub",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryArith_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryArith_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryArith_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_BinaryArith_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

struct ILNode_Mul_vtable__ const ILNode_Mul_vt__ = {
	&ILNode_BinaryArith_vt__,
	ILNode_Mul_kind,
	"ILNode_Mul",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryArith_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryArith_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryArith_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_BinaryArith_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

struct ILNode_Div_vtable__ const ILNode_Div_vt__ = {
	&ILNode_BinaryArith_vt__,
	ILNode_Div_kind,
	"ILNode_Div",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryArith_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryArith_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryArith_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_BinaryArith_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

struct ILNode_Rem_vtable__ const ILNode_Rem_vt__ = {
	&ILNode_BinaryArith_vt__,
	ILNode_Rem_kind,
	"ILNode_Rem",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryArith_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryArith_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryArith_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_BinaryArith_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

struct ILNode_And_vtable__ const ILNode_And_vt__ = {
	&ILNode_BinaryBitwise_vt__,
	ILNode_And_kind,
	"ILNode_And",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryBitwise_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryBitwise_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryBitwise_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_BinaryBitwise_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

struct ILNode_Or_vtable__ const ILNode_Or_vt__ = {
	&ILNode_BinaryBitwise_vt__,
	ILNode_Or_kind,
	"ILNode_Or",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryBitwise_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryBitwise_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryBitwise_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_BinaryBitwise_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

struct ILNode_Xor_vtable__ const ILNode_Xor_vt__ = {
	&ILNode_BinaryBitwise_vt__,
	ILNode_Xor_kind,
	"ILNode_Xor",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryBitwise_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryBitwise_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryBitwise_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_BinaryBitwise_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

struct ILNode_Shl_vtable__ const ILNode_Shl_vt__ = {
	&ILNode_BinaryShift_vt__,
	ILNode_Shl_kind,
	"ILNode_Shl",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryShift_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryShift_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryShift_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_BinaryShift_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

struct ILNode_Shr_vtable__ const ILNode_Shr_vt__ = {
	&ILNode_BinaryShift_vt__,
	ILNode_Shr_kind,
	"ILNode_Shr",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryShift_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryShift_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryShift_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_BinaryShift_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

struct ILNode_UShr_vtable__ const ILNode_UShr_vt__ = {
	&ILNode_BinaryShift_vt__,
	ILNode_UShr_kind,
	"ILNode_UShr",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryShift_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryShift_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_BinaryShift_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Expression_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_BinaryShift_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

ILNode *ILNode_Neg_create(ILNode * expr)
{
	ILNode_Neg *node__ = (ILNode_Neg *)yynodealloc(sizeof(struct ILNode_Neg__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_Neg_vt__;
	node__->kind__ = ILNode_Neg_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr = expr;
	return (ILNode *)node__;
}

ILNode *ILNode_UnaryPlus_create(ILNode * expr)
{
	ILNode_UnaryPlus *node__ = (ILNode_UnaryPlus *)yynodealloc(sizeof(struct ILNode_UnaryPlus__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_UnaryPlus_vt__;
	node__->kind__ = ILNode_UnaryPlus_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr = expr;
	return (ILNode *)node__;
}

ILNode *ILNode_Not_create(ILNode * expr)
{
	ILNode_Not *node__ = (ILNode_Not *)yynodealloc(sizeof(struct ILNode_Not__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_Not_vt__;
	node__->kind__ = ILNode_Not_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr = expr;
	return (ILNode *)node__;
}

ILNode *ILNode_UserUnaryOp_create(ILNode * expr, ILMachineType machineType, ILMethod * method)
{
	ILNode_UserUnaryOp *node__ = (ILNode_UserUnaryOp *)yynodealloc(sizeof(struct ILNode_UserUnaryOp__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_UserUnaryOp_vt__;
	node__->kind__ = ILNode_UserUnaryOp_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr = expr;
	node__->machineType = machineType;
	node__->method = method;
	return (ILNode *)node__;
}

ILNode *ILNode_UserBinaryOp_create(ILNode * expr1, ILNode * expr2, ILMachineType machineType, ILMethod * method)
{
	ILNode_UserBinaryOp *node__ = (ILNode_UserBinaryOp *)yynodealloc(sizeof(struct ILNode_UserBinaryOp__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_UserBinaryOp_vt__;
	node__->kind__ = ILNode_UserBinaryOp_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	node__->machineType = machineType;
	node__->method = method;
	return (ILNode *)node__;
}

ILNode *ILNode_Concat_create(ILNode * expr1, ILNode * expr2)
{
	ILNode_Concat *node__ = (ILNode_Concat *)yynodealloc(sizeof(struct ILNode_Concat__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_Concat_vt__;
	node__->kind__ = ILNode_Concat_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	return (ILNode *)node__;
}

ILNode *ILNode_DelegateAdd_create(ILNode * expr1, ILNode * expr2, ILClass * delegateClass)
{
	ILNode_DelegateAdd *node__ = (ILNode_DelegateAdd *)yynodealloc(sizeof(struct ILNode_DelegateAdd__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_DelegateAdd_vt__;
	node__->kind__ = ILNode_DelegateAdd_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	node__->delegateClass = delegateClass;
	return (ILNode *)node__;
}

ILNode *ILNode_DelegateSub_create(ILNode * expr1, ILNode * expr2, ILClass * delegateClass)
{
	ILNode_DelegateSub *node__ = (ILNode_DelegateSub *)yynodealloc(sizeof(struct ILNode_DelegateSub__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_DelegateSub_vt__;
	node__->kind__ = ILNode_DelegateSub_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	node__->delegateClass = delegateClass;
	return (ILNode *)node__;
}

ILNode *ILNode_Add_create(ILNode * expr1, ILNode * expr2)
{
	ILNode_Add *node__ = (ILNode_Add *)yynodealloc(sizeof(struct ILNode_Add__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_Add_vt__;
	node__->kind__ = ILNode_Add_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	return (ILNode *)node__;
}

ILNode *ILNode_Sub_create(ILNode * expr1, ILNode * expr2)
{
	ILNode_Sub *node__ = (ILNode_Sub *)yynodealloc(sizeof(struct ILNode_Sub__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_Sub_vt__;
	node__->kind__ = ILNode_Sub_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	return (ILNode *)node__;
}

ILNode *ILNode_Mul_create(ILNode * expr1, ILNode * expr2)
{
	ILNode_Mul *node__ = (ILNode_Mul *)yynodealloc(sizeof(struct ILNode_Mul__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_Mul_vt__;
	node__->kind__ = ILNode_Mul_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	return (ILNode *)node__;
}

ILNode *ILNode_Div_create(ILNode * expr1, ILNode * expr2)
{
	ILNode_Div *node__ = (ILNode_Div *)yynodealloc(sizeof(struct ILNode_Div__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_Div_vt__;
	node__->kind__ = ILNode_Div_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	return (ILNode *)node__;
}

ILNode *ILNode_Rem_create(ILNode * expr1, ILNode * expr2)
{
	ILNode_Rem *node__ = (ILNode_Rem *)yynodealloc(sizeof(struct ILNode_Rem__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_Rem_vt__;
	node__->kind__ = ILNode_Rem_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	return (ILNode *)node__;
}

ILNode *ILNode_And_create(ILNode * expr1, ILNode * expr2)
{
	ILNode_And *node__ = (ILNode_And *)yynodealloc(sizeof(struct ILNode_And__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_And_vt__;
	node__->kind__ = ILNode_And_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	return (ILNode *)node__;
}

ILNode *ILNode_Or_create(ILNode * expr1, ILNode * expr2)
{
	ILNode_Or *node__ = (ILNode_Or *)yynodealloc(sizeof(struct ILNode_Or__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_Or_vt__;
	node__->kind__ = ILNode_Or_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	return (ILNode *)node__;
}

ILNode *ILNode_Xor_create(ILNode * expr1, ILNode * expr2)
{
	ILNode_Xor *node__ = (ILNode_Xor *)yynodealloc(sizeof(struct ILNode_Xor__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_Xor_vt__;
	node__->kind__ = ILNode_Xor_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	return (ILNode *)node__;
}

ILNode *ILNode_Shl_create(ILNode * expr1, ILNode * expr2)
{
	ILNode_Shl *node__ = (ILNode_Shl *)yynodealloc(sizeof(struct ILNode_Shl__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_Shl_vt__;
	node__->kind__ = ILNode_Shl_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	return (ILNode *)node__;
}

ILNode *ILNode_Shr_create(ILNode * expr1, ILNode * expr2)
{
	ILNode_Shr *node__ = (ILNode_Shr *)yynodealloc(sizeof(struct ILNode_Shr__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_Shr_vt__;
	node__->kind__ = ILNode_Shr_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	return (ILNode *)node__;
}

ILNode *ILNode_UShr_create(ILNode * expr1, ILNode * expr2)
{
	ILNode_UShr *node__ = (ILNode_UShr *)yynodealloc(sizeof(struct ILNode_UShr__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_UShr_vt__;
	node__->kind__ = ILNode_UShr_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	return (ILNode *)node__;
}

static int ILShift_EvalOp_1__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2906 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	value1->un.i4Value =
		(ILInt32)(ILInt8)(value1->un.i4Value <<
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1383 "cg_arith.c"

static int ILShift_EvalOp_2__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2914 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	value1->un.i4Value =
		(ILInt32)(ILUInt8)(value1->un.i4Value <<
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1394 "cg_arith.c"

static int ILShift_EvalOp_3__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2922 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	value1->un.i4Value =
		(ILInt32)(ILInt16)(value1->un.i4Value <<
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1405 "cg_arith.c"

static int ILShift_EvalOp_4__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2931 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	value1->un.i4Value =
		(ILInt32)(ILUInt16)(value1->un.i4Value <<
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1416 "cg_arith.c"

static int ILShift_EvalOp_5__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2931 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	value1->un.i4Value =
		(ILInt32)(ILUInt16)(value1->un.i4Value <<
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1427 "cg_arith.c"

static int ILShift_EvalOp_6__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2942 "cg_arith.tc"
{
	value1->un.i4Value <<= (ILUInt32)(value2->un.i4Value);
	return 1;
}
#line 1435 "cg_arith.c"

static int ILShift_EvalOp_7__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2942 "cg_arith.tc"
{
	value1->un.i4Value <<= (ILUInt32)(value2->un.i4Value);
	return 1;
}
#line 1443 "cg_arith.c"

static int ILShift_EvalOp_8__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2948 "cg_arith.tc"
{
	value1->un.i8Value <<= (ILUInt32)(value2->un.i4Value);
	return 1;
}
#line 1451 "cg_arith.c"

static int ILShift_EvalOp_9__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2948 "cg_arith.tc"
{
	value1->un.i8Value <<= (ILUInt32)(value2->un.i4Value);
	return 1;
}
#line 1459 "cg_arith.c"

static int ILShift_EvalOp_10__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2942 "cg_arith.tc"
{
	value1->un.i4Value <<= (ILUInt32)(value2->un.i4Value);
	return 1;
}
#line 1467 "cg_arith.c"

static int ILShift_EvalOp_11__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2942 "cg_arith.tc"
{
	value1->un.i4Value <<= (ILUInt32)(value2->un.i4Value);
	return 1;
}
#line 1475 "cg_arith.c"

static int ILShift_EvalOp_12__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2953 "cg_arith.tc"
{
	return 0;
}
#line 1482 "cg_arith.c"

static int ILShift_EvalOp_13__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2961 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	value1->un.i4Value =
		(ILInt32)(ILInt8)(value1->un.i4Value >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1493 "cg_arith.c"

static int ILShift_EvalOp_14__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2969 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	value1->un.i4Value =
		(ILInt32)(ILUInt8)((ILUInt32)(value1->un.i4Value) >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1504 "cg_arith.c"

static int ILShift_EvalOp_15__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2977 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	value1->un.i4Value =
		(ILInt32)(ILInt16)(value1->un.i4Value >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1515 "cg_arith.c"

static int ILShift_EvalOp_16__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2986 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	value1->un.i4Value =
		(ILInt32)(ILUInt16)((ILUInt32)(value1->un.i4Value) >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1526 "cg_arith.c"

static int ILShift_EvalOp_17__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2986 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	value1->un.i4Value =
		(ILInt32)(ILUInt16)((ILUInt32)(value1->un.i4Value) >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1537 "cg_arith.c"

static int ILShift_EvalOp_18__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2995 "cg_arith.tc"
{
	value1->un.i4Value >>= (ILUInt32)(value2->un.i4Value);
	return 1;
}
#line 1545 "cg_arith.c"

static int ILShift_EvalOp_19__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 3001 "cg_arith.tc"
{
	value1->un.i4Value =
		(ILInt32)((ILUInt32)(value1->un.i4Value) >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1555 "cg_arith.c"

static int ILShift_EvalOp_20__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 3008 "cg_arith.tc"
{
	value1->un.i8Value >>= (ILUInt32)(value2->un.i4Value);
	return 1;
}
#line 1563 "cg_arith.c"

static int ILShift_EvalOp_21__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 3013 "cg_arith.tc"
{
	value1->un.i8Value =
		(ILInt64)((ILUInt64)(value1->un.i8Value) >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1573 "cg_arith.c"

static int ILShift_EvalOp_22__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2995 "cg_arith.tc"
{
	value1->un.i4Value >>= (ILUInt32)(value2->un.i4Value);
	return 1;
}
#line 1581 "cg_arith.c"

static int ILShift_EvalOp_23__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 3001 "cg_arith.tc"
{
	value1->un.i4Value =
		(ILInt32)((ILUInt32)(value1->un.i4Value) >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1591 "cg_arith.c"

static int ILShift_EvalOp_24__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 3020 "cg_arith.tc"
{
	return 0;
}
#line 1598 "cg_arith.c"

static int ILShift_EvalOp_25__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 3028 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	value1->un.i4Value =
		(ILInt32)(ILInt8)((ILUInt32)(value1->un.i4Value) >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1609 "cg_arith.c"

static int ILShift_EvalOp_26__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 3036 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	value1->un.i4Value =
		(ILInt32)(ILUInt8)((ILUInt32)(value1->un.i4Value) >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1620 "cg_arith.c"

static int ILShift_EvalOp_27__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 3044 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	value1->un.i4Value =
		(ILInt32)(ILInt16)((ILUInt32)(value1->un.i4Value) >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1631 "cg_arith.c"

static int ILShift_EvalOp_28__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 3053 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	value1->un.i4Value =
		(ILInt32)(ILUInt16)((ILUInt32)(value1->un.i4Value) >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1642 "cg_arith.c"

static int ILShift_EvalOp_29__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 3053 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	value1->un.i4Value =
		(ILInt32)(ILUInt16)((ILUInt32)(value1->un.i4Value) >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1653 "cg_arith.c"

static int ILShift_EvalOp_30__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 3064 "cg_arith.tc"
{
	value1->un.i4Value =
		(ILInt32)((ILUInt32)(value1->un.i4Value) >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1663 "cg_arith.c"

static int ILShift_EvalOp_31__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 3064 "cg_arith.tc"
{
	value1->un.i4Value =
		(ILInt32)((ILUInt32)(value1->un.i4Value) >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1673 "cg_arith.c"

static int ILShift_EvalOp_32__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 3072 "cg_arith.tc"
{
	value1->un.i8Value =
		(ILInt64)((ILUInt64)(value1->un.i8Value) >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1683 "cg_arith.c"

static int ILShift_EvalOp_33__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 3072 "cg_arith.tc"
{
	value1->un.i8Value =
		(ILInt64)((ILUInt64)(value1->un.i8Value) >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1693 "cg_arith.c"

static int ILShift_EvalOp_34__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 3064 "cg_arith.tc"
{
	value1->un.i4Value =
		(ILInt32)((ILUInt32)(value1->un.i4Value) >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1703 "cg_arith.c"

static int ILShift_EvalOp_35__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 3064 "cg_arith.tc"
{
	value1->un.i4Value =
		(ILInt32)((ILUInt32)(value1->un.i4Value) >>
						  (ILUInt32)(value2->un.i4Value));
	return 1;
}
#line 1713 "cg_arith.c"

static int ILShift_EvalOp_36__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 3079 "cg_arith.tc"
{
	return 0;
}
#line 1720 "cg_arith.c"

int ILShift_EvalOp(ILGenInfo * info, ILNode_BinaryShift * node__, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
{
	switch(node__->kind__)
	{
		case ILNode_Shl_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					return ILShift_EvalOp_12__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Boolean:
				{
					return ILShift_EvalOp_12__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int8:
				{
					return ILShift_EvalOp_1__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt8:
				{
					return ILShift_EvalOp_2__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int16:
				{
					return ILShift_EvalOp_3__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt16:
				{
					return ILShift_EvalOp_4__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Char:
				{
					return ILShift_EvalOp_5__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int32:
				{
					return ILShift_EvalOp_6__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt32:
				{
					return ILShift_EvalOp_7__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int64:
				{
					return ILShift_EvalOp_8__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt64:
				{
					return ILShift_EvalOp_9__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeInt:
				{
					return ILShift_EvalOp_10__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					return ILShift_EvalOp_11__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float32:
				{
					return ILShift_EvalOp_12__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float64:
				{
					return ILShift_EvalOp_12__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					return ILShift_EvalOp_12__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Decimal:
				{
					return ILShift_EvalOp_12__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_String:
				{
					return ILShift_EvalOp_12__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					return ILShift_EvalOp_12__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					return ILShift_EvalOp_12__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					return ILShift_EvalOp_12__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					return ILShift_EvalOp_12__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					return ILShift_EvalOp_12__(info, (ILNode_Shl *)node__, commonType, value1, value2);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Shr_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					return ILShift_EvalOp_24__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Boolean:
				{
					return ILShift_EvalOp_24__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int8:
				{
					return ILShift_EvalOp_13__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt8:
				{
					return ILShift_EvalOp_14__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int16:
				{
					return ILShift_EvalOp_15__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt16:
				{
					return ILShift_EvalOp_16__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Char:
				{
					return ILShift_EvalOp_17__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int32:
				{
					return ILShift_EvalOp_18__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt32:
				{
					return ILShift_EvalOp_19__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int64:
				{
					return ILShift_EvalOp_20__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt64:
				{
					return ILShift_EvalOp_21__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeInt:
				{
					return ILShift_EvalOp_22__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					return ILShift_EvalOp_23__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float32:
				{
					return ILShift_EvalOp_24__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float64:
				{
					return ILShift_EvalOp_24__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					return ILShift_EvalOp_24__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Decimal:
				{
					return ILShift_EvalOp_24__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_String:
				{
					return ILShift_EvalOp_24__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					return ILShift_EvalOp_24__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					return ILShift_EvalOp_24__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					return ILShift_EvalOp_24__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					return ILShift_EvalOp_24__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					return ILShift_EvalOp_24__(info, (ILNode_Shr *)node__, commonType, value1, value2);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_UShr_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					return ILShift_EvalOp_36__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Boolean:
				{
					return ILShift_EvalOp_36__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int8:
				{
					return ILShift_EvalOp_25__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt8:
				{
					return ILShift_EvalOp_26__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int16:
				{
					return ILShift_EvalOp_27__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt16:
				{
					return ILShift_EvalOp_28__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Char:
				{
					return ILShift_EvalOp_29__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int32:
				{
					return ILShift_EvalOp_30__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt32:
				{
					return ILShift_EvalOp_31__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int64:
				{
					return ILShift_EvalOp_32__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt64:
				{
					return ILShift_EvalOp_33__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeInt:
				{
					return ILShift_EvalOp_34__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					return ILShift_EvalOp_35__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float32:
				{
					return ILShift_EvalOp_36__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float64:
				{
					return ILShift_EvalOp_36__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					return ILShift_EvalOp_36__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Decimal:
				{
					return ILShift_EvalOp_36__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_String:
				{
					return ILShift_EvalOp_36__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					return ILShift_EvalOp_36__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					return ILShift_EvalOp_36__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					return ILShift_EvalOp_36__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					return ILShift_EvalOp_36__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					return ILShift_EvalOp_36__(info, (ILNode_UShr *)node__, commonType, value1, value2);
				}
				break;

				default: break;
			}
		}
		break;

		default: break;
	}
	return (0);
}

int ILNot_EvalOp(ILGenInfo * info, ILMachineType commonType, ILEvalValue * value)
{
	switch(commonType)
	{
		case ILMachineType_Int8:
		{
#line 3194 "cg_arith.tc"
			{
				value->un.i4Value = (ILInt32)(ILInt8)(~(value->un.i4Value));
				return 1;
			}
#line 2183 "cg_arith.c"
		}
		break;

		case ILMachineType_UInt8:
		{
#line 3199 "cg_arith.tc"
			{
				value->un.i4Value = (ILInt32)(ILUInt8)(~(value->un.i4Value));
				return 1;
			}
#line 2194 "cg_arith.c"
		}
		break;

		case ILMachineType_Int16:
		{
#line 3204 "cg_arith.tc"
			{
				value->un.i4Value = (ILInt32)(ILInt16)(~(value->un.i4Value));
				return 1;
			}
#line 2205 "cg_arith.c"
		}
		break;

		case ILMachineType_UInt16:
		{
#line 3210 "cg_arith.tc"
			{
				value->un.i4Value = (ILInt32)(ILInt32)(~(value->un.i4Value));
				return 1;
			}
#line 2216 "cg_arith.c"
		}
		break;

		case ILMachineType_Char:
		{
#line 3210 "cg_arith.tc"
			{
				value->un.i4Value = (ILInt32)(ILInt32)(~(value->un.i4Value));
				return 1;
			}
#line 2227 "cg_arith.c"
		}
		break;

		case ILMachineType_Int32:
		{
#line 3216 "cg_arith.tc"
			{
				value->un.i4Value = ~(value->un.i4Value);
				return 1;
			}
#line 2238 "cg_arith.c"
		}
		break;

		case ILMachineType_UInt32:
		{
#line 3216 "cg_arith.tc"
			{
				value->un.i4Value = ~(value->un.i4Value);
				return 1;
			}
#line 2249 "cg_arith.c"
		}
		break;

		case ILMachineType_Int64:
		{
#line 3238 "cg_arith.tc"
			{
				value->un.i8Value = ~(value->un.i8Value);
				return 1;
			}
#line 2260 "cg_arith.c"
		}
		break;

		case ILMachineType_UInt64:
		{
#line 3238 "cg_arith.tc"
			{
				value->un.i8Value = ~(value->un.i8Value);
				return 1;
			}
#line 2271 "cg_arith.c"
		}
		break;

		case ILMachineType_NativeInt:
		{
#line 3221 "cg_arith.tc"
			{
				/* Because we don't know the size of native integers
				   at compile time, we need to be careful.  We can
				   only perform the operation if the 32-bit and 64-bit
				   results would be the same */
				ILInt64 testResult = ~((ILInt64)(value->un.i4Value));
				value->un.i4Value = ~(value->un.i4Value);
				return (((ILInt64)(value->un.i4Value)) == testResult);
			}
#line 2287 "cg_arith.c"
		}
		break;

		case ILMachineType_NativeUInt:
		{
#line 3231 "cg_arith.tc"
			{
				/* We cannot use bitwise NOT because we don't know
				   the size of native integers at compile time */
				return 0;
			}
#line 2299 "cg_arith.c"
		}
		break;

		case ILMachineType_Void:
		case ILMachineType_Boolean:
		case ILMachineType_Float32:
		case ILMachineType_Float64:
		case ILMachineType_NativeFloat:
		case ILMachineType_Decimal:
		case ILMachineType_String:
		case ILMachineType_ObjectRef:
		case ILMachineType_UnmanagedPtr:
		case ILMachineType_ManagedPtr:
		case ILMachineType_TransientPtr:
		case ILMachineType_ManagedValue:
		{
#line 3243 "cg_arith.tc"
			{
				return 0;
			}
#line 2320 "cg_arith.c"
		}
		break;

		default: break;
	}
	return (0);
}

static void ILBitwise_ApplyOp_1__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1518 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2335 "cg_arith.c"

static void ILBitwise_ApplyOp_2__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1468 "cg_arith.tc"
{
	/* Returns true if both arguments are true.  We assume
	   that both arguments are clamped to the set {0,1} */
	ILGenSimple(info, IL_OP_AND);
}
#line 2344 "cg_arith.c"

static void ILBitwise_ApplyOp_3__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1474 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	ILGenSimple(info, IL_OP_AND);
	ILGenSimple(info, IL_OP_CONV_I1);
}
#line 2353 "cg_arith.c"

static void ILBitwise_ApplyOp_4__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1480 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	ILGenSimple(info, IL_OP_AND);
	ILGenSimple(info, IL_OP_CONV_U1);
}
#line 2362 "cg_arith.c"

static void ILBitwise_ApplyOp_5__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1486 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	ILGenSimple(info, IL_OP_AND);
	ILGenSimple(info, IL_OP_CONV_I2);
}
#line 2371 "cg_arith.c"

static void ILBitwise_ApplyOp_6__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1493 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	ILGenSimple(info, IL_OP_AND);
	ILGenSimple(info, IL_OP_CONV_U2);
}
#line 2380 "cg_arith.c"

static void ILBitwise_ApplyOp_7__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1493 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	ILGenSimple(info, IL_OP_AND);
	ILGenSimple(info, IL_OP_CONV_U2);
}
#line 2389 "cg_arith.c"

static void ILBitwise_ApplyOp_8__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1504 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_AND);
}
#line 2396 "cg_arith.c"

static void ILBitwise_ApplyOp_9__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1504 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_AND);
}
#line 2403 "cg_arith.c"

static void ILBitwise_ApplyOp_10__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1504 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_AND);
}
#line 2410 "cg_arith.c"

static void ILBitwise_ApplyOp_11__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1504 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_AND);
}
#line 2417 "cg_arith.c"

static void ILBitwise_ApplyOp_12__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1504 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_AND);
}
#line 2424 "cg_arith.c"

static void ILBitwise_ApplyOp_13__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1504 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_AND);
}
#line 2431 "cg_arith.c"

static void ILBitwise_ApplyOp_14__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1518 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2439 "cg_arith.c"

static void ILBitwise_ApplyOp_15__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1518 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2447 "cg_arith.c"

static void ILBitwise_ApplyOp_16__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1518 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2455 "cg_arith.c"

static void ILBitwise_ApplyOp_17__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1518 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2463 "cg_arith.c"

static void ILBitwise_ApplyOp_18__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1518 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2471 "cg_arith.c"

static void ILBitwise_ApplyOp_19__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1518 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2479 "cg_arith.c"

static void ILBitwise_ApplyOp_20__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1518 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2487 "cg_arith.c"

static void ILBitwise_ApplyOp_21__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1518 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2495 "cg_arith.c"

static void ILBitwise_ApplyOp_22__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1518 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2503 "cg_arith.c"

static void ILBitwise_ApplyOp_23__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType)
#line 1518 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2511 "cg_arith.c"

static void ILBitwise_ApplyOp_24__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1577 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2519 "cg_arith.c"

static void ILBitwise_ApplyOp_25__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1527 "cg_arith.tc"
{
	/* Returns true if one of the arguments is true.  We assume
	   that both arguments are clamped to the set {0,1} */
	ILGenSimple(info, IL_OP_OR);
}
#line 2528 "cg_arith.c"

static void ILBitwise_ApplyOp_26__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1533 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	ILGenSimple(info, IL_OP_OR);
	ILGenSimple(info, IL_OP_CONV_I1);
}
#line 2537 "cg_arith.c"

static void ILBitwise_ApplyOp_27__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1539 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	ILGenSimple(info, IL_OP_OR);
	ILGenSimple(info, IL_OP_CONV_U1);
}
#line 2546 "cg_arith.c"

static void ILBitwise_ApplyOp_28__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1545 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	ILGenSimple(info, IL_OP_OR);
	ILGenSimple(info, IL_OP_CONV_I2);
}
#line 2555 "cg_arith.c"

static void ILBitwise_ApplyOp_29__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1552 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	ILGenSimple(info, IL_OP_OR);
	ILGenSimple(info, IL_OP_CONV_U2);
}
#line 2564 "cg_arith.c"

static void ILBitwise_ApplyOp_30__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1552 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	ILGenSimple(info, IL_OP_OR);
	ILGenSimple(info, IL_OP_CONV_U2);
}
#line 2573 "cg_arith.c"

static void ILBitwise_ApplyOp_31__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1563 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_OR);
}
#line 2580 "cg_arith.c"

static void ILBitwise_ApplyOp_32__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1563 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_OR);
}
#line 2587 "cg_arith.c"

static void ILBitwise_ApplyOp_33__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1563 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_OR);
}
#line 2594 "cg_arith.c"

static void ILBitwise_ApplyOp_34__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1563 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_OR);
}
#line 2601 "cg_arith.c"

static void ILBitwise_ApplyOp_35__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1563 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_OR);
}
#line 2608 "cg_arith.c"

static void ILBitwise_ApplyOp_36__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1563 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_OR);
}
#line 2615 "cg_arith.c"

static void ILBitwise_ApplyOp_37__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1577 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2623 "cg_arith.c"

static void ILBitwise_ApplyOp_38__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1577 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2631 "cg_arith.c"

static void ILBitwise_ApplyOp_39__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1577 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2639 "cg_arith.c"

static void ILBitwise_ApplyOp_40__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1577 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2647 "cg_arith.c"

static void ILBitwise_ApplyOp_41__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1577 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2655 "cg_arith.c"

static void ILBitwise_ApplyOp_42__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1577 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2663 "cg_arith.c"

static void ILBitwise_ApplyOp_43__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1577 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2671 "cg_arith.c"

static void ILBitwise_ApplyOp_44__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1577 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2679 "cg_arith.c"

static void ILBitwise_ApplyOp_45__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1577 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2687 "cg_arith.c"

static void ILBitwise_ApplyOp_46__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType)
#line 1577 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2695 "cg_arith.c"

static void ILBitwise_ApplyOp_47__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1636 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2703 "cg_arith.c"

static void ILBitwise_ApplyOp_48__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1586 "cg_arith.tc"
{
	/* Returns the XOR of the boolean arguments.  We assume
	   that both arguments are clamped to the set {0,1} */
	ILGenSimple(info, IL_OP_XOR);
}
#line 2712 "cg_arith.c"

static void ILBitwise_ApplyOp_49__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1592 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	ILGenSimple(info, IL_OP_XOR);
	ILGenSimple(info, IL_OP_CONV_I1);
}
#line 2721 "cg_arith.c"

static void ILBitwise_ApplyOp_50__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1598 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	ILGenSimple(info, IL_OP_XOR);
	ILGenSimple(info, IL_OP_CONV_U1);
}
#line 2730 "cg_arith.c"

static void ILBitwise_ApplyOp_51__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1604 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	ILGenSimple(info, IL_OP_XOR);
	ILGenSimple(info, IL_OP_CONV_I2);
}
#line 2739 "cg_arith.c"

static void ILBitwise_ApplyOp_52__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1611 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	ILGenSimple(info, IL_OP_XOR);
	ILGenSimple(info, IL_OP_CONV_U2);
}
#line 2748 "cg_arith.c"

static void ILBitwise_ApplyOp_53__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1611 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	ILGenSimple(info, IL_OP_XOR);
	ILGenSimple(info, IL_OP_CONV_U2);
}
#line 2757 "cg_arith.c"

static void ILBitwise_ApplyOp_54__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1622 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_XOR);
}
#line 2764 "cg_arith.c"

static void ILBitwise_ApplyOp_55__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1622 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_XOR);
}
#line 2771 "cg_arith.c"

static void ILBitwise_ApplyOp_56__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1622 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_XOR);
}
#line 2778 "cg_arith.c"

static void ILBitwise_ApplyOp_57__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1622 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_XOR);
}
#line 2785 "cg_arith.c"

static void ILBitwise_ApplyOp_58__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1622 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_XOR);
}
#line 2792 "cg_arith.c"

static void ILBitwise_ApplyOp_59__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1622 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_XOR);
}
#line 2799 "cg_arith.c"

static void ILBitwise_ApplyOp_60__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1636 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2807 "cg_arith.c"

static void ILBitwise_ApplyOp_61__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1636 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2815 "cg_arith.c"

static void ILBitwise_ApplyOp_62__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1636 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2823 "cg_arith.c"

static void ILBitwise_ApplyOp_63__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1636 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2831 "cg_arith.c"

static void ILBitwise_ApplyOp_64__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1636 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2839 "cg_arith.c"

static void ILBitwise_ApplyOp_65__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1636 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2847 "cg_arith.c"

static void ILBitwise_ApplyOp_66__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1636 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2855 "cg_arith.c"

static void ILBitwise_ApplyOp_67__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1636 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2863 "cg_arith.c"

static void ILBitwise_ApplyOp_68__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1636 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2871 "cg_arith.c"

static void ILBitwise_ApplyOp_69__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType)
#line 1636 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 2879 "cg_arith.c"

void ILBitwise_ApplyOp(ILGenInfo * info, ILNode_BinaryBitwise * node__, ILMachineType commonType)
{
	switch(node__->kind__)
	{
		case ILNode_And_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILBitwise_ApplyOp_1__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILBitwise_ApplyOp_2__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_Int8:
				{
					ILBitwise_ApplyOp_3__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILBitwise_ApplyOp_4__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_Int16:
				{
					ILBitwise_ApplyOp_5__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILBitwise_ApplyOp_6__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_Char:
				{
					ILBitwise_ApplyOp_7__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_Int32:
				{
					ILBitwise_ApplyOp_8__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILBitwise_ApplyOp_9__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_Int64:
				{
					ILBitwise_ApplyOp_10__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILBitwise_ApplyOp_11__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILBitwise_ApplyOp_12__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILBitwise_ApplyOp_13__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_Float32:
				{
					ILBitwise_ApplyOp_14__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_Float64:
				{
					ILBitwise_ApplyOp_15__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILBitwise_ApplyOp_16__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILBitwise_ApplyOp_17__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_String:
				{
					ILBitwise_ApplyOp_18__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILBitwise_ApplyOp_19__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILBitwise_ApplyOp_20__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILBitwise_ApplyOp_21__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILBitwise_ApplyOp_22__(info, (ILNode_And *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILBitwise_ApplyOp_23__(info, (ILNode_And *)node__, commonType);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Or_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILBitwise_ApplyOp_24__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILBitwise_ApplyOp_25__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_Int8:
				{
					ILBitwise_ApplyOp_26__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILBitwise_ApplyOp_27__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_Int16:
				{
					ILBitwise_ApplyOp_28__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILBitwise_ApplyOp_29__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_Char:
				{
					ILBitwise_ApplyOp_30__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_Int32:
				{
					ILBitwise_ApplyOp_31__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILBitwise_ApplyOp_32__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_Int64:
				{
					ILBitwise_ApplyOp_33__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILBitwise_ApplyOp_34__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILBitwise_ApplyOp_35__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILBitwise_ApplyOp_36__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_Float32:
				{
					ILBitwise_ApplyOp_37__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_Float64:
				{
					ILBitwise_ApplyOp_38__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILBitwise_ApplyOp_39__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILBitwise_ApplyOp_40__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_String:
				{
					ILBitwise_ApplyOp_41__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILBitwise_ApplyOp_42__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILBitwise_ApplyOp_43__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILBitwise_ApplyOp_44__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILBitwise_ApplyOp_45__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILBitwise_ApplyOp_46__(info, (ILNode_Or *)node__, commonType);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Xor_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILBitwise_ApplyOp_47__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILBitwise_ApplyOp_48__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_Int8:
				{
					ILBitwise_ApplyOp_49__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILBitwise_ApplyOp_50__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_Int16:
				{
					ILBitwise_ApplyOp_51__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILBitwise_ApplyOp_52__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_Char:
				{
					ILBitwise_ApplyOp_53__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_Int32:
				{
					ILBitwise_ApplyOp_54__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILBitwise_ApplyOp_55__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_Int64:
				{
					ILBitwise_ApplyOp_56__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILBitwise_ApplyOp_57__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILBitwise_ApplyOp_58__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILBitwise_ApplyOp_59__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_Float32:
				{
					ILBitwise_ApplyOp_60__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_Float64:
				{
					ILBitwise_ApplyOp_61__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILBitwise_ApplyOp_62__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILBitwise_ApplyOp_63__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_String:
				{
					ILBitwise_ApplyOp_64__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILBitwise_ApplyOp_65__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILBitwise_ApplyOp_66__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILBitwise_ApplyOp_67__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILBitwise_ApplyOp_68__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILBitwise_ApplyOp_69__(info, (ILNode_Xor *)node__, commonType);
				}
				break;

				default: break;
			}
		}
		break;

		default: break;
	}
}

static void ILShift_ApplyOp_1__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1690 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3336 "cg_arith.c"

static void ILShift_ApplyOp_2__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1690 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3344 "cg_arith.c"

static void ILShift_ApplyOp_3__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1645 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	ILGenSimple(info, IL_OP_SHL);
	ILGenSimple(info, IL_OP_CONV_I1);
}
#line 3353 "cg_arith.c"

static void ILShift_ApplyOp_4__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1651 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	ILGenSimple(info, IL_OP_SHL);
	ILGenSimple(info, IL_OP_CONV_U1);
}
#line 3362 "cg_arith.c"

static void ILShift_ApplyOp_5__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1657 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	ILGenSimple(info, IL_OP_SHL);
	ILGenSimple(info, IL_OP_CONV_I2);
}
#line 3371 "cg_arith.c"

static void ILShift_ApplyOp_6__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1664 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	ILGenSimple(info, IL_OP_SHL);
	ILGenSimple(info, IL_OP_CONV_U2);
}
#line 3380 "cg_arith.c"

static void ILShift_ApplyOp_7__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1664 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	ILGenSimple(info, IL_OP_SHL);
	ILGenSimple(info, IL_OP_CONV_U2);
}
#line 3389 "cg_arith.c"

static void ILShift_ApplyOp_8__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1675 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHL);
}
#line 3396 "cg_arith.c"

static void ILShift_ApplyOp_9__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1675 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHL);
}
#line 3403 "cg_arith.c"

static void ILShift_ApplyOp_10__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1675 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHL);
}
#line 3410 "cg_arith.c"

static void ILShift_ApplyOp_11__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1675 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHL);
}
#line 3417 "cg_arith.c"

static void ILShift_ApplyOp_12__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1675 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHL);
}
#line 3424 "cg_arith.c"

static void ILShift_ApplyOp_13__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1675 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHL);
}
#line 3431 "cg_arith.c"

static void ILShift_ApplyOp_14__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1690 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3439 "cg_arith.c"

static void ILShift_ApplyOp_15__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1690 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3447 "cg_arith.c"

static void ILShift_ApplyOp_16__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1690 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3455 "cg_arith.c"

static void ILShift_ApplyOp_17__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1690 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3463 "cg_arith.c"

static void ILShift_ApplyOp_18__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1690 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3471 "cg_arith.c"

static void ILShift_ApplyOp_19__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1690 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3479 "cg_arith.c"

static void ILShift_ApplyOp_20__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1690 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3487 "cg_arith.c"

static void ILShift_ApplyOp_21__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1690 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3495 "cg_arith.c"

static void ILShift_ApplyOp_22__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1690 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3503 "cg_arith.c"

static void ILShift_ApplyOp_23__(ILGenInfo * info, ILNode_Shl *node, ILMachineType commonType)
#line 1690 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3511 "cg_arith.c"

static void ILShift_ApplyOp_24__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1727 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3519 "cg_arith.c"

static void ILShift_ApplyOp_25__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1727 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3527 "cg_arith.c"

static void ILShift_ApplyOp_26__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1706 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR);
}
#line 3534 "cg_arith.c"

static void ILShift_ApplyOp_27__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1706 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR);
}
#line 3541 "cg_arith.c"

static void ILShift_ApplyOp_28__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1706 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR);
}
#line 3548 "cg_arith.c"

static void ILShift_ApplyOp_29__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1706 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR);
}
#line 3555 "cg_arith.c"

static void ILShift_ApplyOp_30__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1706 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR);
}
#line 3562 "cg_arith.c"

static void ILShift_ApplyOp_31__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1706 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR);
}
#line 3569 "cg_arith.c"

static void ILShift_ApplyOp_32__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1712 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR_UN);
}
#line 3576 "cg_arith.c"

static void ILShift_ApplyOp_33__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1706 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR);
}
#line 3583 "cg_arith.c"

static void ILShift_ApplyOp_34__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1712 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR_UN);
}
#line 3590 "cg_arith.c"

static void ILShift_ApplyOp_35__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1706 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR);
}
#line 3597 "cg_arith.c"

static void ILShift_ApplyOp_36__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1712 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR_UN);
}
#line 3604 "cg_arith.c"

static void ILShift_ApplyOp_37__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1727 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3612 "cg_arith.c"

static void ILShift_ApplyOp_38__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1727 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3620 "cg_arith.c"

static void ILShift_ApplyOp_39__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1727 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3628 "cg_arith.c"

static void ILShift_ApplyOp_40__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1727 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3636 "cg_arith.c"

static void ILShift_ApplyOp_41__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1727 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3644 "cg_arith.c"

static void ILShift_ApplyOp_42__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1727 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3652 "cg_arith.c"

static void ILShift_ApplyOp_43__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1727 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3660 "cg_arith.c"

static void ILShift_ApplyOp_44__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1727 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3668 "cg_arith.c"

static void ILShift_ApplyOp_45__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1727 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3676 "cg_arith.c"

static void ILShift_ApplyOp_46__(ILGenInfo * info, ILNode_Shr *node, ILMachineType commonType)
#line 1727 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3684 "cg_arith.c"

static void ILShift_ApplyOp_47__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1761 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3692 "cg_arith.c"

static void ILShift_ApplyOp_48__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1761 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3700 "cg_arith.c"

static void ILShift_ApplyOp_49__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1746 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR_UN);
}
#line 3707 "cg_arith.c"

static void ILShift_ApplyOp_50__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1746 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR_UN);
}
#line 3714 "cg_arith.c"

static void ILShift_ApplyOp_51__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1746 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR_UN);
}
#line 3721 "cg_arith.c"

static void ILShift_ApplyOp_52__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1746 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR_UN);
}
#line 3728 "cg_arith.c"

static void ILShift_ApplyOp_53__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1746 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR_UN);
}
#line 3735 "cg_arith.c"

static void ILShift_ApplyOp_54__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1746 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR_UN);
}
#line 3742 "cg_arith.c"

static void ILShift_ApplyOp_55__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1746 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR_UN);
}
#line 3749 "cg_arith.c"

static void ILShift_ApplyOp_56__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1746 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR_UN);
}
#line 3756 "cg_arith.c"

static void ILShift_ApplyOp_57__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1746 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR_UN);
}
#line 3763 "cg_arith.c"

static void ILShift_ApplyOp_58__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1746 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR_UN);
}
#line 3770 "cg_arith.c"

static void ILShift_ApplyOp_59__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1746 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SHR_UN);
}
#line 3777 "cg_arith.c"

static void ILShift_ApplyOp_60__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1761 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3785 "cg_arith.c"

static void ILShift_ApplyOp_61__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1761 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3793 "cg_arith.c"

static void ILShift_ApplyOp_62__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1761 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3801 "cg_arith.c"

static void ILShift_ApplyOp_63__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1761 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3809 "cg_arith.c"

static void ILShift_ApplyOp_64__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1761 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3817 "cg_arith.c"

static void ILShift_ApplyOp_65__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1761 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3825 "cg_arith.c"

static void ILShift_ApplyOp_66__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1761 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3833 "cg_arith.c"

static void ILShift_ApplyOp_67__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1761 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3841 "cg_arith.c"

static void ILShift_ApplyOp_68__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1761 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3849 "cg_arith.c"

static void ILShift_ApplyOp_69__(ILGenInfo * info, ILNode_UShr *node, ILMachineType commonType)
#line 1761 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 3857 "cg_arith.c"

void ILShift_ApplyOp(ILGenInfo * info, ILNode_BinaryShift * node__, ILMachineType commonType)
{
	switch(node__->kind__)
	{
		case ILNode_Shl_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILShift_ApplyOp_1__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILShift_ApplyOp_2__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_Int8:
				{
					ILShift_ApplyOp_3__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILShift_ApplyOp_4__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_Int16:
				{
					ILShift_ApplyOp_5__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILShift_ApplyOp_6__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_Char:
				{
					ILShift_ApplyOp_7__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_Int32:
				{
					ILShift_ApplyOp_8__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILShift_ApplyOp_9__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_Int64:
				{
					ILShift_ApplyOp_10__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILShift_ApplyOp_11__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILShift_ApplyOp_12__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILShift_ApplyOp_13__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_Float32:
				{
					ILShift_ApplyOp_14__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_Float64:
				{
					ILShift_ApplyOp_15__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILShift_ApplyOp_16__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILShift_ApplyOp_17__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_String:
				{
					ILShift_ApplyOp_18__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILShift_ApplyOp_19__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILShift_ApplyOp_20__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILShift_ApplyOp_21__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILShift_ApplyOp_22__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILShift_ApplyOp_23__(info, (ILNode_Shl *)node__, commonType);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Shr_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILShift_ApplyOp_24__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILShift_ApplyOp_25__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_Int8:
				{
					ILShift_ApplyOp_26__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILShift_ApplyOp_27__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_Int16:
				{
					ILShift_ApplyOp_28__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILShift_ApplyOp_29__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_Char:
				{
					ILShift_ApplyOp_30__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_Int32:
				{
					ILShift_ApplyOp_31__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILShift_ApplyOp_32__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_Int64:
				{
					ILShift_ApplyOp_33__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILShift_ApplyOp_34__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILShift_ApplyOp_35__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILShift_ApplyOp_36__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_Float32:
				{
					ILShift_ApplyOp_37__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_Float64:
				{
					ILShift_ApplyOp_38__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILShift_ApplyOp_39__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILShift_ApplyOp_40__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_String:
				{
					ILShift_ApplyOp_41__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILShift_ApplyOp_42__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILShift_ApplyOp_43__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILShift_ApplyOp_44__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILShift_ApplyOp_45__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILShift_ApplyOp_46__(info, (ILNode_Shr *)node__, commonType);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_UShr_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILShift_ApplyOp_47__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILShift_ApplyOp_48__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_Int8:
				{
					ILShift_ApplyOp_49__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILShift_ApplyOp_50__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_Int16:
				{
					ILShift_ApplyOp_51__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILShift_ApplyOp_52__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_Char:
				{
					ILShift_ApplyOp_53__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_Int32:
				{
					ILShift_ApplyOp_54__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILShift_ApplyOp_55__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_Int64:
				{
					ILShift_ApplyOp_56__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILShift_ApplyOp_57__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILShift_ApplyOp_58__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILShift_ApplyOp_59__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_Float32:
				{
					ILShift_ApplyOp_60__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_Float64:
				{
					ILShift_ApplyOp_61__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILShift_ApplyOp_62__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILShift_ApplyOp_63__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_String:
				{
					ILShift_ApplyOp_64__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILShift_ApplyOp_65__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILShift_ApplyOp_66__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILShift_ApplyOp_67__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILShift_ApplyOp_68__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILShift_ApplyOp_69__(info, (ILNode_UShr *)node__, commonType);
				}
				break;

				default: break;
			}
		}
		break;

		default: break;
	}
}

static void ILBinary_ApplyOp_1__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 993 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 4314 "cg_arith.c"

static void ILBinary_ApplyOp_2__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 993 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 4322 "cg_arith.c"

static void ILBinary_ApplyOp_3__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 872 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	ILGenSimple(info, IL_OP_ADD);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_I1);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_I1);
	}
}
#line 4338 "cg_arith.c"

static void ILBinary_ApplyOp_4__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 885 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	ILGenSimple(info, IL_OP_ADD);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_U1);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_U1);
	}
}
#line 4354 "cg_arith.c"

static void ILBinary_ApplyOp_5__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 898 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	ILGenSimple(info, IL_OP_ADD);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_I2);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_I2);
	}
}
#line 4370 "cg_arith.c"

static void ILBinary_ApplyOp_6__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 912 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	ILGenSimple(info, IL_OP_ADD);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_U2);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_U2);
	}
}
#line 4386 "cg_arith.c"

static void ILBinary_ApplyOp_7__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 912 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	ILGenSimple(info, IL_OP_ADD);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_U2);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_U2);
	}
}
#line 4402 "cg_arith.c"

static void ILBinary_ApplyOp_8__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 927 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_ADD_OVF);
	}
	else
	{
		ILGenSimple(info, IL_OP_ADD);
	}
}
#line 4416 "cg_arith.c"

static void ILBinary_ApplyOp_9__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 941 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_ADD_OVF_UN);
	}
	else
	{
		ILGenSimple(info, IL_OP_ADD);
	}
}
#line 4430 "cg_arith.c"

static void ILBinary_ApplyOp_10__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 927 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_ADD_OVF);
	}
	else
	{
		ILGenSimple(info, IL_OP_ADD);
	}
}
#line 4444 "cg_arith.c"

static void ILBinary_ApplyOp_11__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 941 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_ADD_OVF_UN);
	}
	else
	{
		ILGenSimple(info, IL_OP_ADD);
	}
}
#line 4458 "cg_arith.c"

static void ILBinary_ApplyOp_12__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 927 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_ADD_OVF);
	}
	else
	{
		ILGenSimple(info, IL_OP_ADD);
	}
}
#line 4472 "cg_arith.c"

static void ILBinary_ApplyOp_13__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 941 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_ADD_OVF_UN);
	}
	else
	{
		ILGenSimple(info, IL_OP_ADD);
	}
}
#line 4486 "cg_arith.c"

static void ILBinary_ApplyOp_14__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 952 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_ADD);
	if(info->pedanticArith)
	{
		/* Clamp the result back to "float32" */
		ILGenSimple(info, IL_OP_CONV_R4);
	}
}
#line 4498 "cg_arith.c"

static void ILBinary_ApplyOp_15__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 961 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_ADD);
	if(info->pedanticArith)
	{
		/* Clamp the result back to "float64" */
		ILGenSimple(info, IL_OP_CONV_R8);
	}
}
#line 4510 "cg_arith.c"

static void ILBinary_ApplyOp_16__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 970 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_ADD);
}
#line 4517 "cg_arith.c"

static void ILBinary_ApplyOp_17__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 974 "cg_arith.tc"
{
	ILGenCallByName(info,
		"valuetype [.library]System.Decimal "
			"[.library]System.Decimal::op_Addition"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
}
#line 4528 "cg_arith.c"

static void ILBinary_ApplyOp_18__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 982 "cg_arith.tc"
{
	ILGenCallByName(info,
		"class [.library]System.String [.library]System.String::Concat"
			"(class [.library]System.String, class [.library]System.String)");
}
#line 4537 "cg_arith.c"

static void ILBinary_ApplyOp_19__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 993 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 4545 "cg_arith.c"

static void ILBinary_ApplyOp_20__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 941 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_ADD_OVF_UN);
	}
	else
	{
		ILGenSimple(info, IL_OP_ADD);
	}
}
#line 4559 "cg_arith.c"

static void ILBinary_ApplyOp_21__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 993 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 4567 "cg_arith.c"

static void ILBinary_ApplyOp_22__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 993 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 4575 "cg_arith.c"

static void ILBinary_ApplyOp_23__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType)
#line 993 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 4583 "cg_arith.c"

static void ILBinary_ApplyOp_24__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1118 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 4591 "cg_arith.c"

static void ILBinary_ApplyOp_25__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1118 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 4599 "cg_arith.c"

static void ILBinary_ApplyOp_26__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1002 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	ILGenSimple(info, IL_OP_SUB);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_I1);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_I1);
	}
}
#line 4615 "cg_arith.c"

static void ILBinary_ApplyOp_27__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1015 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	ILGenSimple(info, IL_OP_SUB);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_U1);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_U1);
	}
}
#line 4631 "cg_arith.c"

static void ILBinary_ApplyOp_28__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1028 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	ILGenSimple(info, IL_OP_SUB);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_I2);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_I2);
	}
}
#line 4647 "cg_arith.c"

static void ILBinary_ApplyOp_29__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1042 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	ILGenSimple(info, IL_OP_SUB);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_U2);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_U2);
	}
}
#line 4663 "cg_arith.c"

static void ILBinary_ApplyOp_30__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1042 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	ILGenSimple(info, IL_OP_SUB);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_U2);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_U2);
	}
}
#line 4679 "cg_arith.c"

static void ILBinary_ApplyOp_31__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1057 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_SUB_OVF);
	}
	else
	{
		ILGenSimple(info, IL_OP_SUB);
	}
}
#line 4693 "cg_arith.c"

static void ILBinary_ApplyOp_32__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1071 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_SUB_OVF_UN);
	}
	else
	{
		ILGenSimple(info, IL_OP_SUB);
	}
}
#line 4707 "cg_arith.c"

static void ILBinary_ApplyOp_33__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1057 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_SUB_OVF);
	}
	else
	{
		ILGenSimple(info, IL_OP_SUB);
	}
}
#line 4721 "cg_arith.c"

static void ILBinary_ApplyOp_34__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1071 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_SUB_OVF_UN);
	}
	else
	{
		ILGenSimple(info, IL_OP_SUB);
	}
}
#line 4735 "cg_arith.c"

static void ILBinary_ApplyOp_35__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1057 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_SUB_OVF);
	}
	else
	{
		ILGenSimple(info, IL_OP_SUB);
	}
}
#line 4749 "cg_arith.c"

static void ILBinary_ApplyOp_36__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1071 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_SUB_OVF_UN);
	}
	else
	{
		ILGenSimple(info, IL_OP_SUB);
	}
}
#line 4763 "cg_arith.c"

static void ILBinary_ApplyOp_37__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1082 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SUB);
	if(info->pedanticArith)
	{
		/* Clamp the result back to "float32" */
		ILGenSimple(info, IL_OP_CONV_R4);
	}
}
#line 4775 "cg_arith.c"

static void ILBinary_ApplyOp_38__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1091 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SUB);
	if(info->pedanticArith)
	{
		/* Clamp the result back to "float64" */
		ILGenSimple(info, IL_OP_CONV_R8);
	}
}
#line 4787 "cg_arith.c"

static void ILBinary_ApplyOp_39__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1100 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_SUB);
}
#line 4794 "cg_arith.c"

static void ILBinary_ApplyOp_40__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1104 "cg_arith.tc"
{
	ILGenCallByName(info,
		"valuetype [.library]System.Decimal "
			"[.library]System.Decimal::op_Subtraction"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
}
#line 4805 "cg_arith.c"

static void ILBinary_ApplyOp_41__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1118 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 4813 "cg_arith.c"

static void ILBinary_ApplyOp_42__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1118 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 4821 "cg_arith.c"

static void ILBinary_ApplyOp_43__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1071 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_SUB_OVF_UN);
	}
	else
	{
		ILGenSimple(info, IL_OP_SUB);
	}
}
#line 4835 "cg_arith.c"

static void ILBinary_ApplyOp_44__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1118 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 4843 "cg_arith.c"

static void ILBinary_ApplyOp_45__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1118 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 4851 "cg_arith.c"

static void ILBinary_ApplyOp_46__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType)
#line 1118 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 4859 "cg_arith.c"

static void ILBinary_ApplyOp_47__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1243 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 4867 "cg_arith.c"

static void ILBinary_ApplyOp_48__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1243 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 4875 "cg_arith.c"

static void ILBinary_ApplyOp_49__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1127 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	ILGenSimple(info, IL_OP_MUL);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_I1);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_I1);
	}
}
#line 4891 "cg_arith.c"

static void ILBinary_ApplyOp_50__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1140 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	ILGenSimple(info, IL_OP_MUL);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_U1);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_U1);
	}
}
#line 4907 "cg_arith.c"

static void ILBinary_ApplyOp_51__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1153 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	ILGenSimple(info, IL_OP_MUL);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_I2);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_I2);
	}
}
#line 4923 "cg_arith.c"

static void ILBinary_ApplyOp_52__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1167 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	ILGenSimple(info, IL_OP_MUL);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_U2);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_U2);
	}
}
#line 4939 "cg_arith.c"

static void ILBinary_ApplyOp_53__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1167 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	ILGenSimple(info, IL_OP_MUL);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_U2);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_U2);
	}
}
#line 4955 "cg_arith.c"

static void ILBinary_ApplyOp_54__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1182 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_MUL_OVF);
	}
	else
	{
		ILGenSimple(info, IL_OP_MUL);
	}
}
#line 4969 "cg_arith.c"

static void ILBinary_ApplyOp_55__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1195 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_MUL_OVF_UN);
	}
	else
	{
		ILGenSimple(info, IL_OP_MUL);
	}
}
#line 4983 "cg_arith.c"

static void ILBinary_ApplyOp_56__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1182 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_MUL_OVF);
	}
	else
	{
		ILGenSimple(info, IL_OP_MUL);
	}
}
#line 4997 "cg_arith.c"

static void ILBinary_ApplyOp_57__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1195 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_MUL_OVF_UN);
	}
	else
	{
		ILGenSimple(info, IL_OP_MUL);
	}
}
#line 5011 "cg_arith.c"

static void ILBinary_ApplyOp_58__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1182 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_MUL_OVF);
	}
	else
	{
		ILGenSimple(info, IL_OP_MUL);
	}
}
#line 5025 "cg_arith.c"

static void ILBinary_ApplyOp_59__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1195 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_MUL_OVF_UN);
	}
	else
	{
		ILGenSimple(info, IL_OP_MUL);
	}
}
#line 5039 "cg_arith.c"

static void ILBinary_ApplyOp_60__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1206 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_MUL);
	if(info->pedanticArith)
	{
		/* Clamp the result back to "float32" */
		ILGenSimple(info, IL_OP_CONV_R4);
	}
}
#line 5051 "cg_arith.c"

static void ILBinary_ApplyOp_61__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1215 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_MUL);
	if(info->pedanticArith)
	{
		/* Clamp the result back to "float64" */
		ILGenSimple(info, IL_OP_CONV_R8);
	}
}
#line 5063 "cg_arith.c"

static void ILBinary_ApplyOp_62__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1224 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_MUL);
}
#line 5070 "cg_arith.c"

static void ILBinary_ApplyOp_63__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1228 "cg_arith.tc"
{
	ILGenCallByName(info,
		"valuetype [.library]System.Decimal "
			"[.library]System.Decimal::op_Multiply"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
}
#line 5081 "cg_arith.c"

static void ILBinary_ApplyOp_64__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1243 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5089 "cg_arith.c"

static void ILBinary_ApplyOp_65__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1243 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5097 "cg_arith.c"

static void ILBinary_ApplyOp_66__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1243 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5105 "cg_arith.c"

static void ILBinary_ApplyOp_67__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1243 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5113 "cg_arith.c"

static void ILBinary_ApplyOp_68__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1243 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5121 "cg_arith.c"

static void ILBinary_ApplyOp_69__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType)
#line 1243 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5129 "cg_arith.c"

static void ILBinary_ApplyOp_70__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1351 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5137 "cg_arith.c"

static void ILBinary_ApplyOp_71__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1351 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5145 "cg_arith.c"

static void ILBinary_ApplyOp_72__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1252 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	ILGenSimple(info, IL_OP_DIV);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_I1);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_I1);
	}
}
#line 5161 "cg_arith.c"

static void ILBinary_ApplyOp_73__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1265 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	ILGenSimple(info, IL_OP_DIV);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_U1);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_U1);
	}
}
#line 5177 "cg_arith.c"

static void ILBinary_ApplyOp_74__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1278 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	ILGenSimple(info, IL_OP_DIV);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_I2);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_I2);
	}
}
#line 5193 "cg_arith.c"

static void ILBinary_ApplyOp_75__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1292 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	ILGenSimple(info, IL_OP_DIV);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_U2);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_U2);
	}
}
#line 5209 "cg_arith.c"

static void ILBinary_ApplyOp_76__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1292 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	ILGenSimple(info, IL_OP_DIV);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_U2);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_U2);
	}
}
#line 5225 "cg_arith.c"

static void ILBinary_ApplyOp_77__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1308 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_DIV);
}
#line 5232 "cg_arith.c"

static void ILBinary_ApplyOp_78__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1314 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_DIV_UN);
}
#line 5239 "cg_arith.c"

static void ILBinary_ApplyOp_79__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1308 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_DIV);
}
#line 5246 "cg_arith.c"

static void ILBinary_ApplyOp_80__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1314 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_DIV_UN);
}
#line 5253 "cg_arith.c"

static void ILBinary_ApplyOp_81__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1308 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_DIV);
}
#line 5260 "cg_arith.c"

static void ILBinary_ApplyOp_82__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1314 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_DIV_UN);
}
#line 5267 "cg_arith.c"

static void ILBinary_ApplyOp_83__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1318 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_DIV);
	if(info->pedanticArith)
	{
		/* Clamp the result back to "float32" */
		ILGenSimple(info, IL_OP_CONV_R4);
	}
}
#line 5279 "cg_arith.c"

static void ILBinary_ApplyOp_84__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1327 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_DIV);
	if(info->pedanticArith)
	{
		/* Clamp the result back to "float64" */
		ILGenSimple(info, IL_OP_CONV_R8);
	}
}
#line 5291 "cg_arith.c"

static void ILBinary_ApplyOp_85__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1308 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_DIV);
}
#line 5298 "cg_arith.c"

static void ILBinary_ApplyOp_86__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1336 "cg_arith.tc"
{
	ILGenCallByName(info,
		"valuetype [.library]System.Decimal "
			"[.library]System.Decimal::op_Division"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
}
#line 5309 "cg_arith.c"

static void ILBinary_ApplyOp_87__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1351 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5317 "cg_arith.c"

static void ILBinary_ApplyOp_88__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1351 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5325 "cg_arith.c"

static void ILBinary_ApplyOp_89__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1351 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5333 "cg_arith.c"

static void ILBinary_ApplyOp_90__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1351 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5341 "cg_arith.c"

static void ILBinary_ApplyOp_91__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1351 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5349 "cg_arith.c"

static void ILBinary_ApplyOp_92__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType)
#line 1351 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5357 "cg_arith.c"

static void ILBinary_ApplyOp_93__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1459 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5365 "cg_arith.c"

static void ILBinary_ApplyOp_94__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1459 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5373 "cg_arith.c"

static void ILBinary_ApplyOp_95__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1360 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	ILGenSimple(info, IL_OP_REM);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_I1);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_I1);
	}
}
#line 5389 "cg_arith.c"

static void ILBinary_ApplyOp_96__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1373 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	ILGenSimple(info, IL_OP_REM);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_U1);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_U1);
	}
}
#line 5405 "cg_arith.c"

static void ILBinary_ApplyOp_97__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1386 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	ILGenSimple(info, IL_OP_REM);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_I2);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_I2);
	}
}
#line 5421 "cg_arith.c"

static void ILBinary_ApplyOp_98__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1400 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	ILGenSimple(info, IL_OP_REM);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_U2);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_U2);
	}
}
#line 5437 "cg_arith.c"

static void ILBinary_ApplyOp_99__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1400 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	ILGenSimple(info, IL_OP_REM);
	if(info->overflowInsns)
	{
		ILGenSimple(info, IL_OP_CONV_OVF_U2);
	}
	else
	{
		ILGenSimple(info, IL_OP_CONV_U2);
	}
}
#line 5453 "cg_arith.c"

static void ILBinary_ApplyOp_100__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1416 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_REM);
}
#line 5460 "cg_arith.c"

static void ILBinary_ApplyOp_101__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1422 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_REM_UN);
}
#line 5467 "cg_arith.c"

static void ILBinary_ApplyOp_102__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1416 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_REM);
}
#line 5474 "cg_arith.c"

static void ILBinary_ApplyOp_103__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1422 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_REM_UN);
}
#line 5481 "cg_arith.c"

static void ILBinary_ApplyOp_104__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1416 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_REM);
}
#line 5488 "cg_arith.c"

static void ILBinary_ApplyOp_105__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1422 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_REM_UN);
}
#line 5495 "cg_arith.c"

static void ILBinary_ApplyOp_106__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1426 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_REM);
	if(info->pedanticArith)
	{
		/* Clamp the result back to "float32" */
		ILGenSimple(info, IL_OP_CONV_R4);
	}
}
#line 5507 "cg_arith.c"

static void ILBinary_ApplyOp_107__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1435 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_REM);
	if(info->pedanticArith)
	{
		/* Clamp the result back to "float64" */
		ILGenSimple(info, IL_OP_CONV_R8);
	}
}
#line 5519 "cg_arith.c"

static void ILBinary_ApplyOp_108__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1416 "cg_arith.tc"
{
	ILGenSimple(info, IL_OP_REM);
}
#line 5526 "cg_arith.c"

static void ILBinary_ApplyOp_109__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1444 "cg_arith.tc"
{
	ILGenCallByName(info,
		"valuetype [.library]System.Decimal "
			"[.library]System.Decimal::op_Modulus"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
}
#line 5537 "cg_arith.c"

static void ILBinary_ApplyOp_110__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1459 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5545 "cg_arith.c"

static void ILBinary_ApplyOp_111__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1459 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5553 "cg_arith.c"

static void ILBinary_ApplyOp_112__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1459 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5561 "cg_arith.c"

static void ILBinary_ApplyOp_113__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1459 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5569 "cg_arith.c"

static void ILBinary_ApplyOp_114__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1459 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5577 "cg_arith.c"

static void ILBinary_ApplyOp_115__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType)
#line 1459 "cg_arith.tc"
{
	/* Default - should never be used */
	ILGenSimple(info, IL_OP_POP);
}
#line 5585 "cg_arith.c"

void ILBinary_ApplyOp(ILGenInfo * info, ILNode_BinaryArith * node__, ILMachineType commonType)
{
	switch(node__->kind__)
	{
		case ILNode_Add_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILBinary_ApplyOp_1__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILBinary_ApplyOp_2__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_Int8:
				{
					ILBinary_ApplyOp_3__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILBinary_ApplyOp_4__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_Int16:
				{
					ILBinary_ApplyOp_5__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILBinary_ApplyOp_6__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_Char:
				{
					ILBinary_ApplyOp_7__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_Int32:
				{
					ILBinary_ApplyOp_8__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILBinary_ApplyOp_9__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_Int64:
				{
					ILBinary_ApplyOp_10__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILBinary_ApplyOp_11__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILBinary_ApplyOp_12__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILBinary_ApplyOp_13__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_Float32:
				{
					ILBinary_ApplyOp_14__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_Float64:
				{
					ILBinary_ApplyOp_15__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILBinary_ApplyOp_16__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILBinary_ApplyOp_17__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_String:
				{
					ILBinary_ApplyOp_18__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILBinary_ApplyOp_19__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILBinary_ApplyOp_20__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILBinary_ApplyOp_21__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILBinary_ApplyOp_22__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILBinary_ApplyOp_23__(info, (ILNode_Add *)node__, commonType);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Sub_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILBinary_ApplyOp_24__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILBinary_ApplyOp_25__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_Int8:
				{
					ILBinary_ApplyOp_26__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILBinary_ApplyOp_27__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_Int16:
				{
					ILBinary_ApplyOp_28__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILBinary_ApplyOp_29__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_Char:
				{
					ILBinary_ApplyOp_30__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_Int32:
				{
					ILBinary_ApplyOp_31__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILBinary_ApplyOp_32__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_Int64:
				{
					ILBinary_ApplyOp_33__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILBinary_ApplyOp_34__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILBinary_ApplyOp_35__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILBinary_ApplyOp_36__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_Float32:
				{
					ILBinary_ApplyOp_37__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_Float64:
				{
					ILBinary_ApplyOp_38__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILBinary_ApplyOp_39__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILBinary_ApplyOp_40__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_String:
				{
					ILBinary_ApplyOp_41__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILBinary_ApplyOp_42__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILBinary_ApplyOp_43__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILBinary_ApplyOp_44__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILBinary_ApplyOp_45__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILBinary_ApplyOp_46__(info, (ILNode_Sub *)node__, commonType);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Mul_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILBinary_ApplyOp_47__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILBinary_ApplyOp_48__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_Int8:
				{
					ILBinary_ApplyOp_49__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILBinary_ApplyOp_50__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_Int16:
				{
					ILBinary_ApplyOp_51__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILBinary_ApplyOp_52__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_Char:
				{
					ILBinary_ApplyOp_53__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_Int32:
				{
					ILBinary_ApplyOp_54__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILBinary_ApplyOp_55__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_Int64:
				{
					ILBinary_ApplyOp_56__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILBinary_ApplyOp_57__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILBinary_ApplyOp_58__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILBinary_ApplyOp_59__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_Float32:
				{
					ILBinary_ApplyOp_60__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_Float64:
				{
					ILBinary_ApplyOp_61__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILBinary_ApplyOp_62__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILBinary_ApplyOp_63__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_String:
				{
					ILBinary_ApplyOp_64__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILBinary_ApplyOp_65__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILBinary_ApplyOp_66__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILBinary_ApplyOp_67__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILBinary_ApplyOp_68__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILBinary_ApplyOp_69__(info, (ILNode_Mul *)node__, commonType);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Div_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILBinary_ApplyOp_70__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILBinary_ApplyOp_71__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_Int8:
				{
					ILBinary_ApplyOp_72__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILBinary_ApplyOp_73__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_Int16:
				{
					ILBinary_ApplyOp_74__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILBinary_ApplyOp_75__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_Char:
				{
					ILBinary_ApplyOp_76__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_Int32:
				{
					ILBinary_ApplyOp_77__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILBinary_ApplyOp_78__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_Int64:
				{
					ILBinary_ApplyOp_79__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILBinary_ApplyOp_80__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILBinary_ApplyOp_81__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILBinary_ApplyOp_82__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_Float32:
				{
					ILBinary_ApplyOp_83__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_Float64:
				{
					ILBinary_ApplyOp_84__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILBinary_ApplyOp_85__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILBinary_ApplyOp_86__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_String:
				{
					ILBinary_ApplyOp_87__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILBinary_ApplyOp_88__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILBinary_ApplyOp_89__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILBinary_ApplyOp_90__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILBinary_ApplyOp_91__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILBinary_ApplyOp_92__(info, (ILNode_Div *)node__, commonType);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Rem_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILBinary_ApplyOp_93__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILBinary_ApplyOp_94__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_Int8:
				{
					ILBinary_ApplyOp_95__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILBinary_ApplyOp_96__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_Int16:
				{
					ILBinary_ApplyOp_97__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILBinary_ApplyOp_98__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_Char:
				{
					ILBinary_ApplyOp_99__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_Int32:
				{
					ILBinary_ApplyOp_100__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILBinary_ApplyOp_101__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_Int64:
				{
					ILBinary_ApplyOp_102__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILBinary_ApplyOp_103__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILBinary_ApplyOp_104__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILBinary_ApplyOp_105__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_Float32:
				{
					ILBinary_ApplyOp_106__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_Float64:
				{
					ILBinary_ApplyOp_107__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILBinary_ApplyOp_108__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILBinary_ApplyOp_109__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_String:
				{
					ILBinary_ApplyOp_110__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILBinary_ApplyOp_111__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILBinary_ApplyOp_112__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILBinary_ApplyOp_113__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILBinary_ApplyOp_114__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILBinary_ApplyOp_115__(info, (ILNode_Rem *)node__, commonType);
				}
				break;

				default: break;
			}
		}
		break;

		default: break;
	}
}

void ILNegate_ApplyOp(ILGenInfo * info, ILNode_Neg * node, ILMachineType commonType)
{
	switch(commonType)
	{
		case ILMachineType_Void:
		{
#line 1891 "cg_arith.tc"
			{
				/* Default - should never be used */
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
			}
#line 6341 "cg_arith.c"
		}
		break;

		case ILMachineType_Boolean:
		{
#line 1891 "cg_arith.tc"
			{
				/* Default - should never be used */
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
			}
#line 6352 "cg_arith.c"
		}
		break;

		case ILMachineType_Int8:
		{
#line 1770 "cg_arith.tc"
			{
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
				ILGenSimple(info, IL_OP_NEG);
				if(info->overflowInsns)
				{
					ILGenSimple(info, IL_OP_CONV_OVF_I1);
				}
				else
				{
					ILGenSimple(info, IL_OP_CONV_I1);
				}
			}
#line 6371 "cg_arith.c"
		}
		break;

		case ILMachineType_UInt8:
		{
#line 1783 "cg_arith.tc"
			{
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
				ILGenSimple(info, IL_OP_NEG);
				ILGenSimple(info, IL_OP_CONV_U1);
			}
#line 6383 "cg_arith.c"
		}
		break;

		case ILMachineType_Int16:
		{
#line 1789 "cg_arith.tc"
			{
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
				ILGenSimple(info, IL_OP_NEG);
				if(info->overflowInsns)
				{
					ILGenSimple(info, IL_OP_CONV_OVF_I2);
				}
				else
				{
					ILGenSimple(info, IL_OP_CONV_I2);
				}
			}
#line 6402 "cg_arith.c"
		}
		break;

		case ILMachineType_UInt16:
		{
#line 1803 "cg_arith.tc"
			{
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
				ILGenSimple(info, IL_OP_NEG);
				ILGenSimple(info, IL_OP_CONV_U2);
			}
#line 6414 "cg_arith.c"
		}
		break;

		case ILMachineType_Char:
		{
#line 1803 "cg_arith.tc"
			{
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
				ILGenSimple(info, IL_OP_NEG);
				ILGenSimple(info, IL_OP_CONV_U2);
			}
#line 6426 "cg_arith.c"
		}
		break;

		case ILMachineType_Int32:
		{
#line 1809 "cg_arith.tc"
			{
				if(info->overflowInsns)
				{
					/* We need to detect overflow while performing the negation,
					   and there is no "NEG_OVF" operation to do that.  So, we
					   subtract the argument from zero instead */
					ILGenSimple(info, IL_OP_LDC_I4_0);
					ILGenAdjust(info, 1);
					ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
					ILGenSimple(info, IL_OP_SUB_OVF);
					ILGenAdjust(info, -1);
				}
				else
				{
					ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
					ILGenSimple(info, IL_OP_NEG);
				}
			}
#line 6451 "cg_arith.c"
		}
		break;

		case ILMachineType_UInt32:
		{
#line 1871 "cg_arith.tc"
			{
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
				ILGenSimple(info, IL_OP_NEG);
			}
#line 6462 "cg_arith.c"
		}
		break;

		case ILMachineType_Int64:
		{
#line 1828 "cg_arith.tc"
			{
				if(info->overflowInsns)
				{
					/* We need to detect overflow while performing the negation,
					   and there is no "NEG_OVF" operation to do that.  So, we
					   subtract the argument from zero instead */
					ILGenInt64(info, (ILInt64)0);
					ILGenAdjust(info, 1);
					ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
					ILGenSimple(info, IL_OP_SUB_OVF);
					ILGenAdjust(info, -1);
				}
				else
				{
					ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
					ILGenSimple(info, IL_OP_NEG);
				}
			}
#line 6487 "cg_arith.c"
		}
		break;

		case ILMachineType_UInt64:
		{
#line 1871 "cg_arith.tc"
			{
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
				ILGenSimple(info, IL_OP_NEG);
			}
#line 6498 "cg_arith.c"
		}
		break;

		case ILMachineType_NativeInt:
		{
#line 1847 "cg_arith.tc"
			{
				if(info->overflowInsns)
				{
					/* We need to detect overflow while performing the negation,
					   and there is no "NEG_OVF" operation to do that.  So, we
					   subtract the argument from zero instead */
					ILGenIntNative(info, (ILInt32)0);
					ILGenAdjust(info, 1);
					ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
					ILGenSimple(info, IL_OP_SUB_OVF);
					ILGenAdjust(info, -1);
				}
				else
				{
					ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
					ILGenSimple(info, IL_OP_NEG);
				}
			}
#line 6523 "cg_arith.c"
		}
		break;

		case ILMachineType_NativeUInt:
		{
#line 1871 "cg_arith.tc"
			{
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
				ILGenSimple(info, IL_OP_NEG);
			}
#line 6534 "cg_arith.c"
		}
		break;

		case ILMachineType_Float32:
		{
#line 1871 "cg_arith.tc"
			{
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
				ILGenSimple(info, IL_OP_NEG);
			}
#line 6545 "cg_arith.c"
		}
		break;

		case ILMachineType_Float64:
		{
#line 1871 "cg_arith.tc"
			{
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
				ILGenSimple(info, IL_OP_NEG);
			}
#line 6556 "cg_arith.c"
		}
		break;

		case ILMachineType_NativeFloat:
		{
#line 1871 "cg_arith.tc"
			{
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
				ILGenSimple(info, IL_OP_NEG);
			}
#line 6567 "cg_arith.c"
		}
		break;

		case ILMachineType_Decimal:
		{
#line 1876 "cg_arith.tc"
			{
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
				ILGenCallByName(info,
					"valuetype [.library]System.Decimal "
						"[.library]System.Decimal::op_UnaryNegation"
						"(valuetype [.library]System.Decimal)");
			}
#line 6581 "cg_arith.c"
		}
		break;

		case ILMachineType_String:
		{
#line 1891 "cg_arith.tc"
			{
				/* Default - should never be used */
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
			}
#line 6592 "cg_arith.c"
		}
		break;

		case ILMachineType_ObjectRef:
		{
#line 1891 "cg_arith.tc"
			{
				/* Default - should never be used */
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
			}
#line 6603 "cg_arith.c"
		}
		break;

		case ILMachineType_UnmanagedPtr:
		{
#line 1891 "cg_arith.tc"
			{
				/* Default - should never be used */
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
			}
#line 6614 "cg_arith.c"
		}
		break;

		case ILMachineType_ManagedPtr:
		{
#line 1891 "cg_arith.tc"
			{
				/* Default - should never be used */
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
			}
#line 6625 "cg_arith.c"
		}
		break;

		case ILMachineType_TransientPtr:
		{
#line 1891 "cg_arith.tc"
			{
				/* Default - should never be used */
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
			}
#line 6636 "cg_arith.c"
		}
		break;

		case ILMachineType_ManagedValue:
		{
#line 1891 "cg_arith.tc"
			{
				/* Default - should never be used */
				ILGenCast(info, ILNode_GenValue(node->expr, info), commonType);
			}
#line 6647 "cg_arith.c"
		}
		break;

		default: break;
	}
}

static int ILBitwise_EvalOp_1__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2753 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	value1->un.i4Value =
		(ILInt32)(ILInt8)(value1->un.i4Value & value2->un.i4Value);
	return 1;
}
#line 6663 "cg_arith.c"

static int ILBitwise_EvalOp_2__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2760 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	value1->un.i4Value =
		(ILInt32)(ILUInt8)(value1->un.i4Value & value2->un.i4Value);
	return 1;
}
#line 6673 "cg_arith.c"

static int ILBitwise_EvalOp_3__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2767 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	value1->un.i4Value =
		(ILInt32)(ILInt16)(value1->un.i4Value & value2->un.i4Value);
	return 1;
}
#line 6683 "cg_arith.c"

static int ILBitwise_EvalOp_4__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2775 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	value1->un.i4Value =
		(ILInt32)(ILUInt16)(value1->un.i4Value & value2->un.i4Value);
	return 1;
}
#line 6693 "cg_arith.c"

static int ILBitwise_EvalOp_5__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2775 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	value1->un.i4Value =
		(ILInt32)(ILUInt16)(value1->un.i4Value & value2->un.i4Value);
	return 1;
}
#line 6703 "cg_arith.c"

static int ILBitwise_EvalOp_6__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2785 "cg_arith.tc"
{
	value1->un.i4Value &= value2->un.i4Value;
	return 1;
}
#line 6711 "cg_arith.c"

static int ILBitwise_EvalOp_7__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2785 "cg_arith.tc"
{
	value1->un.i4Value &= value2->un.i4Value;
	return 1;
}
#line 6719 "cg_arith.c"

static int ILBitwise_EvalOp_8__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2791 "cg_arith.tc"
{
	value1->un.i8Value &= value2->un.i8Value;
	return 1;
}
#line 6727 "cg_arith.c"

static int ILBitwise_EvalOp_9__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2791 "cg_arith.tc"
{
	value1->un.i8Value &= value2->un.i8Value;
	return 1;
}
#line 6735 "cg_arith.c"

static int ILBitwise_EvalOp_10__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2785 "cg_arith.tc"
{
	value1->un.i4Value &= value2->un.i4Value;
	return 1;
}
#line 6743 "cg_arith.c"

static int ILBitwise_EvalOp_11__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2785 "cg_arith.tc"
{
	value1->un.i4Value &= value2->un.i4Value;
	return 1;
}
#line 6751 "cg_arith.c"

static int ILBitwise_EvalOp_12__(ILGenInfo * info, ILNode_And *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2796 "cg_arith.tc"
{
	return 0;
}
#line 6758 "cg_arith.c"

static int ILBitwise_EvalOp_13__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2804 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	value1->un.i4Value =
		(ILInt32)(ILInt8)(value1->un.i4Value | value2->un.i4Value);
	return 1;
}
#line 6768 "cg_arith.c"

static int ILBitwise_EvalOp_14__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2811 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	value1->un.i4Value =
		(ILInt32)(ILUInt8)(value1->un.i4Value | value2->un.i4Value);
	return 1;
}
#line 6778 "cg_arith.c"

static int ILBitwise_EvalOp_15__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2818 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	value1->un.i4Value =
		(ILInt32)(ILInt16)(value1->un.i4Value | value2->un.i4Value);
	return 1;
}
#line 6788 "cg_arith.c"

static int ILBitwise_EvalOp_16__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2826 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	value1->un.i4Value =
		(ILInt32)(ILUInt16)(value1->un.i4Value | value2->un.i4Value);
	return 1;
}
#line 6798 "cg_arith.c"

static int ILBitwise_EvalOp_17__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2826 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	value1->un.i4Value =
		(ILInt32)(ILUInt16)(value1->un.i4Value | value2->un.i4Value);
	return 1;
}
#line 6808 "cg_arith.c"

static int ILBitwise_EvalOp_18__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2836 "cg_arith.tc"
{
	value1->un.i4Value |= value2->un.i4Value;
	return 1;
}
#line 6816 "cg_arith.c"

static int ILBitwise_EvalOp_19__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2836 "cg_arith.tc"
{
	value1->un.i4Value |= value2->un.i4Value;
	return 1;
}
#line 6824 "cg_arith.c"

static int ILBitwise_EvalOp_20__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2842 "cg_arith.tc"
{
	value1->un.i8Value |= value2->un.i8Value;
	return 1;
}
#line 6832 "cg_arith.c"

static int ILBitwise_EvalOp_21__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2842 "cg_arith.tc"
{
	value1->un.i8Value |= value2->un.i8Value;
	return 1;
}
#line 6840 "cg_arith.c"

static int ILBitwise_EvalOp_22__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2836 "cg_arith.tc"
{
	value1->un.i4Value |= value2->un.i4Value;
	return 1;
}
#line 6848 "cg_arith.c"

static int ILBitwise_EvalOp_23__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2836 "cg_arith.tc"
{
	value1->un.i4Value |= value2->un.i4Value;
	return 1;
}
#line 6856 "cg_arith.c"

static int ILBitwise_EvalOp_24__(ILGenInfo * info, ILNode_Or *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2847 "cg_arith.tc"
{
	return 0;
}
#line 6863 "cg_arith.c"

static int ILBitwise_EvalOp_25__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2855 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	value1->un.i4Value =
		(ILInt32)(ILInt8)(value1->un.i4Value ^ value2->un.i4Value);
	return 1;
}
#line 6873 "cg_arith.c"

static int ILBitwise_EvalOp_26__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2862 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	value1->un.i4Value =
		(ILInt32)(ILUInt8)(value1->un.i4Value ^ value2->un.i4Value);
	return 1;
}
#line 6883 "cg_arith.c"

static int ILBitwise_EvalOp_27__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2869 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	value1->un.i4Value =
		(ILInt32)(ILInt16)(value1->un.i4Value ^ value2->un.i4Value);
	return 1;
}
#line 6893 "cg_arith.c"

static int ILBitwise_EvalOp_28__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2877 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	value1->un.i4Value =
		(ILInt32)(ILUInt16)(value1->un.i4Value ^ value2->un.i4Value);
	return 1;
}
#line 6903 "cg_arith.c"

static int ILBitwise_EvalOp_29__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2877 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	value1->un.i4Value =
		(ILInt32)(ILUInt16)(value1->un.i4Value ^ value2->un.i4Value);
	return 1;
}
#line 6913 "cg_arith.c"

static int ILBitwise_EvalOp_30__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2887 "cg_arith.tc"
{
	value1->un.i4Value ^= value2->un.i4Value;
	return 1;
}
#line 6921 "cg_arith.c"

static int ILBitwise_EvalOp_31__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2887 "cg_arith.tc"
{
	value1->un.i4Value ^= value2->un.i4Value;
	return 1;
}
#line 6929 "cg_arith.c"

static int ILBitwise_EvalOp_32__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2893 "cg_arith.tc"
{
	value1->un.i8Value ^= value2->un.i8Value;
	return 1;
}
#line 6937 "cg_arith.c"

static int ILBitwise_EvalOp_33__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2893 "cg_arith.tc"
{
	value1->un.i8Value ^= value2->un.i8Value;
	return 1;
}
#line 6945 "cg_arith.c"

static int ILBitwise_EvalOp_34__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2887 "cg_arith.tc"
{
	value1->un.i4Value ^= value2->un.i4Value;
	return 1;
}
#line 6953 "cg_arith.c"

static int ILBitwise_EvalOp_35__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2887 "cg_arith.tc"
{
	value1->un.i4Value ^= value2->un.i4Value;
	return 1;
}
#line 6961 "cg_arith.c"

static int ILBitwise_EvalOp_36__(ILGenInfo * info, ILNode_Xor *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2898 "cg_arith.tc"
{
	return 0;
}
#line 6968 "cg_arith.c"

int ILBitwise_EvalOp(ILGenInfo * info, ILNode_BinaryBitwise * node__, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
{
	switch(node__->kind__)
	{
		case ILNode_And_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					return ILBitwise_EvalOp_12__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Boolean:
				{
					return ILBitwise_EvalOp_12__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int8:
				{
					return ILBitwise_EvalOp_1__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt8:
				{
					return ILBitwise_EvalOp_2__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int16:
				{
					return ILBitwise_EvalOp_3__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt16:
				{
					return ILBitwise_EvalOp_4__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Char:
				{
					return ILBitwise_EvalOp_5__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int32:
				{
					return ILBitwise_EvalOp_6__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt32:
				{
					return ILBitwise_EvalOp_7__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int64:
				{
					return ILBitwise_EvalOp_8__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt64:
				{
					return ILBitwise_EvalOp_9__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeInt:
				{
					return ILBitwise_EvalOp_10__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					return ILBitwise_EvalOp_11__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float32:
				{
					return ILBitwise_EvalOp_12__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float64:
				{
					return ILBitwise_EvalOp_12__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					return ILBitwise_EvalOp_12__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Decimal:
				{
					return ILBitwise_EvalOp_12__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_String:
				{
					return ILBitwise_EvalOp_12__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					return ILBitwise_EvalOp_12__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					return ILBitwise_EvalOp_12__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					return ILBitwise_EvalOp_12__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					return ILBitwise_EvalOp_12__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					return ILBitwise_EvalOp_12__(info, (ILNode_And *)node__, commonType, value1, value2);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Or_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					return ILBitwise_EvalOp_24__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Boolean:
				{
					return ILBitwise_EvalOp_24__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int8:
				{
					return ILBitwise_EvalOp_13__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt8:
				{
					return ILBitwise_EvalOp_14__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int16:
				{
					return ILBitwise_EvalOp_15__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt16:
				{
					return ILBitwise_EvalOp_16__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Char:
				{
					return ILBitwise_EvalOp_17__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int32:
				{
					return ILBitwise_EvalOp_18__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt32:
				{
					return ILBitwise_EvalOp_19__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int64:
				{
					return ILBitwise_EvalOp_20__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt64:
				{
					return ILBitwise_EvalOp_21__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeInt:
				{
					return ILBitwise_EvalOp_22__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					return ILBitwise_EvalOp_23__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float32:
				{
					return ILBitwise_EvalOp_24__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float64:
				{
					return ILBitwise_EvalOp_24__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					return ILBitwise_EvalOp_24__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Decimal:
				{
					return ILBitwise_EvalOp_24__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_String:
				{
					return ILBitwise_EvalOp_24__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					return ILBitwise_EvalOp_24__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					return ILBitwise_EvalOp_24__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					return ILBitwise_EvalOp_24__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					return ILBitwise_EvalOp_24__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					return ILBitwise_EvalOp_24__(info, (ILNode_Or *)node__, commonType, value1, value2);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Xor_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					return ILBitwise_EvalOp_36__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Boolean:
				{
					return ILBitwise_EvalOp_36__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int8:
				{
					return ILBitwise_EvalOp_25__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt8:
				{
					return ILBitwise_EvalOp_26__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int16:
				{
					return ILBitwise_EvalOp_27__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt16:
				{
					return ILBitwise_EvalOp_28__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Char:
				{
					return ILBitwise_EvalOp_29__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int32:
				{
					return ILBitwise_EvalOp_30__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt32:
				{
					return ILBitwise_EvalOp_31__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int64:
				{
					return ILBitwise_EvalOp_32__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt64:
				{
					return ILBitwise_EvalOp_33__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeInt:
				{
					return ILBitwise_EvalOp_34__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					return ILBitwise_EvalOp_35__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float32:
				{
					return ILBitwise_EvalOp_36__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float64:
				{
					return ILBitwise_EvalOp_36__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					return ILBitwise_EvalOp_36__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Decimal:
				{
					return ILBitwise_EvalOp_36__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_String:
				{
					return ILBitwise_EvalOp_36__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					return ILBitwise_EvalOp_36__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					return ILBitwise_EvalOp_36__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					return ILBitwise_EvalOp_36__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					return ILBitwise_EvalOp_36__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					return ILBitwise_EvalOp_36__(info, (ILNode_Xor *)node__, commonType, value1, value2);
				}
				break;

				default: break;
			}
		}
		break;

		default: break;
	}
	return (0);
}

static int ILBinary_EvalOp_1__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1949 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	if(info->overflowInsns)
	{
		value1->un.i4Value += value2->un.i4Value;
		if(value1->un.i4Value < (ILInt32)(-128) ||
		   value1->un.i4Value > (ILInt32)127)
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value =
			(ILInt32)(ILInt8)(value1->un.i4Value + value2->un.i4Value);
	}
	return 1;
}
#line 7440 "cg_arith.c"

static int ILBinary_EvalOp_2__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1968 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	if(info->overflowInsns)
	{
		value1->un.i4Value += value2->un.i4Value;
		if(value1->un.i4Value < (ILInt32)0 ||
		   value1->un.i4Value > (ILInt32)255)
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value =
			(ILInt32)(ILUInt8)(value1->un.i4Value + value2->un.i4Value);
	}
	return 1;
}
#line 7462 "cg_arith.c"

static int ILBinary_EvalOp_3__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1987 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	if(info->overflowInsns)
	{
		value1->un.i4Value += value2->un.i4Value;
		if(value1->un.i4Value < (ILInt32)(-32768) ||
		   value1->un.i4Value > (ILInt32)32767)
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value =
			(ILInt32)(ILInt16)(value1->un.i4Value + value2->un.i4Value);
	}
	return 1;
}
#line 7484 "cg_arith.c"

static int ILBinary_EvalOp_4__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2007 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	if(info->overflowInsns)
	{
		value1->un.i4Value += value2->un.i4Value;
		if(value1->un.i4Value < (ILInt32)0 ||
		   value1->un.i4Value > (ILInt32)65535)
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value =
			(ILInt32)(ILUInt16)(value1->un.i4Value + value2->un.i4Value);
	}
	return 1;
}
#line 7506 "cg_arith.c"

static int ILBinary_EvalOp_5__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2007 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	if(info->overflowInsns)
	{
		value1->un.i4Value += value2->un.i4Value;
		if(value1->un.i4Value < (ILInt32)0 ||
		   value1->un.i4Value > (ILInt32)65535)
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value =
			(ILInt32)(ILUInt16)(value1->un.i4Value + value2->un.i4Value);
	}
	return 1;
}
#line 7528 "cg_arith.c"

static int ILBinary_EvalOp_6__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2027 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		value1->un.i4Value += value2->un.i4Value;
		if(((ILUInt32)(value1->un.i4Value)) <
				((ILUInt32)(value2->un.i4Value)))
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value += value2->un.i4Value;
	}
	return 1;
}
#line 7548 "cg_arith.c"

static int ILBinary_EvalOp_7__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2027 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		value1->un.i4Value += value2->un.i4Value;
		if(((ILUInt32)(value1->un.i4Value)) <
				((ILUInt32)(value2->un.i4Value)))
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value += value2->un.i4Value;
	}
	return 1;
}
#line 7568 "cg_arith.c"

static int ILBinary_EvalOp_8__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2045 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		value1->un.i8Value += value2->un.i8Value;
		if(((ILUInt64)(value1->un.i8Value)) <
				((ILUInt64)(value2->un.i8Value)))
		{
			return 0;
		}
	}
	else
	{
		value1->un.i8Value += value2->un.i8Value;
	}
	return 1;
}
#line 7588 "cg_arith.c"

static int ILBinary_EvalOp_9__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2045 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		value1->un.i8Value += value2->un.i8Value;
		if(((ILUInt64)(value1->un.i8Value)) <
				((ILUInt64)(value2->un.i8Value)))
		{
			return 0;
		}
	}
	else
	{
		value1->un.i8Value += value2->un.i8Value;
	}
	return 1;
}
#line 7608 "cg_arith.c"

static int ILBinary_EvalOp_10__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2062 "cg_arith.tc"
{
	ILInt64 testResult = ((ILInt64)(value1->un.i4Value)) +
						 ((ILInt64)(value2->un.i4Value));
	value1->un.i4Value += value2->un.i4Value;
	if(((ILInt64)(value1->un.i4Value)) != testResult)
	{
		/* The operation behaves differently on 32-bit and
		   64-bit platforms, so we must evaluate at runtime */
		return 0;
	}
	if(info->overflowInsns)
	{
		if(((ILUInt32)(value1->un.i4Value)) <
				((ILUInt32)(value2->un.i4Value)))
		{
			return 0;
		}
	}
	return 1;
}
#line 7632 "cg_arith.c"

static int ILBinary_EvalOp_11__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2083 "cg_arith.tc"
{
	ILUInt64 testResult = ((ILUInt64)(ILUInt32)(value1->un.i4Value)) +
						  ((ILUInt64)(ILUInt32)(value2->un.i4Value));
	value1->un.i4Value += value2->un.i4Value;
	if(((ILUInt64)(ILUInt32)(value1->un.i4Value)) != testResult)
	{
		/* The operation behaves differently on 32-bit and
		   64-bit platforms, so we must evaluate at runtime */
		return 0;
	}
	if(info->overflowInsns)
	{
		if(((ILUInt32)(value1->un.i4Value)) <
				((ILUInt32)(value2->un.i4Value)))
		{
			return 0;
		}
	}
	return 1;
}
#line 7656 "cg_arith.c"

static int ILBinary_EvalOp_12__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2104 "cg_arith.tc"
{
	value1->un.r4Value += value2->un.r4Value;
	return 1;
}
#line 7664 "cg_arith.c"

static int ILBinary_EvalOp_13__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2110 "cg_arith.tc"
{
	value1->un.r8Value += value2->un.r8Value;
	return 1;
}
#line 7672 "cg_arith.c"

static int ILBinary_EvalOp_14__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2110 "cg_arith.tc"
{
	value1->un.r8Value += value2->un.r8Value;
	return 1;
}
#line 7680 "cg_arith.c"

static int ILBinary_EvalOp_15__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2115 "cg_arith.tc"
{
	return ILDecimalAdd(&(value1->un.decValue),
						&(value1->un.decValue),
						&(value2->un.decValue),
						info->decimalRoundMode);
}
#line 7690 "cg_arith.c"

static int ILBinary_EvalOp_16__(ILGenInfo * info, ILNode_Add *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2122 "cg_arith.tc"
{
	return 0;
}
#line 7697 "cg_arith.c"

static int ILBinary_EvalOp_17__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2130 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	if(info->overflowInsns)
	{
		value1->un.i4Value -= value2->un.i4Value;
		if(value1->un.i4Value < (ILInt32)(-128) ||
		   value1->un.i4Value > (ILInt32)127)
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value =
			(ILInt32)(ILInt8)(value1->un.i4Value - value2->un.i4Value);
	}
	return 1;
}
#line 7719 "cg_arith.c"

static int ILBinary_EvalOp_18__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2149 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	if(info->overflowInsns)
	{
		value1->un.i4Value -= value2->un.i4Value;
		if(value1->un.i4Value < (ILInt32)0 ||
		   value1->un.i4Value > (ILInt32)255)
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value =
			(ILInt32)(ILUInt8)(value1->un.i4Value - value2->un.i4Value);
	}
	return 1;
}
#line 7741 "cg_arith.c"

static int ILBinary_EvalOp_19__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2168 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	if(info->overflowInsns)
	{
		value1->un.i4Value -= value2->un.i4Value;
		if(value1->un.i4Value < (ILInt32)(-32768) ||
		   value1->un.i4Value > (ILInt32)32767)
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value =
			(ILInt32)(ILInt16)(value1->un.i4Value - value2->un.i4Value);
	}
	return 1;
}
#line 7763 "cg_arith.c"

static int ILBinary_EvalOp_20__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2188 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	if(info->overflowInsns)
	{
		value1->un.i4Value -= value2->un.i4Value;
		if(value1->un.i4Value < (ILInt32)0 ||
		   value1->un.i4Value > (ILInt32)65535)
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value =
			(ILInt32)(ILUInt16)(value1->un.i4Value - value2->un.i4Value);
	}
	return 1;
}
#line 7785 "cg_arith.c"

static int ILBinary_EvalOp_21__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2188 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	if(info->overflowInsns)
	{
		value1->un.i4Value -= value2->un.i4Value;
		if(value1->un.i4Value < (ILInt32)0 ||
		   value1->un.i4Value > (ILInt32)65535)
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value =
			(ILInt32)(ILUInt16)(value1->un.i4Value - value2->un.i4Value);
	}
	return 1;
}
#line 7807 "cg_arith.c"

static int ILBinary_EvalOp_22__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2207 "cg_arith.tc"
{
	int RetVal = 1;
	ILInt32 diff = value1->un.i4Value - value2->un.i4Value;
	if(info->overflowInsns)
	{

		if (((ILUInt32)diff > (ILUInt32)value1->un.i4Value)
			!= (diff < 0))
		{
			RetVal = 0;
		}
	}
	value1->un.i4Value = diff;
	return RetVal;
}
#line 7826 "cg_arith.c"

static int ILBinary_EvalOp_23__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2223 "cg_arith.tc"
{
	int RetVal = 1;
	if(info->overflowInsns && 
	   (ILUInt32)value1->un.i4Value < (ILUInt32)value2->un.i4Value)
	{
		RetVal = 0;
	}
	value1->un.i4Value -= value2->un.i4Value;
	return RetVal;
}
#line 7840 "cg_arith.c"

static int ILBinary_EvalOp_24__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2235 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		value1->un.i8Value -= value2->un.i8Value;
		if(((ILUInt64)(value1->un.i8Value)) >
				((ILUInt64)(value2->un.i8Value)))
		{
			return 0;
		}
	}
	else
	{
		value1->un.i8Value -= value2->un.i8Value;
	}
	return 1;
}
#line 7860 "cg_arith.c"

static int ILBinary_EvalOp_25__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2235 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		value1->un.i8Value -= value2->un.i8Value;
		if(((ILUInt64)(value1->un.i8Value)) >
				((ILUInt64)(value2->un.i8Value)))
		{
			return 0;
		}
	}
	else
	{
		value1->un.i8Value -= value2->un.i8Value;
	}
	return 1;
}
#line 7880 "cg_arith.c"

static int ILBinary_EvalOp_26__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2252 "cg_arith.tc"
{
	ILInt64 testResult = ((ILInt64)(value1->un.i4Value)) -
						 ((ILInt64)(value2->un.i4Value));
	value1->un.i4Value -= value2->un.i4Value;
	if(((ILInt64)(value1->un.i4Value)) != testResult)
	{
		/* The operation behaves differently on 32-bit and
		   64-bit platforms, so we must evaluate at runtime */
		return 0;
	}
	if(info->overflowInsns)
	{
		if(((ILUInt32)(value1->un.i4Value)) >
				((ILUInt32)(value2->un.i4Value)))
		{
			return 0;
		}
	}
	return 1;
}
#line 7904 "cg_arith.c"

static int ILBinary_EvalOp_27__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2273 "cg_arith.tc"
{
	ILUInt64 testResult = ((ILUInt64)(ILUInt32)(value1->un.i4Value)) -
						  ((ILUInt64)(ILUInt32)(value2->un.i4Value));
	value1->un.i4Value -= value2->un.i4Value;
	if(((ILUInt64)(ILUInt32)(value1->un.i4Value)) != testResult)
	{
		/* The operation behaves differently on 32-bit and
		   64-bit platforms, so we must evaluate at runtime */
		return 0;
	}
	if(info->overflowInsns)
	{
		if(((ILUInt32)(value1->un.i4Value)) >
				((ILUInt32)(value2->un.i4Value)))
		{
			return 0;
		}
	}
	return 1;
}
#line 7928 "cg_arith.c"

static int ILBinary_EvalOp_28__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2294 "cg_arith.tc"
{
	value1->un.r4Value -= value2->un.r4Value;
	return 1;
}
#line 7936 "cg_arith.c"

static int ILBinary_EvalOp_29__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2300 "cg_arith.tc"
{
	value1->un.r8Value -= value2->un.r8Value;
	return 1;
}
#line 7944 "cg_arith.c"

static int ILBinary_EvalOp_30__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2300 "cg_arith.tc"
{
	value1->un.r8Value -= value2->un.r8Value;
	return 1;
}
#line 7952 "cg_arith.c"

static int ILBinary_EvalOp_31__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2305 "cg_arith.tc"
{
	return ILDecimalSub(&(value1->un.decValue),
						&(value1->un.decValue),
						&(value2->un.decValue),
						info->decimalRoundMode);
}
#line 7962 "cg_arith.c"

static int ILBinary_EvalOp_32__(ILGenInfo * info, ILNode_Sub *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2312 "cg_arith.tc"
{
	return 0;
}
#line 7969 "cg_arith.c"

static int ILBinary_EvalOp_33__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2320 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	if(info->overflowInsns)
	{
		value1->un.i4Value *= value2->un.i4Value;
		if(value1->un.i4Value < (ILInt32)(-128) ||
		   value1->un.i4Value > (ILInt32)127)
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value =
			(ILInt32)(ILInt8)(value1->un.i4Value * value2->un.i4Value);
	}
	return 1;
}
#line 7991 "cg_arith.c"

static int ILBinary_EvalOp_34__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2339 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	if(info->overflowInsns)
	{
		value1->un.i4Value *= value2->un.i4Value;
		if(value1->un.i4Value < (ILInt32)0 ||
		   value1->un.i4Value > (ILInt32)255)
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value =
			(ILInt32)(ILUInt8)(value1->un.i4Value * value2->un.i4Value);
	}
	return 1;
}
#line 8013 "cg_arith.c"

static int ILBinary_EvalOp_35__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2358 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	if(info->overflowInsns)
	{
		value1->un.i4Value *= value2->un.i4Value;
		if(value1->un.i4Value < (ILInt32)(-32768) ||
		   value1->un.i4Value > (ILInt32)32767)
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value =
			(ILInt32)(ILInt16)(value1->un.i4Value * value2->un.i4Value);
	}
	return 1;
}
#line 8035 "cg_arith.c"

static int ILBinary_EvalOp_36__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2378 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	if(info->overflowInsns)
	{
		value1->un.i4Value *= value2->un.i4Value;
		if(value1->un.i4Value < (ILInt32)0 ||
		   value1->un.i4Value > (ILInt32)65535)
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value =
			(ILInt32)(ILUInt16)(value1->un.i4Value * value2->un.i4Value);
	}
	return 1;
}
#line 8057 "cg_arith.c"

static int ILBinary_EvalOp_37__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2378 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	if(info->overflowInsns)
	{
		value1->un.i4Value *= value2->un.i4Value;
		if(value1->un.i4Value < (ILInt32)0 ||
		   value1->un.i4Value > (ILInt32)65535)
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value =
			(ILInt32)(ILUInt16)(value1->un.i4Value * value2->un.i4Value);
	}
	return 1;
}
#line 8079 "cg_arith.c"

static int ILBinary_EvalOp_38__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2397 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILInt64 testResult = ((ILInt64)(value1->un.i4Value)) *
							 ((ILInt64)(value2->un.i4Value));
		value1->un.i4Value *= value2->un.i4Value;
		if(((ILInt64)(value1->un.i4Value)) != testResult)
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value *= value2->un.i4Value;
	}
	return 1;
}
#line 8100 "cg_arith.c"

static int ILBinary_EvalOp_39__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2415 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		ILUInt64 testResult = ((ILUInt64)(ILUInt32)(value1->un.i4Value)) *
							  ((ILUInt64)(ILUInt32)(value2->un.i4Value));
		value1->un.i4Value =
			(ILInt32)(((ILUInt32)(value1->un.i4Value)) *
					  ((ILUInt32)(value2->un.i4Value)));
		if(((ILUInt64)(ILUInt32)(value1->un.i4Value)) != testResult)
		{
			return 0;
		}
	}
	else
	{
		value1->un.i4Value =
			(ILInt32)(((ILUInt32)(value1->un.i4Value)) *
					  ((ILUInt32)(value2->un.i4Value)));
	}
	return 1;
}
#line 8125 "cg_arith.c"

static int ILBinary_EvalOp_40__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2437 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		if(!ILInt64MulOvf(&(value1->un.i8Value),
						  value1->un.i8Value, value2->un.i8Value))
		{
			return 0;
		}
	}
	else
	{
		value1->un.i8Value *= value2->un.i8Value;
	}
	return 1;
}
#line 8144 "cg_arith.c"

static int ILBinary_EvalOp_41__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2453 "cg_arith.tc"
{
	if(info->overflowInsns)
	{
		if(!ILUInt64MulOvf((ILUInt64 *)&(value1->un.i8Value),
						   (ILUInt64)(value1->un.i8Value),
						   (ILUInt64)(value2->un.i8Value)))
		{
			return 0;
		}
	}
	else
	{
		value1->un.i8Value = (ILInt64)(((ILUInt64)(value1->un.i8Value)) *
									   ((ILUInt64)(value2->un.i8Value)));
	}
	return 1;
}
#line 8165 "cg_arith.c"

static int ILBinary_EvalOp_42__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2471 "cg_arith.tc"
{
	ILInt64 testResult = ((ILInt64)(value1->un.i4Value)) *
						 ((ILInt64)(value2->un.i4Value));
	value1->un.i4Value *= value2->un.i4Value;
	if(((ILInt64)(value1->un.i4Value)) != testResult)
	{
		/* The operation behaves differently on 32-bit and
		   64-bit platforms, so we must evaluate at runtime.
		   This can also happen because of overflow */
		return 0;
	}
	return 1;
}
#line 8182 "cg_arith.c"

static int ILBinary_EvalOp_43__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2485 "cg_arith.tc"
{
	ILUInt64 testResult = ((ILUInt64)(ILUInt32)(value1->un.i4Value)) *
						  ((ILUInt64)(ILUInt32)(value2->un.i4Value));
	value1->un.i4Value *= value2->un.i4Value;
	if(((ILUInt64)(ILUInt32)(value1->un.i4Value)) != testResult)
	{
		/* The operation behaves differently on 32-bit and
		   64-bit platforms, so we must evaluate at runtime.
		   This can also happen because of overflow */
		return 0;
	}
	return 1;
}
#line 8199 "cg_arith.c"

static int ILBinary_EvalOp_44__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2499 "cg_arith.tc"
{
	value1->un.r4Value *= value2->un.r4Value;
	return 1;
}
#line 8207 "cg_arith.c"

static int ILBinary_EvalOp_45__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2505 "cg_arith.tc"
{
	value1->un.r8Value *= value2->un.r8Value;
	return 1;
}
#line 8215 "cg_arith.c"

static int ILBinary_EvalOp_46__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2505 "cg_arith.tc"
{
	value1->un.r8Value *= value2->un.r8Value;
	return 1;
}
#line 8223 "cg_arith.c"

static int ILBinary_EvalOp_47__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2510 "cg_arith.tc"
{
	return ILDecimalMul(&(value1->un.decValue),
						&(value1->un.decValue),
						&(value2->un.decValue),
						info->decimalRoundMode);
}
#line 8233 "cg_arith.c"

static int ILBinary_EvalOp_48__(ILGenInfo * info, ILNode_Mul *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2517 "cg_arith.tc"
{
	return 0;
}
#line 8240 "cg_arith.c"

static int ILBinary_EvalOp_49__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2525 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	if(!(value2->un.i4Value))
	{
		return 0;
	}
	value1->un.i4Value =
		(ILInt32)(ILInt8)(value1->un.i4Value / value2->un.i4Value);
	return 1;
}
#line 8254 "cg_arith.c"

static int ILBinary_EvalOp_50__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2536 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	if(!(value2->un.i4Value))
	{
		return 0;
	}
	value1->un.i4Value =
		(ILInt32)(ILUInt8)(value1->un.i4Value / value2->un.i4Value);
	return 1;
}
#line 8268 "cg_arith.c"

static int ILBinary_EvalOp_51__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2547 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	if(!(value2->un.i4Value))
	{
		return 0;
	}
	value1->un.i4Value =
		(ILInt32)(ILInt16)(value1->un.i4Value / value2->un.i4Value);
	return 1;
}
#line 8282 "cg_arith.c"

static int ILBinary_EvalOp_52__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2559 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	if(!(value2->un.i4Value))
	{
		return 0;
	}
	value1->un.i4Value =
		(ILInt32)(ILUInt16)(value1->un.i4Value / value2->un.i4Value);
	return 1;
}
#line 8296 "cg_arith.c"

static int ILBinary_EvalOp_53__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2559 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	if(!(value2->un.i4Value))
	{
		return 0;
	}
	value1->un.i4Value =
		(ILInt32)(ILUInt16)(value1->un.i4Value / value2->un.i4Value);
	return 1;
}
#line 8310 "cg_arith.c"

static int ILBinary_EvalOp_54__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2571 "cg_arith.tc"
{
	if(!(value2->un.i4Value))
	{
		return 0;
	}
	value1->un.i4Value /= value2->un.i4Value;
	return 1;
}
#line 8322 "cg_arith.c"

static int ILBinary_EvalOp_55__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2581 "cg_arith.tc"
{
	if(!(value2->un.i4Value))
	{
		return 0;
	}
	value1->un.i4Value =
		(ILInt32)(((ILUInt32)(value1->un.i4Value)) /
				  ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 8336 "cg_arith.c"

static int ILBinary_EvalOp_56__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2592 "cg_arith.tc"
{
	if(!(value2->un.i8Value))
	{
		return 0;
	}
	value1->un.i8Value /= value2->un.i8Value;
	return 1;
}
#line 8348 "cg_arith.c"

static int ILBinary_EvalOp_57__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2601 "cg_arith.tc"
{
	if(!(value2->un.i8Value))
	{
		return 0;
	}
	value1->un.i8Value =
		(ILInt64)(((ILUInt64)(value1->un.i8Value)) /
				  ((ILUInt64)(value2->un.i8Value)));
	return 1;
}
#line 8362 "cg_arith.c"

static int ILBinary_EvalOp_58__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2571 "cg_arith.tc"
{
	if(!(value2->un.i4Value))
	{
		return 0;
	}
	value1->un.i4Value /= value2->un.i4Value;
	return 1;
}
#line 8374 "cg_arith.c"

static int ILBinary_EvalOp_59__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2581 "cg_arith.tc"
{
	if(!(value2->un.i4Value))
	{
		return 0;
	}
	value1->un.i4Value =
		(ILInt32)(((ILUInt32)(value1->un.i4Value)) /
				  ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 8388 "cg_arith.c"

static int ILBinary_EvalOp_60__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2612 "cg_arith.tc"
{
	value1->un.r4Value /= value2->un.r4Value;
	return 1;
}
#line 8396 "cg_arith.c"

static int ILBinary_EvalOp_61__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2618 "cg_arith.tc"
{
	value1->un.r8Value /= value2->un.r8Value;
	return 1;
}
#line 8404 "cg_arith.c"

static int ILBinary_EvalOp_62__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2618 "cg_arith.tc"
{
	value1->un.r8Value /= value2->un.r8Value;
	return 1;
}
#line 8412 "cg_arith.c"

static int ILBinary_EvalOp_63__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2623 "cg_arith.tc"
{
	return ILDecimalDiv(&(value1->un.decValue),
						&(value1->un.decValue),
						&(value2->un.decValue),
						info->decimalRoundMode);
}
#line 8422 "cg_arith.c"

static int ILBinary_EvalOp_64__(ILGenInfo * info, ILNode_Div *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2630 "cg_arith.tc"
{
	return 0;
}
#line 8429 "cg_arith.c"

static int ILBinary_EvalOp_65__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2638 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int8" */
	if(!(value2->un.i4Value))
	{
		return 0;
	}
	value1->un.i4Value =
		(ILInt32)(ILInt8)(value1->un.i4Value % value2->un.i4Value);
	return 1;
}
#line 8443 "cg_arith.c"

static int ILBinary_EvalOp_66__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2649 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint8" */
	if(!(value2->un.i4Value))
	{
		return 0;
	}
	value1->un.i4Value =
		(ILInt32)(ILUInt8)(value1->un.i4Value % value2->un.i4Value);
	return 1;
}
#line 8457 "cg_arith.c"

static int ILBinary_EvalOp_67__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2660 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "int16" */
	if(!(value2->un.i4Value))
	{
		return 0;
	}
	value1->un.i4Value =
		(ILInt32)(ILInt16)(value1->un.i4Value % value2->un.i4Value);
	return 1;
}
#line 8471 "cg_arith.c"

static int ILBinary_EvalOp_68__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2672 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	if(!(value2->un.i4Value))
	{
		return 0;
	}
	value1->un.i4Value =
		(ILInt32)(ILUInt16)(value1->un.i4Value % value2->un.i4Value);
	return 1;
}
#line 8485 "cg_arith.c"

static int ILBinary_EvalOp_69__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2672 "cg_arith.tc"
{
	/* Perform the operation and then clamp the result to "uint16" */
	if(!(value2->un.i4Value))
	{
		return 0;
	}
	value1->un.i4Value =
		(ILInt32)(ILUInt16)(value1->un.i4Value % value2->un.i4Value);
	return 1;
}
#line 8499 "cg_arith.c"

static int ILBinary_EvalOp_70__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2684 "cg_arith.tc"
{
	if(!(value2->un.i4Value))
	{
		return 0;
	}
	value1->un.i4Value %= value2->un.i4Value;
	return 1;
}
#line 8511 "cg_arith.c"

static int ILBinary_EvalOp_71__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2694 "cg_arith.tc"
{
	if(!(value2->un.i4Value))
	{
		return 0;
	}
	value1->un.i4Value =
		(ILInt32)(((ILUInt32)(value1->un.i4Value)) %
				  ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 8525 "cg_arith.c"

static int ILBinary_EvalOp_72__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2705 "cg_arith.tc"
{
	if(!(value2->un.i8Value))
	{
		return 0;
	}
	value1->un.i8Value %= value2->un.i8Value;
	return 1;
}
#line 8537 "cg_arith.c"

static int ILBinary_EvalOp_73__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2714 "cg_arith.tc"
{
	if(!(value2->un.i8Value))
	{
		return 0;
	}
	value1->un.i8Value =
		(ILInt64)(((ILUInt64)(value1->un.i8Value)) %
				  ((ILUInt64)(value2->un.i8Value)));
	return 1;
}
#line 8551 "cg_arith.c"

static int ILBinary_EvalOp_74__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2684 "cg_arith.tc"
{
	if(!(value2->un.i4Value))
	{
		return 0;
	}
	value1->un.i4Value %= value2->un.i4Value;
	return 1;
}
#line 8563 "cg_arith.c"

static int ILBinary_EvalOp_75__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2694 "cg_arith.tc"
{
	if(!(value2->un.i4Value))
	{
		return 0;
	}
	value1->un.i4Value =
		(ILInt32)(((ILUInt32)(value1->un.i4Value)) %
				  ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 8577 "cg_arith.c"

static int ILBinary_EvalOp_76__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2725 "cg_arith.tc"
{
	value1->un.r4Value = (ILFloat)ILNativeFloatRem(value1->un.r4Value,
												   value2->un.r4Value);
	return 1;
}
#line 8586 "cg_arith.c"

static int ILBinary_EvalOp_77__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2732 "cg_arith.tc"
{
	value1->un.r8Value = (ILDouble)ILNativeFloatRem(value1->un.r8Value,
												    value2->un.r8Value);
	return 1;
}
#line 8595 "cg_arith.c"

static int ILBinary_EvalOp_78__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2732 "cg_arith.tc"
{
	value1->un.r8Value = (ILDouble)ILNativeFloatRem(value1->un.r8Value,
												    value2->un.r8Value);
	return 1;
}
#line 8604 "cg_arith.c"

static int ILBinary_EvalOp_79__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2738 "cg_arith.tc"
{
	return ILDecimalRem(&(value1->un.decValue),
						&(value1->un.decValue),
						&(value2->un.decValue),
						info->decimalRoundMode);
}
#line 8614 "cg_arith.c"

static int ILBinary_EvalOp_80__(ILGenInfo * info, ILNode_Rem *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 2745 "cg_arith.tc"
{
	return 0;
}
#line 8621 "cg_arith.c"

int ILBinary_EvalOp(ILGenInfo * info, ILNode_BinaryArith * node__, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
{
	switch(node__->kind__)
	{
		case ILNode_Add_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					return ILBinary_EvalOp_16__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Boolean:
				{
					return ILBinary_EvalOp_16__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int8:
				{
					return ILBinary_EvalOp_1__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt8:
				{
					return ILBinary_EvalOp_2__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int16:
				{
					return ILBinary_EvalOp_3__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt16:
				{
					return ILBinary_EvalOp_4__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Char:
				{
					return ILBinary_EvalOp_5__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int32:
				{
					return ILBinary_EvalOp_6__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt32:
				{
					return ILBinary_EvalOp_7__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int64:
				{
					return ILBinary_EvalOp_8__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt64:
				{
					return ILBinary_EvalOp_9__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeInt:
				{
					return ILBinary_EvalOp_10__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					return ILBinary_EvalOp_11__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float32:
				{
					return ILBinary_EvalOp_12__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float64:
				{
					return ILBinary_EvalOp_13__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					return ILBinary_EvalOp_14__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Decimal:
				{
					return ILBinary_EvalOp_15__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_String:
				{
					return ILBinary_EvalOp_16__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					return ILBinary_EvalOp_16__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					return ILBinary_EvalOp_16__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					return ILBinary_EvalOp_16__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					return ILBinary_EvalOp_16__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					return ILBinary_EvalOp_16__(info, (ILNode_Add *)node__, commonType, value1, value2);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Sub_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					return ILBinary_EvalOp_32__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Boolean:
				{
					return ILBinary_EvalOp_32__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int8:
				{
					return ILBinary_EvalOp_17__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt8:
				{
					return ILBinary_EvalOp_18__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int16:
				{
					return ILBinary_EvalOp_19__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt16:
				{
					return ILBinary_EvalOp_20__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Char:
				{
					return ILBinary_EvalOp_21__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int32:
				{
					return ILBinary_EvalOp_22__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt32:
				{
					return ILBinary_EvalOp_23__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int64:
				{
					return ILBinary_EvalOp_24__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt64:
				{
					return ILBinary_EvalOp_25__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeInt:
				{
					return ILBinary_EvalOp_26__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					return ILBinary_EvalOp_27__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float32:
				{
					return ILBinary_EvalOp_28__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float64:
				{
					return ILBinary_EvalOp_29__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					return ILBinary_EvalOp_30__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Decimal:
				{
					return ILBinary_EvalOp_31__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_String:
				{
					return ILBinary_EvalOp_32__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					return ILBinary_EvalOp_32__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					return ILBinary_EvalOp_32__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					return ILBinary_EvalOp_32__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					return ILBinary_EvalOp_32__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					return ILBinary_EvalOp_32__(info, (ILNode_Sub *)node__, commonType, value1, value2);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Mul_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					return ILBinary_EvalOp_48__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Boolean:
				{
					return ILBinary_EvalOp_48__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int8:
				{
					return ILBinary_EvalOp_33__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt8:
				{
					return ILBinary_EvalOp_34__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int16:
				{
					return ILBinary_EvalOp_35__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt16:
				{
					return ILBinary_EvalOp_36__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Char:
				{
					return ILBinary_EvalOp_37__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int32:
				{
					return ILBinary_EvalOp_38__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt32:
				{
					return ILBinary_EvalOp_39__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int64:
				{
					return ILBinary_EvalOp_40__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt64:
				{
					return ILBinary_EvalOp_41__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeInt:
				{
					return ILBinary_EvalOp_42__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					return ILBinary_EvalOp_43__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float32:
				{
					return ILBinary_EvalOp_44__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float64:
				{
					return ILBinary_EvalOp_45__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					return ILBinary_EvalOp_46__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Decimal:
				{
					return ILBinary_EvalOp_47__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_String:
				{
					return ILBinary_EvalOp_48__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					return ILBinary_EvalOp_48__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					return ILBinary_EvalOp_48__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					return ILBinary_EvalOp_48__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					return ILBinary_EvalOp_48__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					return ILBinary_EvalOp_48__(info, (ILNode_Mul *)node__, commonType, value1, value2);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Div_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					return ILBinary_EvalOp_64__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Boolean:
				{
					return ILBinary_EvalOp_64__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int8:
				{
					return ILBinary_EvalOp_49__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt8:
				{
					return ILBinary_EvalOp_50__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int16:
				{
					return ILBinary_EvalOp_51__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt16:
				{
					return ILBinary_EvalOp_52__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Char:
				{
					return ILBinary_EvalOp_53__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int32:
				{
					return ILBinary_EvalOp_54__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt32:
				{
					return ILBinary_EvalOp_55__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int64:
				{
					return ILBinary_EvalOp_56__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt64:
				{
					return ILBinary_EvalOp_57__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeInt:
				{
					return ILBinary_EvalOp_58__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					return ILBinary_EvalOp_59__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float32:
				{
					return ILBinary_EvalOp_60__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float64:
				{
					return ILBinary_EvalOp_61__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					return ILBinary_EvalOp_62__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Decimal:
				{
					return ILBinary_EvalOp_63__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_String:
				{
					return ILBinary_EvalOp_64__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					return ILBinary_EvalOp_64__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					return ILBinary_EvalOp_64__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					return ILBinary_EvalOp_64__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					return ILBinary_EvalOp_64__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					return ILBinary_EvalOp_64__(info, (ILNode_Div *)node__, commonType, value1, value2);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Rem_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					return ILBinary_EvalOp_80__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Boolean:
				{
					return ILBinary_EvalOp_80__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int8:
				{
					return ILBinary_EvalOp_65__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt8:
				{
					return ILBinary_EvalOp_66__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int16:
				{
					return ILBinary_EvalOp_67__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt16:
				{
					return ILBinary_EvalOp_68__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Char:
				{
					return ILBinary_EvalOp_69__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int32:
				{
					return ILBinary_EvalOp_70__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt32:
				{
					return ILBinary_EvalOp_71__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int64:
				{
					return ILBinary_EvalOp_72__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt64:
				{
					return ILBinary_EvalOp_73__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeInt:
				{
					return ILBinary_EvalOp_74__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					return ILBinary_EvalOp_75__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float32:
				{
					return ILBinary_EvalOp_76__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float64:
				{
					return ILBinary_EvalOp_77__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					return ILBinary_EvalOp_78__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Decimal:
				{
					return ILBinary_EvalOp_79__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_String:
				{
					return ILBinary_EvalOp_80__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					return ILBinary_EvalOp_80__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					return ILBinary_EvalOp_80__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					return ILBinary_EvalOp_80__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					return ILBinary_EvalOp_80__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					return ILBinary_EvalOp_80__(info, (ILNode_Rem *)node__, commonType, value1, value2);
				}
				break;

				default: break;
			}
		}
		break;

		default: break;
	}
	return (0);
}

int ILNegate_EvalOp(ILGenInfo * info, ILMachineType commonType, ILEvalValue * value)
{
	switch(commonType)
	{
		case ILMachineType_Int8:
		{
#line 3087 "cg_arith.tc"
			{
				if(info->overflowInsns)
				{
					value->un.i4Value = -(value->un.i4Value);
					if(value->un.i4Value < (ILInt32)(-128) ||
					   value->un.i4Value > (ILInt32)127)
					{
						return 0;
					}
					return 1;
				}
				else
				{
					value->un.i4Value = (ILInt32)(ILInt8)(-(value->un.i4Value));
					return 1;
				}
			}
#line 9391 "cg_arith.c"
		}
		break;

		case ILMachineType_UInt8:
		{
#line 3105 "cg_arith.tc"
			{
				value->un.i4Value = (ILInt32)(ILUInt8)(-(value->un.i4Value));
				return 1;
			}
#line 9402 "cg_arith.c"
		}
		break;

		case ILMachineType_Int16:
		{
#line 3110 "cg_arith.tc"
			{
				if(info->overflowInsns)
				{
					value->un.i4Value = -(value->un.i4Value);
					if(value->un.i4Value < (ILInt32)(-32768) ||
					   value->un.i4Value > (ILInt32)32767)
					{
						return 0;
					}
					return 1;
				}
				else
				{
					value->un.i4Value = (ILInt32)(ILInt16)(-(value->un.i4Value));
					return 1;
				}
			}
#line 9426 "cg_arith.c"
		}
		break;

		case ILMachineType_UInt16:
		{
#line 3129 "cg_arith.tc"
			{
				value->un.i4Value = (ILInt32)(ILUInt16)(-(value->un.i4Value));
				return 1;
			}
#line 9437 "cg_arith.c"
		}
		break;

		case ILMachineType_Char:
		{
#line 3129 "cg_arith.tc"
			{
				value->un.i4Value = (ILInt32)(ILUInt16)(-(value->un.i4Value));
				return 1;
			}
#line 9448 "cg_arith.c"
		}
		break;

		case ILMachineType_Int32:
		{
#line 3135 "cg_arith.tc"
			{
				if(info->overflowInsns)
				{
					if(value->un.i4Value == IL_MIN_INT32)
					{
						return 0;
					}
				}
				value->un.i4Value = -(value->un.i4Value);
				return 1;
			}
#line 9466 "cg_arith.c"
		}
		break;

		case ILMachineType_UInt32:
		{
#line 3160 "cg_arith.tc"
			{
				value->un.i4Value = -(value->un.i4Value);
				return 1;
			}
#line 9477 "cg_arith.c"
		}
		break;

		case ILMachineType_Int64:
		{
#line 3147 "cg_arith.tc"
			{
				if(info->overflowInsns)
				{
					if(value->un.i8Value == IL_MIN_INT64)
					{
						return 0;
					}
				}
				value->un.i8Value = -(value->un.i8Value);
				return 1;
			}
#line 9495 "cg_arith.c"
		}
		break;

		case ILMachineType_UInt64:
		{
#line 3165 "cg_arith.tc"
			{
				value->un.i8Value = -(value->un.i4Value);
				return 1;
			}
#line 9506 "cg_arith.c"
		}
		break;

		case ILMachineType_NativeInt:
		{
#line 3135 "cg_arith.tc"
			{
				if(info->overflowInsns)
				{
					if(value->un.i4Value == IL_MIN_INT32)
					{
						return 0;
					}
				}
				value->un.i4Value = -(value->un.i4Value);
				return 1;
			}
#line 9524 "cg_arith.c"
		}
		break;

		case ILMachineType_NativeUInt:
		{
#line 3160 "cg_arith.tc"
			{
				value->un.i4Value = -(value->un.i4Value);
				return 1;
			}
#line 9535 "cg_arith.c"
		}
		break;

		case ILMachineType_Float32:
		{
#line 3170 "cg_arith.tc"
			{
				value->un.r4Value = -(value->un.r4Value);
				return 1;
			}
#line 9546 "cg_arith.c"
		}
		break;

		case ILMachineType_Float64:
		{
#line 3176 "cg_arith.tc"
			{
				value->un.r8Value = -(value->un.r8Value);
				return 1;
			}
#line 9557 "cg_arith.c"
		}
		break;

		case ILMachineType_NativeFloat:
		{
#line 3176 "cg_arith.tc"
			{
				value->un.r8Value = -(value->un.r8Value);
				return 1;
			}
#line 9568 "cg_arith.c"
		}
		break;

		case ILMachineType_Decimal:
		{
#line 3181 "cg_arith.tc"
			{
				ILDecimalNeg(&(value->un.decValue), &(value->un.decValue));
				return 1;
			}
#line 9579 "cg_arith.c"
		}
		break;

		case ILMachineType_Void:
		case ILMachineType_Boolean:
		case ILMachineType_String:
		case ILMachineType_ObjectRef:
		case ILMachineType_UnmanagedPtr:
		case ILMachineType_ManagedPtr:
		case ILMachineType_TransientPtr:
		case ILMachineType_ManagedValue:
		{
#line 3186 "cg_arith.tc"
			{
				return 0;
			}
#line 9596 "cg_arith.c"
		}
		break;

		default: break;
	}
	return (0);
}

void ILNot_ApplyOp(ILGenInfo * info, ILMachineType commonType)
{
	switch(commonType)
	{
		case ILMachineType_Void:
		{
#line 1941 "cg_arith.tc"
			{
				/* Default - should never be used */
			}
#line 9615 "cg_arith.c"
		}
		break;

		case ILMachineType_Boolean:
		{
#line 1941 "cg_arith.tc"
			{
				/* Default - should never be used */
			}
#line 9625 "cg_arith.c"
		}
		break;

		case ILMachineType_Int8:
		{
#line 1900 "cg_arith.tc"
			{
				ILGenSimple(info, IL_OP_NOT);
				ILGenSimple(info, IL_OP_CONV_I1);
			}
#line 9636 "cg_arith.c"
		}
		break;

		case ILMachineType_UInt8:
		{
#line 1905 "cg_arith.tc"
			{
				ILGenSimple(info, IL_OP_NOT);
				ILGenSimple(info, IL_OP_CONV_U1);
			}
#line 9647 "cg_arith.c"
		}
		break;

		case ILMachineType_Int16:
		{
#line 1910 "cg_arith.tc"
			{
				ILGenSimple(info, IL_OP_NOT);
				ILGenSimple(info, IL_OP_CONV_I2);
			}
#line 9658 "cg_arith.c"
		}
		break;

		case ILMachineType_UInt16:
		{
#line 1916 "cg_arith.tc"
			{
				ILGenSimple(info, IL_OP_NOT);
				ILGenSimple(info, IL_OP_CONV_U2);
			}
#line 9669 "cg_arith.c"
		}
		break;

		case ILMachineType_Char:
		{
#line 1916 "cg_arith.tc"
			{
				ILGenSimple(info, IL_OP_NOT);
				ILGenSimple(info, IL_OP_CONV_U2);
			}
#line 9680 "cg_arith.c"
		}
		break;

		case ILMachineType_Int32:
		{
#line 1926 "cg_arith.tc"
			{
				ILGenSimple(info, IL_OP_NOT);
			}
#line 9690 "cg_arith.c"
		}
		break;

		case ILMachineType_UInt32:
		{
#line 1926 "cg_arith.tc"
			{
				ILGenSimple(info, IL_OP_NOT);
			}
#line 9700 "cg_arith.c"
		}
		break;

		case ILMachineType_Int64:
		{
#line 1926 "cg_arith.tc"
			{
				ILGenSimple(info, IL_OP_NOT);
			}
#line 9710 "cg_arith.c"
		}
		break;

		case ILMachineType_UInt64:
		{
#line 1926 "cg_arith.tc"
			{
				ILGenSimple(info, IL_OP_NOT);
			}
#line 9720 "cg_arith.c"
		}
		break;

		case ILMachineType_NativeInt:
		{
#line 1926 "cg_arith.tc"
			{
				ILGenSimple(info, IL_OP_NOT);
			}
#line 9730 "cg_arith.c"
		}
		break;

		case ILMachineType_NativeUInt:
		{
#line 1926 "cg_arith.tc"
			{
				ILGenSimple(info, IL_OP_NOT);
			}
#line 9740 "cg_arith.c"
		}
		break;

		case ILMachineType_Float32:
		{
#line 1941 "cg_arith.tc"
			{
				/* Default - should never be used */
			}
#line 9750 "cg_arith.c"
		}
		break;

		case ILMachineType_Float64:
		{
#line 1941 "cg_arith.tc"
			{
				/* Default - should never be used */
			}
#line 9760 "cg_arith.c"
		}
		break;

		case ILMachineType_NativeFloat:
		{
#line 1941 "cg_arith.tc"
			{
				/* Default - should never be used */
			}
#line 9770 "cg_arith.c"
		}
		break;

		case ILMachineType_Decimal:
		{
#line 1941 "cg_arith.tc"
			{
				/* Default - should never be used */
			}
#line 9780 "cg_arith.c"
		}
		break;

		case ILMachineType_String:
		{
#line 1941 "cg_arith.tc"
			{
				/* Default - should never be used */
			}
#line 9790 "cg_arith.c"
		}
		break;

		case ILMachineType_ObjectRef:
		{
#line 1941 "cg_arith.tc"
			{
				/* Default - should never be used */
			}
#line 9800 "cg_arith.c"
		}
		break;

		case ILMachineType_UnmanagedPtr:
		{
#line 1941 "cg_arith.tc"
			{
				/* Default - should never be used */
			}
#line 9810 "cg_arith.c"
		}
		break;

		case ILMachineType_ManagedPtr:
		{
#line 1941 "cg_arith.tc"
			{
				/* Default - should never be used */
			}
#line 9820 "cg_arith.c"
		}
		break;

		case ILMachineType_TransientPtr:
		{
#line 1941 "cg_arith.tc"
			{
				/* Default - should never be used */
			}
#line 9830 "cg_arith.c"
		}
		break;

		case ILMachineType_ManagedValue:
		{
#line 1941 "cg_arith.tc"
			{
				/* Default - should never be used */
			}
#line 9840 "cg_arith.c"
		}
		break;

		default: break;
	}
}

#line 3247 "cg_arith.tc"


ILMachineType ILCommonType(ILGenInfo *info, ILMachineType type1,
						   ILMachineType type2, int intonly)
{
	if(type1 == ILMachineType_Decimal || type2 == ILMachineType_Decimal)
	{
		if(intonly)
			return ILMachineType_Int32;
		else
			return ILMachineType_Decimal;
	}
	if(type1 == ILMachineType_NativeFloat || type2 == ILMachineType_NativeFloat)
	{
		if(intonly)
			return ILMachineType_Int32;
		else
			return ILMachineType_NativeFloat;
	}
	if(type1 == ILMachineType_Float64 || type2 == ILMachineType_Float64)
	{
		if(intonly)
			return ILMachineType_Int32;
		else if(info->pedanticArith)
			return ILMachineType_Float64;
		else
			return ILMachineType_NativeFloat;
	}
	if(type1 == ILMachineType_Float32 || type2 == ILMachineType_Float32)
	{
		if(intonly)
			return ILMachineType_Int32;
		else if(info->pedanticArith)
			return ILMachineType_Float32;
		else
			return ILMachineType_NativeFloat;
	}
	if(type1 == ILMachineType_UInt64 || type2 == ILMachineType_UInt64)
	{
		return ILMachineType_UInt64;
	}
	if(type1 == ILMachineType_Int64 || type2 == ILMachineType_Int64)
	{
		return ILMachineType_Int64;
	}
	if(type1 == ILMachineType_UnmanagedPtr ||
	   type2 == ILMachineType_UnmanagedPtr)
	{
		return ILMachineType_UnmanagedPtr;
	}
	if(type1 == ILMachineType_NativeUInt || type2 == ILMachineType_NativeUInt)
	{
		return ILMachineType_NativeUInt;
	}
	if(type1 == ILMachineType_NativeInt || type2 == ILMachineType_NativeInt)
	{
		return ILMachineType_NativeInt;
	}
	if(type1 == ILMachineType_UInt32 || type2 == ILMachineType_UInt32)
	{
		return ILMachineType_UInt32;
	}
	if(type1 == ILMachineType_Int32 || type2 == ILMachineType_Int32)
	{
		return ILMachineType_Int32;
	}
	if(type1 == ILMachineType_UInt16 || type2 == ILMachineType_UInt16)
	{
		return ILMachineType_UInt16;
	}
	if(type1 == ILMachineType_Char || type2 == ILMachineType_Char)
	{
		return ILMachineType_Char;
	}
	if(type1 == ILMachineType_Int16 || type2 == ILMachineType_Int16)
	{
		return ILMachineType_Int16;
	}
	if(type1 == ILMachineType_UInt8 || type2 == ILMachineType_UInt8)
	{
		return ILMachineType_UInt8;
	}
	if(type1 == ILMachineType_Int8 || type2 == ILMachineType_Int8)
	{
		return ILMachineType_Int8;
	}
	if(type1 == ILMachineType_Boolean || type2 == ILMachineType_Boolean)
	{
		/* Arithmetic operations on booleans give an "int32" result */
		return ILMachineType_Int32;
	}
	return ILMachineType_Void;
}

#line 9943 "cg_arith.c"
