/* cg_relop.c.  Generated automatically by treecc */
#line 3 "cg_relop.tc"

/*
 * cg_relop.tc - Relational operator nodes.
 *
 * Copyright (C) 2001  Southern Storm Software, Pty Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <codegen/cg_nodes.h>

/*
 * Determine a common type for relational operators.
 */
static ILMachineType Relational_CommonType(ILGenInfo *info,
										   ILMachineType type1,
										   ILMachineType type2)
{
	if(type1 == ILMachineType_ObjectRef || type2 == ILMachineType_ObjectRef ||
	   type1 == ILMachineType_String || type2 == ILMachineType_String)
	{
		return ILMachineType_ObjectRef;
	}
	else
	{
		return ILCommonType(info, type1, type2, 0);
	}
}

#line 45 "cg_relop.c"

ILMachineType ILNode_Relational_ILNode_GetType__(ILNode_Relational *node, ILGenInfo * info)
#line 87 "cg_relop.tc"
{
	return ILMachineType_Boolean;
}
#line 52 "cg_relop.c"

void ILNode_Relational_ILNode_GenDiscard__(ILNode_Relational *node, ILGenInfo * info)
#line 95 "cg_relop.tc"
{
	ILNode_GenDiscard(node->expr1, info);
	ILNode_GenDiscard(node->expr2, info);
}
#line 60 "cg_relop.c"

ILMachineType ILNode_Relational_ILNode_GenValue__(ILNode_Relational *node, ILGenInfo * info)
#line 104 "cg_relop.tc"
{
	ILMachineType type1;
	ILMachineType type2;
	ILMachineType commonType;

	/* Determine the common type to use */
	type1 = ILNode_GetType(node->expr1, info);
	type2 = ILNode_GetType(node->expr2, info);
	commonType = Relational_CommonType(info, type1, type2);

	/* Generate code for the sub-expressions */
	ILGenCast(info, ILNode_GenValue(node->expr1, info), commonType);
	ILGenCast(info, ILNode_GenValue(node->expr2, info), commonType);

	/* Compare the values */
	ILRelational_ApplyOp(info, node, commonType);
	ILGenAdjust(info, -1);

	/* The result type is always boolean */
	return ILMachineType_Boolean;
}
#line 85 "cg_relop.c"

void ILNode_Relational_ILNode_GenThen__(ILNode_Relational *node, ILGenInfo * info, ILLabel * label)
#line 130 "cg_relop.tc"
{
	ILMachineType type1;
	ILMachineType type2;
	ILMachineType commonType;

	/* Determine the common type to use */
	type1 = ILNode_GetType(node->expr1, info);
	type2 = ILNode_GetType(node->expr2, info);
	commonType = Relational_CommonType(info, type1, type2);

	/* Generate code for the sub-expressions */
	ILGenCast(info, ILNode_GenValue(node->expr1, info), commonType);
	ILGenCast(info, ILNode_GenValue(node->expr2, info), commonType);

	/* Compare the values and jump */
	ILRelational_ThenOp(info, node, commonType, label);
	ILGenAdjust(info, -2);
}
#line 107 "cg_relop.c"

void ILNode_Relational_ILNode_GenElse__(ILNode_Relational *node, ILGenInfo * info, ILLabel * label)
#line 153 "cg_relop.tc"
{
	ILMachineType type1;
	ILMachineType type2;
	ILMachineType commonType;

	/* Determine the common type to use */
	type1 = ILNode_GetType(node->expr1, info);
	type2 = ILNode_GetType(node->expr2, info);
	commonType = Relational_CommonType(info, type1, type2);

	/* Generate code for the sub-expressions */
	ILGenCast(info, ILNode_GenValue(node->expr1, info), commonType);
	ILGenCast(info, ILNode_GenValue(node->expr2, info), commonType);

	/* Compare the values and jump */
	ILRelational_ElseOp(info, node, commonType, label);
	ILGenAdjust(info, -2);
}
#line 129 "cg_relop.c"

int ILNode_Relational_ILNode_EvalConst__(ILNode_Relational *node, ILGenInfo * info, ILEvalValue * value)
#line 176 "cg_relop.tc"
{
	ILMachineType type1;
	ILMachineType type2;
	ILMachineType commonType;
	ILEvalValue value2;

	/* Determine the common type to use */
	type1 = ILNode_GetType(node->expr1, info);
	type2 = ILNode_GetType(node->expr2, info);
	commonType = Relational_CommonType(info, type1, type2);

	/* Evaluate the sub-expressions and cast to the common type */
	if(!ILNode_EvalConst(node->expr1, info, value) ||
	   !ILGenCastConst(info, value, value->valueType, commonType))
	{
		return 0;
	}
	if(!ILNode_EvalConst(node->expr2, info, &value2) ||
	   !ILGenCastConst(info, &value2, value2.valueType, commonType))
	{
		return 0;
	}

	/* Compare the values */
	if(!ILRelational_EvalOp(info, node, commonType, value, &value2))
	{
		return 0;
	}

	/* The result type is always boolean */
	value->valueType = ILMachineType_Boolean;
	return 1;
}
#line 166 "cg_relop.c"

struct ILNode_Relational_vtable__ const ILNode_Relational_vt__ = {
	&ILNode_BinaryExpression_vt__,
	ILNode_Relational_kind,
	"ILNode_Relational",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Relational_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Relational_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_Relational_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

struct ILNode_Eq_vtable__ const ILNode_Eq_vt__ = {
	&ILNode_Relational_vt__,
	ILNode_Eq_kind,
	"ILNode_Eq",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Relational_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Relational_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_Relational_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

struct ILNode_Ne_vtable__ const ILNode_Ne_vt__ = {
	&ILNode_Relational_vt__,
	ILNode_Ne_kind,
	"ILNode_Ne",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Relational_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Relational_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_Relational_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

struct ILNode_Lt_vtable__ const ILNode_Lt_vt__ = {
	&ILNode_Relational_vt__,
	ILNode_Lt_kind,
	"ILNode_Lt",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Relational_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Relational_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_Relational_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

struct ILNode_Le_vtable__ const ILNode_Le_vt__ = {
	&ILNode_Relational_vt__,
	ILNode_Le_kind,
	"ILNode_Le",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Relational_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Relational_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_Relational_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

struct ILNode_Gt_vtable__ const ILNode_Gt_vt__ = {
	&ILNode_Relational_vt__,
	ILNode_Gt_kind,
	"ILNode_Gt",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Relational_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Relational_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_Relational_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

struct ILNode_Ge_vtable__ const ILNode_Ge_vt__ = {
	&ILNode_Relational_vt__,
	ILNode_Ge_kind,
	"ILNode_Ge",
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GetType__,
	(void (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GenDiscard__,
	(ILMachineType (*)(ILNode *this__, ILGenInfo * info))ILNode_Relational_ILNode_GenValue__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Relational_ILNode_GenThen__,
	(void (*)(ILNode *this__, ILGenInfo * info, ILLabel * label))ILNode_Relational_ILNode_GenElse__,
	(int (*)(ILNode *this__, ILGenInfo * info, ILEvalValue * value))ILNode_Relational_ILNode_EvalConst__,
	(int (*)(ILNode *this__, ILGenInfo * info))ILNode_ILNode_EndsInReturnImpl__,
};

ILNode *ILNode_Eq_create(ILNode * expr1, ILNode * expr2)
{
	ILNode_Eq *node__ = (ILNode_Eq *)yynodealloc(sizeof(struct ILNode_Eq__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_Eq_vt__;
	node__->kind__ = ILNode_Eq_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	return (ILNode *)node__;
}

ILNode *ILNode_Ne_create(ILNode * expr1, ILNode * expr2)
{
	ILNode_Ne *node__ = (ILNode_Ne *)yynodealloc(sizeof(struct ILNode_Ne__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_Ne_vt__;
	node__->kind__ = ILNode_Ne_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	return (ILNode *)node__;
}

ILNode *ILNode_Lt_create(ILNode * expr1, ILNode * expr2)
{
	ILNode_Lt *node__ = (ILNode_Lt *)yynodealloc(sizeof(struct ILNode_Lt__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_Lt_vt__;
	node__->kind__ = ILNode_Lt_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	return (ILNode *)node__;
}

ILNode *ILNode_Le_create(ILNode * expr1, ILNode * expr2)
{
	ILNode_Le *node__ = (ILNode_Le *)yynodealloc(sizeof(struct ILNode_Le__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_Le_vt__;
	node__->kind__ = ILNode_Le_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	return (ILNode *)node__;
}

ILNode *ILNode_Gt_create(ILNode * expr1, ILNode * expr2)
{
	ILNode_Gt *node__ = (ILNode_Gt *)yynodealloc(sizeof(struct ILNode_Gt__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_Gt_vt__;
	node__->kind__ = ILNode_Gt_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	return (ILNode *)node__;
}

ILNode *ILNode_Ge_create(ILNode * expr1, ILNode * expr2)
{
	ILNode_Ge *node__ = (ILNode_Ge *)yynodealloc(sizeof(struct ILNode_Ge__));
	if(node__ == 0) return 0;
	node__->vtable__ = &ILNode_Ge_vt__;
	node__->kind__ = ILNode_Ge_kind;
	node__->filename__ = yycurrfilename();
	node__->linenum__ = yycurrlinenum();
	node__->expr1 = expr1;
	node__->expr2 = expr2;
	return (ILNode *)node__;
}

static int ILRelational_EvalOp_1__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1115 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value == value2->un.i4Value);
	return 1;
}
#line 343 "cg_relop.c"

static int ILRelational_EvalOp_2__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1115 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value == value2->un.i4Value);
	return 1;
}
#line 351 "cg_relop.c"

static int ILRelational_EvalOp_3__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1115 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value == value2->un.i4Value);
	return 1;
}
#line 359 "cg_relop.c"

static int ILRelational_EvalOp_4__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1115 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value == value2->un.i4Value);
	return 1;
}
#line 367 "cg_relop.c"

static int ILRelational_EvalOp_5__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1115 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value == value2->un.i4Value);
	return 1;
}
#line 375 "cg_relop.c"

static int ILRelational_EvalOp_6__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1115 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value == value2->un.i4Value);
	return 1;
}
#line 383 "cg_relop.c"

static int ILRelational_EvalOp_7__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1115 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value == value2->un.i4Value);
	return 1;
}
#line 391 "cg_relop.c"

static int ILRelational_EvalOp_8__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1115 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value == value2->un.i4Value);
	return 1;
}
#line 399 "cg_relop.c"

static int ILRelational_EvalOp_9__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1121 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i8Value == value2->un.i8Value);
	return 1;
}
#line 407 "cg_relop.c"

static int ILRelational_EvalOp_10__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1121 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i8Value == value2->un.i8Value);
	return 1;
}
#line 415 "cg_relop.c"

static int ILRelational_EvalOp_11__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1115 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value == value2->un.i4Value);
	return 1;
}
#line 423 "cg_relop.c"

static int ILRelational_EvalOp_12__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1115 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value == value2->un.i4Value);
	return 1;
}
#line 431 "cg_relop.c"

static int ILRelational_EvalOp_13__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1126 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.r4Value == value2->un.r4Value);
	return 1;
}
#line 439 "cg_relop.c"

static int ILRelational_EvalOp_14__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1132 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.r8Value == value2->un.r8Value);
	return 1;
}
#line 447 "cg_relop.c"

static int ILRelational_EvalOp_15__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1132 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.r8Value == value2->un.r8Value);
	return 1;
}
#line 455 "cg_relop.c"

static int ILRelational_EvalOp_16__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1137 "cg_relop.tc"
{
	value1->un.i4Value = (ILDecimalCmp(&(value1->un.decValue),
									   &(value2->un.decValue)) == 0);
	return 1;
}
#line 464 "cg_relop.c"

static int ILRelational_EvalOp_17__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1143 "cg_relop.tc"
{
	/* Compare two object ref constants, which will
	   always be "null", and hence equal */
	value1->un.i4Value = 1;
	return 1;
}
#line 474 "cg_relop.c"

static int ILRelational_EvalOp_18__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1150 "cg_relop.tc"
{
	return 0;
}
#line 481 "cg_relop.c"

static int ILRelational_EvalOp_19__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1167 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value != value2->un.i4Value);
	return 1;
}
#line 489 "cg_relop.c"

static int ILRelational_EvalOp_20__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1167 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value != value2->un.i4Value);
	return 1;
}
#line 497 "cg_relop.c"

static int ILRelational_EvalOp_21__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1167 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value != value2->un.i4Value);
	return 1;
}
#line 505 "cg_relop.c"

static int ILRelational_EvalOp_22__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1167 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value != value2->un.i4Value);
	return 1;
}
#line 513 "cg_relop.c"

static int ILRelational_EvalOp_23__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1167 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value != value2->un.i4Value);
	return 1;
}
#line 521 "cg_relop.c"

static int ILRelational_EvalOp_24__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1167 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value != value2->un.i4Value);
	return 1;
}
#line 529 "cg_relop.c"

static int ILRelational_EvalOp_25__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1167 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value != value2->un.i4Value);
	return 1;
}
#line 537 "cg_relop.c"

static int ILRelational_EvalOp_26__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1167 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value != value2->un.i4Value);
	return 1;
}
#line 545 "cg_relop.c"

static int ILRelational_EvalOp_27__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1173 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i8Value != value2->un.i8Value);
	return 1;
}
#line 553 "cg_relop.c"

static int ILRelational_EvalOp_28__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1173 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i8Value != value2->un.i8Value);
	return 1;
}
#line 561 "cg_relop.c"

static int ILRelational_EvalOp_29__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1167 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value != value2->un.i4Value);
	return 1;
}
#line 569 "cg_relop.c"

static int ILRelational_EvalOp_30__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1167 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value != value2->un.i4Value);
	return 1;
}
#line 577 "cg_relop.c"

static int ILRelational_EvalOp_31__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1178 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.r4Value != value2->un.r4Value);
	return 1;
}
#line 585 "cg_relop.c"

static int ILRelational_EvalOp_32__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1184 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.r8Value != value2->un.r8Value);
	return 1;
}
#line 593 "cg_relop.c"

static int ILRelational_EvalOp_33__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1184 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.r8Value != value2->un.r8Value);
	return 1;
}
#line 601 "cg_relop.c"

static int ILRelational_EvalOp_34__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1189 "cg_relop.tc"
{
	value1->un.i4Value = (ILDecimalCmp(&(value1->un.decValue),
									   &(value2->un.decValue)) != 0);
	return 1;
}
#line 610 "cg_relop.c"

static int ILRelational_EvalOp_35__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1195 "cg_relop.tc"
{
	/* Compare two object ref constants, which will
	   always be "null", and hence equal */
	value1->un.i4Value = 0;
	return 1;
}
#line 620 "cg_relop.c"

static int ILRelational_EvalOp_36__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1202 "cg_relop.tc"
{
	return 0;
}
#line 627 "cg_relop.c"

static int ILRelational_EvalOp_37__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1214 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value < value2->un.i4Value);
	return 1;
}
#line 635 "cg_relop.c"

static int ILRelational_EvalOp_38__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1214 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value < value2->un.i4Value);
	return 1;
}
#line 643 "cg_relop.c"

static int ILRelational_EvalOp_39__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1223 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) <
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 653 "cg_relop.c"

static int ILRelational_EvalOp_40__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1214 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value < value2->un.i4Value);
	return 1;
}
#line 661 "cg_relop.c"

static int ILRelational_EvalOp_41__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1223 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) <
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 671 "cg_relop.c"

static int ILRelational_EvalOp_42__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1223 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) <
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 681 "cg_relop.c"

static int ILRelational_EvalOp_43__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1214 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value < value2->un.i4Value);
	return 1;
}
#line 689 "cg_relop.c"

static int ILRelational_EvalOp_44__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1223 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) <
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 699 "cg_relop.c"

static int ILRelational_EvalOp_45__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1230 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i8Value < value2->un.i8Value);
	return 1;
}
#line 707 "cg_relop.c"

static int ILRelational_EvalOp_46__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1235 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt64)(value1->un.i8Value)) <
		 ((ILUInt64)(value2->un.i8Value)));
	return 1;
}
#line 717 "cg_relop.c"

static int ILRelational_EvalOp_47__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1214 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value < value2->un.i4Value);
	return 1;
}
#line 725 "cg_relop.c"

static int ILRelational_EvalOp_48__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1223 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) <
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 735 "cg_relop.c"

static int ILRelational_EvalOp_49__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1242 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.r4Value < value2->un.r4Value);
	return 1;
}
#line 743 "cg_relop.c"

static int ILRelational_EvalOp_50__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1248 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.r8Value < value2->un.r8Value);
	return 1;
}
#line 751 "cg_relop.c"

static int ILRelational_EvalOp_51__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1248 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.r8Value < value2->un.r8Value);
	return 1;
}
#line 759 "cg_relop.c"

static int ILRelational_EvalOp_52__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1253 "cg_relop.tc"
{
	value1->un.i4Value = (ILDecimalCmp(&(value1->un.decValue),
									   &(value2->un.decValue)) < 0);
	return 1;
}
#line 768 "cg_relop.c"

static int ILRelational_EvalOp_53__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1259 "cg_relop.tc"
{
	/* Compare two object ref constants, which will
	   always be "null", and hence equal */
	value1->un.i4Value = 0;
	return 1;
}
#line 778 "cg_relop.c"

static int ILRelational_EvalOp_54__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1266 "cg_relop.tc"
{
	return 0;
}
#line 785 "cg_relop.c"

static int ILRelational_EvalOp_55__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1278 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value <= value2->un.i4Value);
	return 1;
}
#line 793 "cg_relop.c"

static int ILRelational_EvalOp_56__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1278 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value <= value2->un.i4Value);
	return 1;
}
#line 801 "cg_relop.c"

static int ILRelational_EvalOp_57__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1287 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) <=
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 811 "cg_relop.c"

static int ILRelational_EvalOp_58__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1278 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value <= value2->un.i4Value);
	return 1;
}
#line 819 "cg_relop.c"

static int ILRelational_EvalOp_59__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1287 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) <=
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 829 "cg_relop.c"

static int ILRelational_EvalOp_60__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1287 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) <=
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 839 "cg_relop.c"

static int ILRelational_EvalOp_61__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1278 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value <= value2->un.i4Value);
	return 1;
}
#line 847 "cg_relop.c"

static int ILRelational_EvalOp_62__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1287 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) <=
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 857 "cg_relop.c"

static int ILRelational_EvalOp_63__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1294 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i8Value <= value2->un.i8Value);
	return 1;
}
#line 865 "cg_relop.c"

static int ILRelational_EvalOp_64__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1299 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt64)(value1->un.i8Value)) <=
		 ((ILUInt64)(value2->un.i8Value)));
	return 1;
}
#line 875 "cg_relop.c"

static int ILRelational_EvalOp_65__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1278 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value <= value2->un.i4Value);
	return 1;
}
#line 883 "cg_relop.c"

static int ILRelational_EvalOp_66__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1287 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) <=
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 893 "cg_relop.c"

static int ILRelational_EvalOp_67__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1306 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.r4Value <= value2->un.r4Value);
	return 1;
}
#line 901 "cg_relop.c"

static int ILRelational_EvalOp_68__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1312 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.r8Value <= value2->un.r8Value);
	return 1;
}
#line 909 "cg_relop.c"

static int ILRelational_EvalOp_69__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1312 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.r8Value <= value2->un.r8Value);
	return 1;
}
#line 917 "cg_relop.c"

static int ILRelational_EvalOp_70__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1317 "cg_relop.tc"
{
	value1->un.i4Value = (ILDecimalCmp(&(value1->un.decValue),
									   &(value2->un.decValue)) <= 0);
	return 1;
}
#line 926 "cg_relop.c"

static int ILRelational_EvalOp_71__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1323 "cg_relop.tc"
{
	/* Compare two object ref constants, which will
	   always be "null", and hence equal */
	value1->un.i4Value = 1;
	return 1;
}
#line 936 "cg_relop.c"

static int ILRelational_EvalOp_72__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1330 "cg_relop.tc"
{
	return 0;
}
#line 943 "cg_relop.c"

static int ILRelational_EvalOp_73__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1342 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value > value2->un.i4Value);
	return 1;
}
#line 951 "cg_relop.c"

static int ILRelational_EvalOp_74__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1342 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value > value2->un.i4Value);
	return 1;
}
#line 959 "cg_relop.c"

static int ILRelational_EvalOp_75__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1351 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) >
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 969 "cg_relop.c"

static int ILRelational_EvalOp_76__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1342 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value > value2->un.i4Value);
	return 1;
}
#line 977 "cg_relop.c"

static int ILRelational_EvalOp_77__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1351 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) >
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 987 "cg_relop.c"

static int ILRelational_EvalOp_78__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1351 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) >
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 997 "cg_relop.c"

static int ILRelational_EvalOp_79__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1342 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value > value2->un.i4Value);
	return 1;
}
#line 1005 "cg_relop.c"

static int ILRelational_EvalOp_80__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1351 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) >
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 1015 "cg_relop.c"

static int ILRelational_EvalOp_81__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1358 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i8Value > value2->un.i8Value);
	return 1;
}
#line 1023 "cg_relop.c"

static int ILRelational_EvalOp_82__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1363 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt64)(value1->un.i8Value)) >
		 ((ILUInt64)(value2->un.i8Value)));
	return 1;
}
#line 1033 "cg_relop.c"

static int ILRelational_EvalOp_83__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1342 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value > value2->un.i4Value);
	return 1;
}
#line 1041 "cg_relop.c"

static int ILRelational_EvalOp_84__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1351 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) >
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 1051 "cg_relop.c"

static int ILRelational_EvalOp_85__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1370 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.r4Value > value2->un.r4Value);
	return 1;
}
#line 1059 "cg_relop.c"

static int ILRelational_EvalOp_86__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1376 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.r8Value > value2->un.r8Value);
	return 1;
}
#line 1067 "cg_relop.c"

static int ILRelational_EvalOp_87__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1376 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.r8Value > value2->un.r8Value);
	return 1;
}
#line 1075 "cg_relop.c"

static int ILRelational_EvalOp_88__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1381 "cg_relop.tc"
{
	value1->un.i4Value = (ILDecimalCmp(&(value1->un.decValue),
									   &(value2->un.decValue)) > 0);
	return 1;
}
#line 1084 "cg_relop.c"

static int ILRelational_EvalOp_89__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1387 "cg_relop.tc"
{
	/* Compare two object ref constants, which will
	   always be "null", and hence equal */
	value1->un.i4Value = 0;
	return 1;
}
#line 1094 "cg_relop.c"

static int ILRelational_EvalOp_90__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1394 "cg_relop.tc"
{
	return 0;
}
#line 1101 "cg_relop.c"

static int ILRelational_EvalOp_91__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1406 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value >= value2->un.i4Value);
	return 1;
}
#line 1109 "cg_relop.c"

static int ILRelational_EvalOp_92__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1406 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value >= value2->un.i4Value);
	return 1;
}
#line 1117 "cg_relop.c"

static int ILRelational_EvalOp_93__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1415 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) >=
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 1127 "cg_relop.c"

static int ILRelational_EvalOp_94__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1406 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value >= value2->un.i4Value);
	return 1;
}
#line 1135 "cg_relop.c"

static int ILRelational_EvalOp_95__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1415 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) >=
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 1145 "cg_relop.c"

static int ILRelational_EvalOp_96__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1415 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) >=
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 1155 "cg_relop.c"

static int ILRelational_EvalOp_97__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1406 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value >= value2->un.i4Value);
	return 1;
}
#line 1163 "cg_relop.c"

static int ILRelational_EvalOp_98__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1415 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) >=
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 1173 "cg_relop.c"

static int ILRelational_EvalOp_99__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1422 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i8Value >= value2->un.i8Value);
	return 1;
}
#line 1181 "cg_relop.c"

static int ILRelational_EvalOp_100__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1427 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt64)(value1->un.i8Value)) >=
		 ((ILUInt64)(value2->un.i8Value)));
	return 1;
}
#line 1191 "cg_relop.c"

static int ILRelational_EvalOp_101__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1406 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.i4Value >= value2->un.i4Value);
	return 1;
}
#line 1199 "cg_relop.c"

static int ILRelational_EvalOp_102__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1415 "cg_relop.tc"
{
	value1->un.i4Value =
		(((ILUInt32)(value1->un.i4Value)) >=
		 ((ILUInt32)(value2->un.i4Value)));
	return 1;
}
#line 1209 "cg_relop.c"

static int ILRelational_EvalOp_103__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1434 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.r4Value >= value2->un.r4Value);
	return 1;
}
#line 1217 "cg_relop.c"

static int ILRelational_EvalOp_104__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1440 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.r8Value >= value2->un.r8Value);
	return 1;
}
#line 1225 "cg_relop.c"

static int ILRelational_EvalOp_105__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1440 "cg_relop.tc"
{
	value1->un.i4Value = (value1->un.r8Value >= value2->un.r8Value);
	return 1;
}
#line 1233 "cg_relop.c"

static int ILRelational_EvalOp_106__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1445 "cg_relop.tc"
{
	value1->un.i4Value = (ILDecimalCmp(&(value1->un.decValue),
									   &(value2->un.decValue)) >= 0);
	return 1;
}
#line 1242 "cg_relop.c"

static int ILRelational_EvalOp_107__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1451 "cg_relop.tc"
{
	/* Compare two object ref constants, which will
	   always be "null", and hence equal */
	value1->un.i4Value = 1;
	return 1;
}
#line 1252 "cg_relop.c"

static int ILRelational_EvalOp_108__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
#line 1458 "cg_relop.tc"
{
	return 0;
}
#line 1259 "cg_relop.c"

int ILRelational_EvalOp(ILGenInfo * info, ILNode_Relational * node__, ILMachineType commonType, ILEvalValue * value1, ILEvalValue * value2)
{
	switch(node__->kind__)
	{
		case ILNode_Eq_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					return ILRelational_EvalOp_18__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Boolean:
				{
					return ILRelational_EvalOp_1__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int8:
				{
					return ILRelational_EvalOp_2__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt8:
				{
					return ILRelational_EvalOp_3__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int16:
				{
					return ILRelational_EvalOp_4__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt16:
				{
					return ILRelational_EvalOp_5__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Char:
				{
					return ILRelational_EvalOp_6__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int32:
				{
					return ILRelational_EvalOp_7__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt32:
				{
					return ILRelational_EvalOp_8__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int64:
				{
					return ILRelational_EvalOp_9__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt64:
				{
					return ILRelational_EvalOp_10__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeInt:
				{
					return ILRelational_EvalOp_11__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					return ILRelational_EvalOp_12__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float32:
				{
					return ILRelational_EvalOp_13__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float64:
				{
					return ILRelational_EvalOp_14__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					return ILRelational_EvalOp_15__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Decimal:
				{
					return ILRelational_EvalOp_16__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_String:
				{
					return ILRelational_EvalOp_18__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					return ILRelational_EvalOp_17__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					return ILRelational_EvalOp_18__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					return ILRelational_EvalOp_18__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					return ILRelational_EvalOp_18__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					return ILRelational_EvalOp_18__(info, (ILNode_Eq *)node__, commonType, value1, value2);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Ne_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					return ILRelational_EvalOp_36__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Boolean:
				{
					return ILRelational_EvalOp_19__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int8:
				{
					return ILRelational_EvalOp_20__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt8:
				{
					return ILRelational_EvalOp_21__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int16:
				{
					return ILRelational_EvalOp_22__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt16:
				{
					return ILRelational_EvalOp_23__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Char:
				{
					return ILRelational_EvalOp_24__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int32:
				{
					return ILRelational_EvalOp_25__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt32:
				{
					return ILRelational_EvalOp_26__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int64:
				{
					return ILRelational_EvalOp_27__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt64:
				{
					return ILRelational_EvalOp_28__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeInt:
				{
					return ILRelational_EvalOp_29__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					return ILRelational_EvalOp_30__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float32:
				{
					return ILRelational_EvalOp_31__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float64:
				{
					return ILRelational_EvalOp_32__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					return ILRelational_EvalOp_33__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Decimal:
				{
					return ILRelational_EvalOp_34__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_String:
				{
					return ILRelational_EvalOp_36__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					return ILRelational_EvalOp_35__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					return ILRelational_EvalOp_36__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					return ILRelational_EvalOp_36__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					return ILRelational_EvalOp_36__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					return ILRelational_EvalOp_36__(info, (ILNode_Ne *)node__, commonType, value1, value2);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Lt_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					return ILRelational_EvalOp_54__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Boolean:
				{
					return ILRelational_EvalOp_37__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int8:
				{
					return ILRelational_EvalOp_38__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt8:
				{
					return ILRelational_EvalOp_39__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int16:
				{
					return ILRelational_EvalOp_40__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt16:
				{
					return ILRelational_EvalOp_41__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Char:
				{
					return ILRelational_EvalOp_42__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int32:
				{
					return ILRelational_EvalOp_43__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt32:
				{
					return ILRelational_EvalOp_44__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int64:
				{
					return ILRelational_EvalOp_45__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt64:
				{
					return ILRelational_EvalOp_46__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeInt:
				{
					return ILRelational_EvalOp_47__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					return ILRelational_EvalOp_48__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float32:
				{
					return ILRelational_EvalOp_49__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float64:
				{
					return ILRelational_EvalOp_50__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					return ILRelational_EvalOp_51__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Decimal:
				{
					return ILRelational_EvalOp_52__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_String:
				{
					return ILRelational_EvalOp_54__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					return ILRelational_EvalOp_53__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					return ILRelational_EvalOp_54__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					return ILRelational_EvalOp_54__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					return ILRelational_EvalOp_54__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					return ILRelational_EvalOp_54__(info, (ILNode_Lt *)node__, commonType, value1, value2);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Le_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					return ILRelational_EvalOp_72__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Boolean:
				{
					return ILRelational_EvalOp_55__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int8:
				{
					return ILRelational_EvalOp_56__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt8:
				{
					return ILRelational_EvalOp_57__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int16:
				{
					return ILRelational_EvalOp_58__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt16:
				{
					return ILRelational_EvalOp_59__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Char:
				{
					return ILRelational_EvalOp_60__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int32:
				{
					return ILRelational_EvalOp_61__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt32:
				{
					return ILRelational_EvalOp_62__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int64:
				{
					return ILRelational_EvalOp_63__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt64:
				{
					return ILRelational_EvalOp_64__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeInt:
				{
					return ILRelational_EvalOp_65__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					return ILRelational_EvalOp_66__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float32:
				{
					return ILRelational_EvalOp_67__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float64:
				{
					return ILRelational_EvalOp_68__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					return ILRelational_EvalOp_69__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Decimal:
				{
					return ILRelational_EvalOp_70__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_String:
				{
					return ILRelational_EvalOp_72__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					return ILRelational_EvalOp_71__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					return ILRelational_EvalOp_72__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					return ILRelational_EvalOp_72__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					return ILRelational_EvalOp_72__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					return ILRelational_EvalOp_72__(info, (ILNode_Le *)node__, commonType, value1, value2);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Gt_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					return ILRelational_EvalOp_90__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Boolean:
				{
					return ILRelational_EvalOp_73__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int8:
				{
					return ILRelational_EvalOp_74__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt8:
				{
					return ILRelational_EvalOp_75__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int16:
				{
					return ILRelational_EvalOp_76__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt16:
				{
					return ILRelational_EvalOp_77__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Char:
				{
					return ILRelational_EvalOp_78__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int32:
				{
					return ILRelational_EvalOp_79__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt32:
				{
					return ILRelational_EvalOp_80__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int64:
				{
					return ILRelational_EvalOp_81__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt64:
				{
					return ILRelational_EvalOp_82__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeInt:
				{
					return ILRelational_EvalOp_83__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					return ILRelational_EvalOp_84__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float32:
				{
					return ILRelational_EvalOp_85__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float64:
				{
					return ILRelational_EvalOp_86__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					return ILRelational_EvalOp_87__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Decimal:
				{
					return ILRelational_EvalOp_88__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_String:
				{
					return ILRelational_EvalOp_90__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					return ILRelational_EvalOp_89__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					return ILRelational_EvalOp_90__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					return ILRelational_EvalOp_90__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					return ILRelational_EvalOp_90__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					return ILRelational_EvalOp_90__(info, (ILNode_Gt *)node__, commonType, value1, value2);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Ge_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					return ILRelational_EvalOp_108__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Boolean:
				{
					return ILRelational_EvalOp_91__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int8:
				{
					return ILRelational_EvalOp_92__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt8:
				{
					return ILRelational_EvalOp_93__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int16:
				{
					return ILRelational_EvalOp_94__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt16:
				{
					return ILRelational_EvalOp_95__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Char:
				{
					return ILRelational_EvalOp_96__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int32:
				{
					return ILRelational_EvalOp_97__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt32:
				{
					return ILRelational_EvalOp_98__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Int64:
				{
					return ILRelational_EvalOp_99__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UInt64:
				{
					return ILRelational_EvalOp_100__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeInt:
				{
					return ILRelational_EvalOp_101__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					return ILRelational_EvalOp_102__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float32:
				{
					return ILRelational_EvalOp_103__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Float64:
				{
					return ILRelational_EvalOp_104__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					return ILRelational_EvalOp_105__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_Decimal:
				{
					return ILRelational_EvalOp_106__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_String:
				{
					return ILRelational_EvalOp_108__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					return ILRelational_EvalOp_107__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					return ILRelational_EvalOp_108__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					return ILRelational_EvalOp_108__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					return ILRelational_EvalOp_108__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					return ILRelational_EvalOp_108__(info, (ILNode_Ge *)node__, commonType, value1, value2);
				}
				break;

				default: break;
			}
		}
		break;

		default: break;
	}
	return (0);
}

static void ILRelational_ElseOp_1__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 816 "cg_relop.tc"
{
	/* Nothing to do here */
}
#line 2157 "cg_relop.c"

static void ILRelational_ElseOp_2__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2164 "cg_relop.c"

static void ILRelational_ElseOp_3__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2171 "cg_relop.c"

static void ILRelational_ElseOp_4__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2178 "cg_relop.c"

static void ILRelational_ElseOp_5__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2185 "cg_relop.c"

static void ILRelational_ElseOp_6__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2192 "cg_relop.c"

static void ILRelational_ElseOp_7__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2199 "cg_relop.c"

static void ILRelational_ElseOp_8__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2206 "cg_relop.c"

static void ILRelational_ElseOp_9__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2213 "cg_relop.c"

static void ILRelational_ElseOp_10__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2220 "cg_relop.c"

static void ILRelational_ElseOp_11__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2227 "cg_relop.c"

static void ILRelational_ElseOp_12__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2234 "cg_relop.c"

static void ILRelational_ElseOp_13__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2241 "cg_relop.c"

static void ILRelational_ElseOp_14__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2248 "cg_relop.c"

static void ILRelational_ElseOp_15__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2255 "cg_relop.c"

static void ILRelational_ElseOp_16__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2262 "cg_relop.c"

static void ILRelational_ElseOp_17__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 843 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.Decimal::op_Equality"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
	ILGenJump(info, IL_OP_BRFALSE, label);
}
#line 2273 "cg_relop.c"

static void ILRelational_ElseOp_18__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 851 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.String::op_Equality"
			"(class [.library]System.String, class [.library]System.String)");
	ILGenJump(info, IL_OP_BRFALSE, label);
}
#line 2283 "cg_relop.c"

static void ILRelational_ElseOp_19__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2290 "cg_relop.c"

static void ILRelational_ElseOp_20__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2297 "cg_relop.c"

static void ILRelational_ElseOp_21__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2304 "cg_relop.c"

static void ILRelational_ElseOp_22__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2311 "cg_relop.c"

static void ILRelational_ElseOp_23__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 839 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 2318 "cg_relop.c"

static void ILRelational_ElseOp_24__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 862 "cg_relop.tc"
{
	/* Nothing to do here */
}
#line 2325 "cg_relop.c"

static void ILRelational_ElseOp_25__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2332 "cg_relop.c"

static void ILRelational_ElseOp_26__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2339 "cg_relop.c"

static void ILRelational_ElseOp_27__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2346 "cg_relop.c"

static void ILRelational_ElseOp_28__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2353 "cg_relop.c"

static void ILRelational_ElseOp_29__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2360 "cg_relop.c"

static void ILRelational_ElseOp_30__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2367 "cg_relop.c"

static void ILRelational_ElseOp_31__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2374 "cg_relop.c"

static void ILRelational_ElseOp_32__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2381 "cg_relop.c"

static void ILRelational_ElseOp_33__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2388 "cg_relop.c"

static void ILRelational_ElseOp_34__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2395 "cg_relop.c"

static void ILRelational_ElseOp_35__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2402 "cg_relop.c"

static void ILRelational_ElseOp_36__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2409 "cg_relop.c"

static void ILRelational_ElseOp_37__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2416 "cg_relop.c"

static void ILRelational_ElseOp_38__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2423 "cg_relop.c"

static void ILRelational_ElseOp_39__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2430 "cg_relop.c"

static void ILRelational_ElseOp_40__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 889 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.Decimal::op_Inequality"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
	ILGenJump(info, IL_OP_BRFALSE, label);
}
#line 2441 "cg_relop.c"

static void ILRelational_ElseOp_41__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 897 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.String::op_Inequality"
			"(class [.library]System.String, class [.library]System.String)");
	ILGenJump(info, IL_OP_BRFALSE, label);
}
#line 2451 "cg_relop.c"

static void ILRelational_ElseOp_42__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2458 "cg_relop.c"

static void ILRelational_ElseOp_43__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2465 "cg_relop.c"

static void ILRelational_ElseOp_44__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2472 "cg_relop.c"

static void ILRelational_ElseOp_45__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2479 "cg_relop.c"

static void ILRelational_ElseOp_46__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 885 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 2486 "cg_relop.c"

static void ILRelational_ElseOp_47__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 908 "cg_relop.tc"
{
	/* Nothing to do here */
}
#line 2493 "cg_relop.c"

static void ILRelational_ElseOp_48__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 923 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 2500 "cg_relop.c"

static void ILRelational_ElseOp_49__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 923 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 2507 "cg_relop.c"

static void ILRelational_ElseOp_50__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 941 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE_UN, label);
}
#line 2514 "cg_relop.c"

static void ILRelational_ElseOp_51__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 923 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 2521 "cg_relop.c"

static void ILRelational_ElseOp_52__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 941 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE_UN, label);
}
#line 2528 "cg_relop.c"

static void ILRelational_ElseOp_53__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 941 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE_UN, label);
}
#line 2535 "cg_relop.c"

static void ILRelational_ElseOp_54__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 923 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 2542 "cg_relop.c"

static void ILRelational_ElseOp_55__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 941 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE_UN, label);
}
#line 2549 "cg_relop.c"

static void ILRelational_ElseOp_56__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 923 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 2556 "cg_relop.c"

static void ILRelational_ElseOp_57__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 941 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE_UN, label);
}
#line 2563 "cg_relop.c"

static void ILRelational_ElseOp_58__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 923 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 2570 "cg_relop.c"

static void ILRelational_ElseOp_59__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 941 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE_UN, label);
}
#line 2577 "cg_relop.c"

static void ILRelational_ElseOp_60__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 929 "cg_relop.tc"
{
	ILLabel label1 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BLT, &label1);
	ILGenJump(info, IL_OP_BR, label);
	ILGenLabel(info, &label1);
}
#line 2587 "cg_relop.c"

static void ILRelational_ElseOp_61__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 929 "cg_relop.tc"
{
	ILLabel label1 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BLT, &label1);
	ILGenJump(info, IL_OP_BR, label);
	ILGenLabel(info, &label1);
}
#line 2597 "cg_relop.c"

static void ILRelational_ElseOp_62__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 929 "cg_relop.tc"
{
	ILLabel label1 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BLT, &label1);
	ILGenJump(info, IL_OP_BR, label);
	ILGenLabel(info, &label1);
}
#line 2607 "cg_relop.c"

static void ILRelational_ElseOp_63__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 945 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.Decimal::op_LessThan"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
	ILGenJump(info, IL_OP_BRFALSE, label);
}
#line 2618 "cg_relop.c"

static void ILRelational_ElseOp_64__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 923 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 2625 "cg_relop.c"

static void ILRelational_ElseOp_65__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 923 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 2632 "cg_relop.c"

static void ILRelational_ElseOp_66__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 923 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 2639 "cg_relop.c"

static void ILRelational_ElseOp_67__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 923 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 2646 "cg_relop.c"

static void ILRelational_ElseOp_68__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 923 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 2653 "cg_relop.c"

static void ILRelational_ElseOp_69__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 923 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 2660 "cg_relop.c"

static void ILRelational_ElseOp_70__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 957 "cg_relop.tc"
{
	/* Nothing to do here */
}
#line 2667 "cg_relop.c"

static void ILRelational_ElseOp_71__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 972 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 2674 "cg_relop.c"

static void ILRelational_ElseOp_72__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 972 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 2681 "cg_relop.c"

static void ILRelational_ElseOp_73__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 992 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT_UN, label);
}
#line 2688 "cg_relop.c"

static void ILRelational_ElseOp_74__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 972 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 2695 "cg_relop.c"

static void ILRelational_ElseOp_75__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 992 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT_UN, label);
}
#line 2702 "cg_relop.c"

static void ILRelational_ElseOp_76__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 992 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT_UN, label);
}
#line 2709 "cg_relop.c"

static void ILRelational_ElseOp_77__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 972 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 2716 "cg_relop.c"

static void ILRelational_ElseOp_78__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 992 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT_UN, label);
}
#line 2723 "cg_relop.c"

static void ILRelational_ElseOp_79__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 972 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 2730 "cg_relop.c"

static void ILRelational_ElseOp_80__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 992 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT_UN, label);
}
#line 2737 "cg_relop.c"

static void ILRelational_ElseOp_81__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 972 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 2744 "cg_relop.c"

static void ILRelational_ElseOp_82__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 992 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT_UN, label);
}
#line 2751 "cg_relop.c"

static void ILRelational_ElseOp_83__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 979 "cg_relop.tc"
{
	ILLabel label1 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BLE, &label1);
	ILGenJump(info, IL_OP_BR, label);
	ILGenLabel(info, &label1);
}
#line 2761 "cg_relop.c"

static void ILRelational_ElseOp_84__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 979 "cg_relop.tc"
{
	ILLabel label1 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BLE, &label1);
	ILGenJump(info, IL_OP_BR, label);
	ILGenLabel(info, &label1);
}
#line 2771 "cg_relop.c"

static void ILRelational_ElseOp_85__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 979 "cg_relop.tc"
{
	ILLabel label1 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BLE, &label1);
	ILGenJump(info, IL_OP_BR, label);
	ILGenLabel(info, &label1);
}
#line 2781 "cg_relop.c"

static void ILRelational_ElseOp_86__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 996 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.Decimal::op_LessThanOrEqual"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
	ILGenJump(info, IL_OP_BRFALSE, label);
}
#line 2792 "cg_relop.c"

static void ILRelational_ElseOp_87__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 972 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 2799 "cg_relop.c"

static void ILRelational_ElseOp_88__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 972 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 2806 "cg_relop.c"

static void ILRelational_ElseOp_89__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 972 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 2813 "cg_relop.c"

static void ILRelational_ElseOp_90__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 972 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 2820 "cg_relop.c"

static void ILRelational_ElseOp_91__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 972 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 2827 "cg_relop.c"

static void ILRelational_ElseOp_92__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 972 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 2834 "cg_relop.c"

static void ILRelational_ElseOp_93__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1008 "cg_relop.tc"
{
	/* Nothing to do here */
}
#line 2841 "cg_relop.c"

static void ILRelational_ElseOp_94__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1023 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 2848 "cg_relop.c"

static void ILRelational_ElseOp_95__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1023 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 2855 "cg_relop.c"

static void ILRelational_ElseOp_96__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1041 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE_UN, label);
}
#line 2862 "cg_relop.c"

static void ILRelational_ElseOp_97__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1023 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 2869 "cg_relop.c"

static void ILRelational_ElseOp_98__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1041 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE_UN, label);
}
#line 2876 "cg_relop.c"

static void ILRelational_ElseOp_99__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1041 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE_UN, label);
}
#line 2883 "cg_relop.c"

static void ILRelational_ElseOp_100__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1023 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 2890 "cg_relop.c"

static void ILRelational_ElseOp_101__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1041 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE_UN, label);
}
#line 2897 "cg_relop.c"

static void ILRelational_ElseOp_102__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1023 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 2904 "cg_relop.c"

static void ILRelational_ElseOp_103__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1041 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE_UN, label);
}
#line 2911 "cg_relop.c"

static void ILRelational_ElseOp_104__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1023 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 2918 "cg_relop.c"

static void ILRelational_ElseOp_105__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1041 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE_UN, label);
}
#line 2925 "cg_relop.c"

static void ILRelational_ElseOp_106__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1029 "cg_relop.tc"
{
	ILLabel label1 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BGT, &label1);
	ILGenJump(info, IL_OP_BR, label);
	ILGenLabel(info, &label1);
}
#line 2935 "cg_relop.c"

static void ILRelational_ElseOp_107__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1029 "cg_relop.tc"
{
	ILLabel label1 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BGT, &label1);
	ILGenJump(info, IL_OP_BR, label);
	ILGenLabel(info, &label1);
}
#line 2945 "cg_relop.c"

static void ILRelational_ElseOp_108__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1029 "cg_relop.tc"
{
	ILLabel label1 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BGT, &label1);
	ILGenJump(info, IL_OP_BR, label);
	ILGenLabel(info, &label1);
}
#line 2955 "cg_relop.c"

static void ILRelational_ElseOp_109__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1045 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.Decimal::op_GreaterThan"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
	ILGenJump(info, IL_OP_BRFALSE, label);
}
#line 2966 "cg_relop.c"

static void ILRelational_ElseOp_110__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1023 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 2973 "cg_relop.c"

static void ILRelational_ElseOp_111__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1023 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 2980 "cg_relop.c"

static void ILRelational_ElseOp_112__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1023 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 2987 "cg_relop.c"

static void ILRelational_ElseOp_113__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1023 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 2994 "cg_relop.c"

static void ILRelational_ElseOp_114__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1023 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 3001 "cg_relop.c"

static void ILRelational_ElseOp_115__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 1023 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 3008 "cg_relop.c"

static void ILRelational_ElseOp_116__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1057 "cg_relop.tc"
{
	/* Nothing to do here */
}
#line 3015 "cg_relop.c"

static void ILRelational_ElseOp_117__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1072 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 3022 "cg_relop.c"

static void ILRelational_ElseOp_118__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1072 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 3029 "cg_relop.c"

static void ILRelational_ElseOp_119__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1090 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT_UN, label);
}
#line 3036 "cg_relop.c"

static void ILRelational_ElseOp_120__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1072 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 3043 "cg_relop.c"

static void ILRelational_ElseOp_121__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1090 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT_UN, label);
}
#line 3050 "cg_relop.c"

static void ILRelational_ElseOp_122__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1090 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT_UN, label);
}
#line 3057 "cg_relop.c"

static void ILRelational_ElseOp_123__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1072 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 3064 "cg_relop.c"

static void ILRelational_ElseOp_124__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1090 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT_UN, label);
}
#line 3071 "cg_relop.c"

static void ILRelational_ElseOp_125__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1072 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 3078 "cg_relop.c"

static void ILRelational_ElseOp_126__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1090 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT_UN, label);
}
#line 3085 "cg_relop.c"

static void ILRelational_ElseOp_127__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1072 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 3092 "cg_relop.c"

static void ILRelational_ElseOp_128__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1090 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT_UN, label);
}
#line 3099 "cg_relop.c"

static void ILRelational_ElseOp_129__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1078 "cg_relop.tc"
{
	ILLabel label1 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BGE, &label1);
	ILGenJump(info, IL_OP_BR, label);
	ILGenLabel(info, &label1);
}
#line 3109 "cg_relop.c"

static void ILRelational_ElseOp_130__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1078 "cg_relop.tc"
{
	ILLabel label1 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BGE, &label1);
	ILGenJump(info, IL_OP_BR, label);
	ILGenLabel(info, &label1);
}
#line 3119 "cg_relop.c"

static void ILRelational_ElseOp_131__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1078 "cg_relop.tc"
{
	ILLabel label1 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BGE, &label1);
	ILGenJump(info, IL_OP_BR, label);
	ILGenLabel(info, &label1);
}
#line 3129 "cg_relop.c"

static void ILRelational_ElseOp_132__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1094 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.Decimal::op_GreaterThanOrEqual"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
	ILGenJump(info, IL_OP_BRFALSE, label);
}
#line 3140 "cg_relop.c"

static void ILRelational_ElseOp_133__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1072 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 3147 "cg_relop.c"

static void ILRelational_ElseOp_134__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1072 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 3154 "cg_relop.c"

static void ILRelational_ElseOp_135__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1072 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 3161 "cg_relop.c"

static void ILRelational_ElseOp_136__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1072 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 3168 "cg_relop.c"

static void ILRelational_ElseOp_137__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1072 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 3175 "cg_relop.c"

static void ILRelational_ElseOp_138__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 1072 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 3182 "cg_relop.c"

void ILRelational_ElseOp(ILGenInfo * info, ILNode_Relational * node__, ILMachineType commonType, ILLabel * label)
{
	switch(node__->kind__)
	{
		case ILNode_Eq_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILRelational_ElseOp_1__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILRelational_ElseOp_2__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int8:
				{
					ILRelational_ElseOp_3__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILRelational_ElseOp_4__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int16:
				{
					ILRelational_ElseOp_5__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILRelational_ElseOp_6__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_Char:
				{
					ILRelational_ElseOp_7__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int32:
				{
					ILRelational_ElseOp_8__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILRelational_ElseOp_9__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int64:
				{
					ILRelational_ElseOp_10__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILRelational_ElseOp_11__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILRelational_ElseOp_12__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILRelational_ElseOp_13__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float32:
				{
					ILRelational_ElseOp_14__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float64:
				{
					ILRelational_ElseOp_15__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILRelational_ElseOp_16__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILRelational_ElseOp_17__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_String:
				{
					ILRelational_ElseOp_18__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILRelational_ElseOp_19__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILRelational_ElseOp_20__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILRelational_ElseOp_21__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILRelational_ElseOp_22__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILRelational_ElseOp_23__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Ne_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILRelational_ElseOp_24__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILRelational_ElseOp_25__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int8:
				{
					ILRelational_ElseOp_26__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILRelational_ElseOp_27__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int16:
				{
					ILRelational_ElseOp_28__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILRelational_ElseOp_29__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_Char:
				{
					ILRelational_ElseOp_30__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int32:
				{
					ILRelational_ElseOp_31__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILRelational_ElseOp_32__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int64:
				{
					ILRelational_ElseOp_33__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILRelational_ElseOp_34__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILRelational_ElseOp_35__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILRelational_ElseOp_36__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float32:
				{
					ILRelational_ElseOp_37__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float64:
				{
					ILRelational_ElseOp_38__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILRelational_ElseOp_39__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILRelational_ElseOp_40__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_String:
				{
					ILRelational_ElseOp_41__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILRelational_ElseOp_42__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILRelational_ElseOp_43__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILRelational_ElseOp_44__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILRelational_ElseOp_45__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILRelational_ElseOp_46__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Lt_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILRelational_ElseOp_47__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILRelational_ElseOp_48__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int8:
				{
					ILRelational_ElseOp_49__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILRelational_ElseOp_50__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int16:
				{
					ILRelational_ElseOp_51__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILRelational_ElseOp_52__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Char:
				{
					ILRelational_ElseOp_53__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int32:
				{
					ILRelational_ElseOp_54__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILRelational_ElseOp_55__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int64:
				{
					ILRelational_ElseOp_56__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILRelational_ElseOp_57__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILRelational_ElseOp_58__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILRelational_ElseOp_59__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float32:
				{
					ILRelational_ElseOp_60__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float64:
				{
					ILRelational_ElseOp_61__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILRelational_ElseOp_62__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILRelational_ElseOp_63__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_String:
				{
					ILRelational_ElseOp_64__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILRelational_ElseOp_65__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILRelational_ElseOp_66__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILRelational_ElseOp_67__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILRelational_ElseOp_68__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILRelational_ElseOp_69__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Le_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILRelational_ElseOp_70__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILRelational_ElseOp_71__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int8:
				{
					ILRelational_ElseOp_72__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILRelational_ElseOp_73__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int16:
				{
					ILRelational_ElseOp_74__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILRelational_ElseOp_75__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_Char:
				{
					ILRelational_ElseOp_76__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int32:
				{
					ILRelational_ElseOp_77__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILRelational_ElseOp_78__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int64:
				{
					ILRelational_ElseOp_79__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILRelational_ElseOp_80__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILRelational_ElseOp_81__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILRelational_ElseOp_82__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float32:
				{
					ILRelational_ElseOp_83__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float64:
				{
					ILRelational_ElseOp_84__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILRelational_ElseOp_85__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILRelational_ElseOp_86__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_String:
				{
					ILRelational_ElseOp_87__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILRelational_ElseOp_88__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILRelational_ElseOp_89__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILRelational_ElseOp_90__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILRelational_ElseOp_91__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILRelational_ElseOp_92__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Gt_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILRelational_ElseOp_93__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILRelational_ElseOp_94__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int8:
				{
					ILRelational_ElseOp_95__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILRelational_ElseOp_96__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int16:
				{
					ILRelational_ElseOp_97__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILRelational_ElseOp_98__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Char:
				{
					ILRelational_ElseOp_99__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int32:
				{
					ILRelational_ElseOp_100__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILRelational_ElseOp_101__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int64:
				{
					ILRelational_ElseOp_102__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILRelational_ElseOp_103__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILRelational_ElseOp_104__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILRelational_ElseOp_105__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float32:
				{
					ILRelational_ElseOp_106__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float64:
				{
					ILRelational_ElseOp_107__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILRelational_ElseOp_108__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILRelational_ElseOp_109__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_String:
				{
					ILRelational_ElseOp_110__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILRelational_ElseOp_111__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILRelational_ElseOp_112__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILRelational_ElseOp_113__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILRelational_ElseOp_114__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILRelational_ElseOp_115__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Ge_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILRelational_ElseOp_116__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILRelational_ElseOp_117__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int8:
				{
					ILRelational_ElseOp_118__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILRelational_ElseOp_119__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int16:
				{
					ILRelational_ElseOp_120__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILRelational_ElseOp_121__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_Char:
				{
					ILRelational_ElseOp_122__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int32:
				{
					ILRelational_ElseOp_123__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILRelational_ElseOp_124__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int64:
				{
					ILRelational_ElseOp_125__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILRelational_ElseOp_126__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILRelational_ElseOp_127__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILRelational_ElseOp_128__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float32:
				{
					ILRelational_ElseOp_129__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float64:
				{
					ILRelational_ElseOp_130__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILRelational_ElseOp_131__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILRelational_ElseOp_132__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_String:
				{
					ILRelational_ElseOp_133__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILRelational_ElseOp_134__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILRelational_ElseOp_135__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILRelational_ElseOp_136__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILRelational_ElseOp_137__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILRelational_ElseOp_138__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				default: break;
			}
		}
		break;

		default: break;
	}
}

static void ILRelational_ApplyOp_1__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 214 "cg_relop.tc"
{
	/* Nothing to do here */
}
#line 4079 "cg_relop.c"

static void ILRelational_ApplyOp_2__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 234 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
}
#line 4086 "cg_relop.c"

static void ILRelational_ApplyOp_3__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 234 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
}
#line 4093 "cg_relop.c"

static void ILRelational_ApplyOp_4__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 234 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
}
#line 4100 "cg_relop.c"

static void ILRelational_ApplyOp_5__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 234 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
}
#line 4107 "cg_relop.c"

static void ILRelational_ApplyOp_6__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 234 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
}
#line 4114 "cg_relop.c"

static void ILRelational_ApplyOp_7__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 234 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
}
#line 4121 "cg_relop.c"

static void ILRelational_ApplyOp_8__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 234 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
}
#line 4128 "cg_relop.c"

static void ILRelational_ApplyOp_9__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 234 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
}
#line 4135 "cg_relop.c"

static void ILRelational_ApplyOp_10__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 234 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
}
#line 4142 "cg_relop.c"

static void ILRelational_ApplyOp_11__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 234 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
}
#line 4149 "cg_relop.c"

static void ILRelational_ApplyOp_12__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 234 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
}
#line 4156 "cg_relop.c"

static void ILRelational_ApplyOp_13__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 234 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
}
#line 4163 "cg_relop.c"

static void ILRelational_ApplyOp_14__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 240 "cg_relop.tc"
{
	/* We must use branch instructions or NaN will not
	   be handled correctly by the comparison */
	ILLabel label1 = ILLabel_Undefined;
	ILLabel label2 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BEQ, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_0);
	ILGenJump(info, IL_OP_BR, &label2);
	ILGenLabel(info, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenLabel(info, &label2);
}
#line 4179 "cg_relop.c"

static void ILRelational_ApplyOp_15__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 240 "cg_relop.tc"
{
	/* We must use branch instructions or NaN will not
	   be handled correctly by the comparison */
	ILLabel label1 = ILLabel_Undefined;
	ILLabel label2 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BEQ, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_0);
	ILGenJump(info, IL_OP_BR, &label2);
	ILGenLabel(info, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenLabel(info, &label2);
}
#line 4195 "cg_relop.c"

static void ILRelational_ApplyOp_16__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 240 "cg_relop.tc"
{
	/* We must use branch instructions or NaN will not
	   be handled correctly by the comparison */
	ILLabel label1 = ILLabel_Undefined;
	ILLabel label2 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BEQ, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_0);
	ILGenJump(info, IL_OP_BR, &label2);
	ILGenLabel(info, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenLabel(info, &label2);
}
#line 4211 "cg_relop.c"

static void ILRelational_ApplyOp_17__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 253 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.Decimal::op_Equality"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
}
#line 4221 "cg_relop.c"

static void ILRelational_ApplyOp_18__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 260 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.String::op_Equality"
			"(class [.library]System.String, class [.library]System.String)");
}
#line 4230 "cg_relop.c"

static void ILRelational_ApplyOp_19__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 234 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
}
#line 4237 "cg_relop.c"

static void ILRelational_ApplyOp_20__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 234 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
}
#line 4244 "cg_relop.c"

static void ILRelational_ApplyOp_21__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 234 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
}
#line 4251 "cg_relop.c"

static void ILRelational_ApplyOp_22__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 234 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
}
#line 4258 "cg_relop.c"

static void ILRelational_ApplyOp_23__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType)
#line 234 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
}
#line 4265 "cg_relop.c"

static void ILRelational_ApplyOp_24__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 270 "cg_relop.tc"
{
	/* Nothing to do here */
}
#line 4272 "cg_relop.c"

static void ILRelational_ApplyOp_25__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 290 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4281 "cg_relop.c"

static void ILRelational_ApplyOp_26__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 290 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4290 "cg_relop.c"

static void ILRelational_ApplyOp_27__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 290 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4299 "cg_relop.c"

static void ILRelational_ApplyOp_28__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 290 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4308 "cg_relop.c"

static void ILRelational_ApplyOp_29__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 290 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4317 "cg_relop.c"

static void ILRelational_ApplyOp_30__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 290 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4326 "cg_relop.c"

static void ILRelational_ApplyOp_31__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 290 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4335 "cg_relop.c"

static void ILRelational_ApplyOp_32__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 290 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4344 "cg_relop.c"

static void ILRelational_ApplyOp_33__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 290 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4353 "cg_relop.c"

static void ILRelational_ApplyOp_34__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 290 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4362 "cg_relop.c"

static void ILRelational_ApplyOp_35__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 290 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4371 "cg_relop.c"

static void ILRelational_ApplyOp_36__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 290 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4380 "cg_relop.c"

static void ILRelational_ApplyOp_37__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 298 "cg_relop.tc"
{
	/* We must use branch instructions or NaN will not
	   be handled correctly by the comparison */
	ILLabel label1 = ILLabel_Undefined;
	ILLabel label2 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BNE_UN, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_0);
	ILGenJump(info, IL_OP_BR, &label2);
	ILGenLabel(info, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenLabel(info, &label2);
}
#line 4396 "cg_relop.c"

static void ILRelational_ApplyOp_38__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 298 "cg_relop.tc"
{
	/* We must use branch instructions or NaN will not
	   be handled correctly by the comparison */
	ILLabel label1 = ILLabel_Undefined;
	ILLabel label2 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BNE_UN, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_0);
	ILGenJump(info, IL_OP_BR, &label2);
	ILGenLabel(info, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenLabel(info, &label2);
}
#line 4412 "cg_relop.c"

static void ILRelational_ApplyOp_39__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 298 "cg_relop.tc"
{
	/* We must use branch instructions or NaN will not
	   be handled correctly by the comparison */
	ILLabel label1 = ILLabel_Undefined;
	ILLabel label2 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BNE_UN, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_0);
	ILGenJump(info, IL_OP_BR, &label2);
	ILGenLabel(info, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenLabel(info, &label2);
}
#line 4428 "cg_relop.c"

static void ILRelational_ApplyOp_40__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 311 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.Decimal::op_Inequality"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
}
#line 4438 "cg_relop.c"

static void ILRelational_ApplyOp_41__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 318 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.String::op_Inequality"
			"(class [.library]System.String, class [.library]System.String)");
}
#line 4447 "cg_relop.c"

static void ILRelational_ApplyOp_42__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 290 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4456 "cg_relop.c"

static void ILRelational_ApplyOp_43__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 290 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4465 "cg_relop.c"

static void ILRelational_ApplyOp_44__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 290 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4474 "cg_relop.c"

static void ILRelational_ApplyOp_45__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 290 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4483 "cg_relop.c"

static void ILRelational_ApplyOp_46__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType)
#line 290 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CEQ);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4492 "cg_relop.c"

static void ILRelational_ApplyOp_47__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 328 "cg_relop.tc"
{
	/* Nothing to do here */
}
#line 4499 "cg_relop.c"

static void ILRelational_ApplyOp_48__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 343 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
}
#line 4506 "cg_relop.c"

static void ILRelational_ApplyOp_49__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 343 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
}
#line 4513 "cg_relop.c"

static void ILRelational_ApplyOp_50__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 352 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT_UN);
}
#line 4520 "cg_relop.c"

static void ILRelational_ApplyOp_51__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 343 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
}
#line 4527 "cg_relop.c"

static void ILRelational_ApplyOp_52__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 352 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT_UN);
}
#line 4534 "cg_relop.c"

static void ILRelational_ApplyOp_53__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 352 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT_UN);
}
#line 4541 "cg_relop.c"

static void ILRelational_ApplyOp_54__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 343 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
}
#line 4548 "cg_relop.c"

static void ILRelational_ApplyOp_55__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 352 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT_UN);
}
#line 4555 "cg_relop.c"

static void ILRelational_ApplyOp_56__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 343 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
}
#line 4562 "cg_relop.c"

static void ILRelational_ApplyOp_57__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 352 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT_UN);
}
#line 4569 "cg_relop.c"

static void ILRelational_ApplyOp_58__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 343 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
}
#line 4576 "cg_relop.c"

static void ILRelational_ApplyOp_59__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 352 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT_UN);
}
#line 4583 "cg_relop.c"

static void ILRelational_ApplyOp_60__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 358 "cg_relop.tc"
{
	/* We must use branch instructions or NaN will not
	   be handled correctly by the comparison */
	ILLabel label1 = ILLabel_Undefined;
	ILLabel label2 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BLT, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_0);
	ILGenJump(info, IL_OP_BR, &label2);
	ILGenLabel(info, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenLabel(info, &label2);
}
#line 4599 "cg_relop.c"

static void ILRelational_ApplyOp_61__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 358 "cg_relop.tc"
{
	/* We must use branch instructions or NaN will not
	   be handled correctly by the comparison */
	ILLabel label1 = ILLabel_Undefined;
	ILLabel label2 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BLT, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_0);
	ILGenJump(info, IL_OP_BR, &label2);
	ILGenLabel(info, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenLabel(info, &label2);
}
#line 4615 "cg_relop.c"

static void ILRelational_ApplyOp_62__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 358 "cg_relop.tc"
{
	/* We must use branch instructions or NaN will not
	   be handled correctly by the comparison */
	ILLabel label1 = ILLabel_Undefined;
	ILLabel label2 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BLT, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_0);
	ILGenJump(info, IL_OP_BR, &label2);
	ILGenLabel(info, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenLabel(info, &label2);
}
#line 4631 "cg_relop.c"

static void ILRelational_ApplyOp_63__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 371 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.Decimal::op_LessThan"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
}
#line 4641 "cg_relop.c"

static void ILRelational_ApplyOp_64__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 343 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
}
#line 4648 "cg_relop.c"

static void ILRelational_ApplyOp_65__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 343 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
}
#line 4655 "cg_relop.c"

static void ILRelational_ApplyOp_66__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 343 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
}
#line 4662 "cg_relop.c"

static void ILRelational_ApplyOp_67__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 343 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
}
#line 4669 "cg_relop.c"

static void ILRelational_ApplyOp_68__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 343 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
}
#line 4676 "cg_relop.c"

static void ILRelational_ApplyOp_69__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType)
#line 343 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
}
#line 4683 "cg_relop.c"

static void ILRelational_ApplyOp_70__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 382 "cg_relop.tc"
{
	/* Nothing to do here */
}
#line 4690 "cg_relop.c"

static void ILRelational_ApplyOp_71__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 397 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4699 "cg_relop.c"

static void ILRelational_ApplyOp_72__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 397 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4708 "cg_relop.c"

static void ILRelational_ApplyOp_73__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 408 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT_UN);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4717 "cg_relop.c"

static void ILRelational_ApplyOp_74__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 397 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4726 "cg_relop.c"

static void ILRelational_ApplyOp_75__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 408 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT_UN);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4735 "cg_relop.c"

static void ILRelational_ApplyOp_76__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 408 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT_UN);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4744 "cg_relop.c"

static void ILRelational_ApplyOp_77__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 397 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4753 "cg_relop.c"

static void ILRelational_ApplyOp_78__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 408 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT_UN);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4762 "cg_relop.c"

static void ILRelational_ApplyOp_79__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 397 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4771 "cg_relop.c"

static void ILRelational_ApplyOp_80__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 408 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT_UN);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4780 "cg_relop.c"

static void ILRelational_ApplyOp_81__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 397 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4789 "cg_relop.c"

static void ILRelational_ApplyOp_82__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 408 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT_UN);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4798 "cg_relop.c"

static void ILRelational_ApplyOp_83__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 416 "cg_relop.tc"
{
	/* We must use branch instructions or NaN will not
	   be handled correctly by the comparison */
	ILLabel label1 = ILLabel_Undefined;
	ILLabel label2 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BLE, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_0);
	ILGenJump(info, IL_OP_BR, &label2);
	ILGenLabel(info, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenLabel(info, &label2);
}
#line 4814 "cg_relop.c"

static void ILRelational_ApplyOp_84__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 416 "cg_relop.tc"
{
	/* We must use branch instructions or NaN will not
	   be handled correctly by the comparison */
	ILLabel label1 = ILLabel_Undefined;
	ILLabel label2 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BLE, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_0);
	ILGenJump(info, IL_OP_BR, &label2);
	ILGenLabel(info, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenLabel(info, &label2);
}
#line 4830 "cg_relop.c"

static void ILRelational_ApplyOp_85__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 416 "cg_relop.tc"
{
	/* We must use branch instructions or NaN will not
	   be handled correctly by the comparison */
	ILLabel label1 = ILLabel_Undefined;
	ILLabel label2 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BLE, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_0);
	ILGenJump(info, IL_OP_BR, &label2);
	ILGenLabel(info, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenLabel(info, &label2);
}
#line 4846 "cg_relop.c"

static void ILRelational_ApplyOp_86__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 429 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.Decimal::op_LessThanOrEqual"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
}
#line 4856 "cg_relop.c"

static void ILRelational_ApplyOp_87__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 397 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4865 "cg_relop.c"

static void ILRelational_ApplyOp_88__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 397 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4874 "cg_relop.c"

static void ILRelational_ApplyOp_89__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 397 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4883 "cg_relop.c"

static void ILRelational_ApplyOp_90__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 397 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4892 "cg_relop.c"

static void ILRelational_ApplyOp_91__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 397 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4901 "cg_relop.c"

static void ILRelational_ApplyOp_92__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType)
#line 397 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 4910 "cg_relop.c"

static void ILRelational_ApplyOp_93__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 440 "cg_relop.tc"
{
	/* Nothing to do here */
}
#line 4917 "cg_relop.c"

static void ILRelational_ApplyOp_94__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 455 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
}
#line 4924 "cg_relop.c"

static void ILRelational_ApplyOp_95__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 455 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
}
#line 4931 "cg_relop.c"

static void ILRelational_ApplyOp_96__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 464 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT_UN);
}
#line 4938 "cg_relop.c"

static void ILRelational_ApplyOp_97__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 455 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
}
#line 4945 "cg_relop.c"

static void ILRelational_ApplyOp_98__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 464 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT_UN);
}
#line 4952 "cg_relop.c"

static void ILRelational_ApplyOp_99__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 464 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT_UN);
}
#line 4959 "cg_relop.c"

static void ILRelational_ApplyOp_100__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 455 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
}
#line 4966 "cg_relop.c"

static void ILRelational_ApplyOp_101__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 464 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT_UN);
}
#line 4973 "cg_relop.c"

static void ILRelational_ApplyOp_102__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 455 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
}
#line 4980 "cg_relop.c"

static void ILRelational_ApplyOp_103__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 464 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT_UN);
}
#line 4987 "cg_relop.c"

static void ILRelational_ApplyOp_104__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 455 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
}
#line 4994 "cg_relop.c"

static void ILRelational_ApplyOp_105__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 464 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT_UN);
}
#line 5001 "cg_relop.c"

static void ILRelational_ApplyOp_106__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 470 "cg_relop.tc"
{
	/* We must use branch instructions or NaN will not
	   be handled correctly by the comparison */
	ILLabel label1 = ILLabel_Undefined;
	ILLabel label2 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BGT, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_0);
	ILGenJump(info, IL_OP_BR, &label2);
	ILGenLabel(info, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenLabel(info, &label2);
}
#line 5017 "cg_relop.c"

static void ILRelational_ApplyOp_107__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 470 "cg_relop.tc"
{
	/* We must use branch instructions or NaN will not
	   be handled correctly by the comparison */
	ILLabel label1 = ILLabel_Undefined;
	ILLabel label2 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BGT, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_0);
	ILGenJump(info, IL_OP_BR, &label2);
	ILGenLabel(info, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenLabel(info, &label2);
}
#line 5033 "cg_relop.c"

static void ILRelational_ApplyOp_108__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 470 "cg_relop.tc"
{
	/* We must use branch instructions or NaN will not
	   be handled correctly by the comparison */
	ILLabel label1 = ILLabel_Undefined;
	ILLabel label2 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BGT, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_0);
	ILGenJump(info, IL_OP_BR, &label2);
	ILGenLabel(info, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenLabel(info, &label2);
}
#line 5049 "cg_relop.c"

static void ILRelational_ApplyOp_109__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 483 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.Decimal::op_GreaterThan"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
}
#line 5059 "cg_relop.c"

static void ILRelational_ApplyOp_110__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 455 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
}
#line 5066 "cg_relop.c"

static void ILRelational_ApplyOp_111__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 455 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
}
#line 5073 "cg_relop.c"

static void ILRelational_ApplyOp_112__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 455 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
}
#line 5080 "cg_relop.c"

static void ILRelational_ApplyOp_113__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 455 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
}
#line 5087 "cg_relop.c"

static void ILRelational_ApplyOp_114__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 455 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
}
#line 5094 "cg_relop.c"

static void ILRelational_ApplyOp_115__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType)
#line 455 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CGT);
}
#line 5101 "cg_relop.c"

static void ILRelational_ApplyOp_116__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 494 "cg_relop.tc"
{
	/* Nothing to do here */
}
#line 5108 "cg_relop.c"

static void ILRelational_ApplyOp_117__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 509 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 5117 "cg_relop.c"

static void ILRelational_ApplyOp_118__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 509 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 5126 "cg_relop.c"

static void ILRelational_ApplyOp_119__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 520 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT_UN);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 5135 "cg_relop.c"

static void ILRelational_ApplyOp_120__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 509 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 5144 "cg_relop.c"

static void ILRelational_ApplyOp_121__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 520 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT_UN);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 5153 "cg_relop.c"

static void ILRelational_ApplyOp_122__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 520 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT_UN);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 5162 "cg_relop.c"

static void ILRelational_ApplyOp_123__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 509 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 5171 "cg_relop.c"

static void ILRelational_ApplyOp_124__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 520 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT_UN);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 5180 "cg_relop.c"

static void ILRelational_ApplyOp_125__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 509 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 5189 "cg_relop.c"

static void ILRelational_ApplyOp_126__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 520 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT_UN);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 5198 "cg_relop.c"

static void ILRelational_ApplyOp_127__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 509 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 5207 "cg_relop.c"

static void ILRelational_ApplyOp_128__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 520 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT_UN);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 5216 "cg_relop.c"

static void ILRelational_ApplyOp_129__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 528 "cg_relop.tc"
{
	/* We must use branch instructions or NaN will not
	   be handled correctly by the comparison */
	ILLabel label1 = ILLabel_Undefined;
	ILLabel label2 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BGE, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_0);
	ILGenJump(info, IL_OP_BR, &label2);
	ILGenLabel(info, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenLabel(info, &label2);
}
#line 5232 "cg_relop.c"

static void ILRelational_ApplyOp_130__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 528 "cg_relop.tc"
{
	/* We must use branch instructions or NaN will not
	   be handled correctly by the comparison */
	ILLabel label1 = ILLabel_Undefined;
	ILLabel label2 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BGE, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_0);
	ILGenJump(info, IL_OP_BR, &label2);
	ILGenLabel(info, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenLabel(info, &label2);
}
#line 5248 "cg_relop.c"

static void ILRelational_ApplyOp_131__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 528 "cg_relop.tc"
{
	/* We must use branch instructions or NaN will not
	   be handled correctly by the comparison */
	ILLabel label1 = ILLabel_Undefined;
	ILLabel label2 = ILLabel_Undefined;
	ILGenJump(info, IL_OP_BGE, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_0);
	ILGenJump(info, IL_OP_BR, &label2);
	ILGenLabel(info, &label1);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenLabel(info, &label2);
}
#line 5264 "cg_relop.c"

static void ILRelational_ApplyOp_132__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 541 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.Decimal::op_GreaterThanOrEqual"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
}
#line 5274 "cg_relop.c"

static void ILRelational_ApplyOp_133__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 509 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 5283 "cg_relop.c"

static void ILRelational_ApplyOp_134__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 509 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 5292 "cg_relop.c"

static void ILRelational_ApplyOp_135__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 509 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 5301 "cg_relop.c"

static void ILRelational_ApplyOp_136__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 509 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 5310 "cg_relop.c"

static void ILRelational_ApplyOp_137__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 509 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 5319 "cg_relop.c"

static void ILRelational_ApplyOp_138__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType)
#line 509 "cg_relop.tc"
{
	ILGenSimple(info, IL_OP_PREFIX + IL_PREFIX_OP_CLT);
	ILGenSimple(info, IL_OP_LDC_I4_1);
	ILGenSimple(info, IL_OP_XOR);
}
#line 5328 "cg_relop.c"

void ILRelational_ApplyOp(ILGenInfo * info, ILNode_Relational * node__, ILMachineType commonType)
{
	switch(node__->kind__)
	{
		case ILNode_Eq_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILRelational_ApplyOp_1__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILRelational_ApplyOp_2__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_Int8:
				{
					ILRelational_ApplyOp_3__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILRelational_ApplyOp_4__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_Int16:
				{
					ILRelational_ApplyOp_5__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILRelational_ApplyOp_6__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_Char:
				{
					ILRelational_ApplyOp_7__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_Int32:
				{
					ILRelational_ApplyOp_8__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILRelational_ApplyOp_9__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_Int64:
				{
					ILRelational_ApplyOp_10__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILRelational_ApplyOp_11__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILRelational_ApplyOp_12__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILRelational_ApplyOp_13__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_Float32:
				{
					ILRelational_ApplyOp_14__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_Float64:
				{
					ILRelational_ApplyOp_15__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILRelational_ApplyOp_16__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILRelational_ApplyOp_17__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_String:
				{
					ILRelational_ApplyOp_18__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILRelational_ApplyOp_19__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILRelational_ApplyOp_20__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILRelational_ApplyOp_21__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILRelational_ApplyOp_22__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILRelational_ApplyOp_23__(info, (ILNode_Eq *)node__, commonType);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Ne_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILRelational_ApplyOp_24__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILRelational_ApplyOp_25__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_Int8:
				{
					ILRelational_ApplyOp_26__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILRelational_ApplyOp_27__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_Int16:
				{
					ILRelational_ApplyOp_28__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILRelational_ApplyOp_29__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_Char:
				{
					ILRelational_ApplyOp_30__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_Int32:
				{
					ILRelational_ApplyOp_31__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILRelational_ApplyOp_32__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_Int64:
				{
					ILRelational_ApplyOp_33__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILRelational_ApplyOp_34__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILRelational_ApplyOp_35__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILRelational_ApplyOp_36__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_Float32:
				{
					ILRelational_ApplyOp_37__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_Float64:
				{
					ILRelational_ApplyOp_38__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILRelational_ApplyOp_39__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILRelational_ApplyOp_40__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_String:
				{
					ILRelational_ApplyOp_41__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILRelational_ApplyOp_42__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILRelational_ApplyOp_43__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILRelational_ApplyOp_44__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILRelational_ApplyOp_45__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILRelational_ApplyOp_46__(info, (ILNode_Ne *)node__, commonType);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Lt_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILRelational_ApplyOp_47__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILRelational_ApplyOp_48__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_Int8:
				{
					ILRelational_ApplyOp_49__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILRelational_ApplyOp_50__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_Int16:
				{
					ILRelational_ApplyOp_51__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILRelational_ApplyOp_52__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_Char:
				{
					ILRelational_ApplyOp_53__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_Int32:
				{
					ILRelational_ApplyOp_54__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILRelational_ApplyOp_55__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_Int64:
				{
					ILRelational_ApplyOp_56__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILRelational_ApplyOp_57__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILRelational_ApplyOp_58__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILRelational_ApplyOp_59__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_Float32:
				{
					ILRelational_ApplyOp_60__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_Float64:
				{
					ILRelational_ApplyOp_61__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILRelational_ApplyOp_62__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILRelational_ApplyOp_63__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_String:
				{
					ILRelational_ApplyOp_64__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILRelational_ApplyOp_65__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILRelational_ApplyOp_66__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILRelational_ApplyOp_67__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILRelational_ApplyOp_68__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILRelational_ApplyOp_69__(info, (ILNode_Lt *)node__, commonType);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Le_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILRelational_ApplyOp_70__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILRelational_ApplyOp_71__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_Int8:
				{
					ILRelational_ApplyOp_72__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILRelational_ApplyOp_73__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_Int16:
				{
					ILRelational_ApplyOp_74__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILRelational_ApplyOp_75__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_Char:
				{
					ILRelational_ApplyOp_76__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_Int32:
				{
					ILRelational_ApplyOp_77__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILRelational_ApplyOp_78__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_Int64:
				{
					ILRelational_ApplyOp_79__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILRelational_ApplyOp_80__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILRelational_ApplyOp_81__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILRelational_ApplyOp_82__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_Float32:
				{
					ILRelational_ApplyOp_83__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_Float64:
				{
					ILRelational_ApplyOp_84__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILRelational_ApplyOp_85__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILRelational_ApplyOp_86__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_String:
				{
					ILRelational_ApplyOp_87__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILRelational_ApplyOp_88__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILRelational_ApplyOp_89__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILRelational_ApplyOp_90__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILRelational_ApplyOp_91__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILRelational_ApplyOp_92__(info, (ILNode_Le *)node__, commonType);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Gt_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILRelational_ApplyOp_93__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILRelational_ApplyOp_94__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_Int8:
				{
					ILRelational_ApplyOp_95__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILRelational_ApplyOp_96__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_Int16:
				{
					ILRelational_ApplyOp_97__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILRelational_ApplyOp_98__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_Char:
				{
					ILRelational_ApplyOp_99__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_Int32:
				{
					ILRelational_ApplyOp_100__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILRelational_ApplyOp_101__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_Int64:
				{
					ILRelational_ApplyOp_102__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILRelational_ApplyOp_103__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILRelational_ApplyOp_104__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILRelational_ApplyOp_105__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_Float32:
				{
					ILRelational_ApplyOp_106__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_Float64:
				{
					ILRelational_ApplyOp_107__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILRelational_ApplyOp_108__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILRelational_ApplyOp_109__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_String:
				{
					ILRelational_ApplyOp_110__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILRelational_ApplyOp_111__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILRelational_ApplyOp_112__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILRelational_ApplyOp_113__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILRelational_ApplyOp_114__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILRelational_ApplyOp_115__(info, (ILNode_Gt *)node__, commonType);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Ge_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILRelational_ApplyOp_116__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILRelational_ApplyOp_117__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_Int8:
				{
					ILRelational_ApplyOp_118__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILRelational_ApplyOp_119__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_Int16:
				{
					ILRelational_ApplyOp_120__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILRelational_ApplyOp_121__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_Char:
				{
					ILRelational_ApplyOp_122__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_Int32:
				{
					ILRelational_ApplyOp_123__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILRelational_ApplyOp_124__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_Int64:
				{
					ILRelational_ApplyOp_125__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILRelational_ApplyOp_126__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILRelational_ApplyOp_127__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILRelational_ApplyOp_128__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_Float32:
				{
					ILRelational_ApplyOp_129__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_Float64:
				{
					ILRelational_ApplyOp_130__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILRelational_ApplyOp_131__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILRelational_ApplyOp_132__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_String:
				{
					ILRelational_ApplyOp_133__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILRelational_ApplyOp_134__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILRelational_ApplyOp_135__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILRelational_ApplyOp_136__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILRelational_ApplyOp_137__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILRelational_ApplyOp_138__(info, (ILNode_Ge *)node__, commonType);
				}
				break;

				default: break;
			}
		}
		break;

		default: break;
	}
}

static void ILRelational_ThenOp_1__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 552 "cg_relop.tc"
{
	/* Nothing to do here */
}
#line 6225 "cg_relop.c"

static void ILRelational_ThenOp_2__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6232 "cg_relop.c"

static void ILRelational_ThenOp_3__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6239 "cg_relop.c"

static void ILRelational_ThenOp_4__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6246 "cg_relop.c"

static void ILRelational_ThenOp_5__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6253 "cg_relop.c"

static void ILRelational_ThenOp_6__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6260 "cg_relop.c"

static void ILRelational_ThenOp_7__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6267 "cg_relop.c"

static void ILRelational_ThenOp_8__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6274 "cg_relop.c"

static void ILRelational_ThenOp_9__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6281 "cg_relop.c"

static void ILRelational_ThenOp_10__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6288 "cg_relop.c"

static void ILRelational_ThenOp_11__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6295 "cg_relop.c"

static void ILRelational_ThenOp_12__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6302 "cg_relop.c"

static void ILRelational_ThenOp_13__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6309 "cg_relop.c"

static void ILRelational_ThenOp_14__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6316 "cg_relop.c"

static void ILRelational_ThenOp_15__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6323 "cg_relop.c"

static void ILRelational_ThenOp_16__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6330 "cg_relop.c"

static void ILRelational_ThenOp_17__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 579 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.Decimal::op_Equality"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
	ILGenJump(info, IL_OP_BRTRUE, label);
}
#line 6341 "cg_relop.c"

static void ILRelational_ThenOp_18__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 587 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.String::op_Equality"
			"(class [.library]System.String, class [.library]System.String)");
	ILGenJump(info, IL_OP_BRTRUE, label);
}
#line 6351 "cg_relop.c"

static void ILRelational_ThenOp_19__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6358 "cg_relop.c"

static void ILRelational_ThenOp_20__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6365 "cg_relop.c"

static void ILRelational_ThenOp_21__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6372 "cg_relop.c"

static void ILRelational_ThenOp_22__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6379 "cg_relop.c"

static void ILRelational_ThenOp_23__(ILGenInfo * info, ILNode_Eq *node, ILMachineType commonType, ILLabel * label)
#line 575 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BEQ, label);
}
#line 6386 "cg_relop.c"

static void ILRelational_ThenOp_24__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 598 "cg_relop.tc"
{
	/* Nothing to do here */
}
#line 6393 "cg_relop.c"

static void ILRelational_ThenOp_25__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6400 "cg_relop.c"

static void ILRelational_ThenOp_26__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6407 "cg_relop.c"

static void ILRelational_ThenOp_27__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6414 "cg_relop.c"

static void ILRelational_ThenOp_28__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6421 "cg_relop.c"

static void ILRelational_ThenOp_29__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6428 "cg_relop.c"

static void ILRelational_ThenOp_30__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6435 "cg_relop.c"

static void ILRelational_ThenOp_31__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6442 "cg_relop.c"

static void ILRelational_ThenOp_32__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6449 "cg_relop.c"

static void ILRelational_ThenOp_33__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6456 "cg_relop.c"

static void ILRelational_ThenOp_34__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6463 "cg_relop.c"

static void ILRelational_ThenOp_35__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6470 "cg_relop.c"

static void ILRelational_ThenOp_36__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6477 "cg_relop.c"

static void ILRelational_ThenOp_37__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6484 "cg_relop.c"

static void ILRelational_ThenOp_38__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6491 "cg_relop.c"

static void ILRelational_ThenOp_39__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6498 "cg_relop.c"

static void ILRelational_ThenOp_40__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 625 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.Decimal::op_Inequality"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
	ILGenJump(info, IL_OP_BRTRUE, label);
}
#line 6509 "cg_relop.c"

static void ILRelational_ThenOp_41__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 633 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.String::op_Inequality"
			"(class [.library]System.String, class [.library]System.String)");
	ILGenJump(info, IL_OP_BRTRUE, label);
}
#line 6519 "cg_relop.c"

static void ILRelational_ThenOp_42__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6526 "cg_relop.c"

static void ILRelational_ThenOp_43__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6533 "cg_relop.c"

static void ILRelational_ThenOp_44__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6540 "cg_relop.c"

static void ILRelational_ThenOp_45__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6547 "cg_relop.c"

static void ILRelational_ThenOp_46__(ILGenInfo * info, ILNode_Ne *node, ILMachineType commonType, ILLabel * label)
#line 621 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BNE_UN, label);
}
#line 6554 "cg_relop.c"

static void ILRelational_ThenOp_47__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 644 "cg_relop.tc"
{
	/* Nothing to do here */
}
#line 6561 "cg_relop.c"

static void ILRelational_ThenOp_48__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 662 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 6568 "cg_relop.c"

static void ILRelational_ThenOp_49__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 662 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 6575 "cg_relop.c"

static void ILRelational_ThenOp_50__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 671 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT_UN, label);
}
#line 6582 "cg_relop.c"

static void ILRelational_ThenOp_51__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 662 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 6589 "cg_relop.c"

static void ILRelational_ThenOp_52__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 671 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT_UN, label);
}
#line 6596 "cg_relop.c"

static void ILRelational_ThenOp_53__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 671 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT_UN, label);
}
#line 6603 "cg_relop.c"

static void ILRelational_ThenOp_54__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 662 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 6610 "cg_relop.c"

static void ILRelational_ThenOp_55__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 671 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT_UN, label);
}
#line 6617 "cg_relop.c"

static void ILRelational_ThenOp_56__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 662 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 6624 "cg_relop.c"

static void ILRelational_ThenOp_57__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 671 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT_UN, label);
}
#line 6631 "cg_relop.c"

static void ILRelational_ThenOp_58__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 662 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 6638 "cg_relop.c"

static void ILRelational_ThenOp_59__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 671 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT_UN, label);
}
#line 6645 "cg_relop.c"

static void ILRelational_ThenOp_60__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 662 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 6652 "cg_relop.c"

static void ILRelational_ThenOp_61__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 662 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 6659 "cg_relop.c"

static void ILRelational_ThenOp_62__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 662 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 6666 "cg_relop.c"

static void ILRelational_ThenOp_63__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 675 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.Decimal::op_LessThan"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
	ILGenJump(info, IL_OP_BRTRUE, label);
}
#line 6677 "cg_relop.c"

static void ILRelational_ThenOp_64__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 662 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 6684 "cg_relop.c"

static void ILRelational_ThenOp_65__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 662 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 6691 "cg_relop.c"

static void ILRelational_ThenOp_66__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 662 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 6698 "cg_relop.c"

static void ILRelational_ThenOp_67__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 662 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 6705 "cg_relop.c"

static void ILRelational_ThenOp_68__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 662 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 6712 "cg_relop.c"

static void ILRelational_ThenOp_69__(ILGenInfo * info, ILNode_Lt *node, ILMachineType commonType, ILLabel * label)
#line 662 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLT, label);
}
#line 6719 "cg_relop.c"

static void ILRelational_ThenOp_70__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 687 "cg_relop.tc"
{
	/* Nothing to do here */
}
#line 6726 "cg_relop.c"

static void ILRelational_ThenOp_71__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 705 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 6733 "cg_relop.c"

static void ILRelational_ThenOp_72__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 705 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 6740 "cg_relop.c"

static void ILRelational_ThenOp_73__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 714 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE_UN, label);
}
#line 6747 "cg_relop.c"

static void ILRelational_ThenOp_74__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 705 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 6754 "cg_relop.c"

static void ILRelational_ThenOp_75__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 714 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE_UN, label);
}
#line 6761 "cg_relop.c"

static void ILRelational_ThenOp_76__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 714 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE_UN, label);
}
#line 6768 "cg_relop.c"

static void ILRelational_ThenOp_77__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 705 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 6775 "cg_relop.c"

static void ILRelational_ThenOp_78__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 714 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE_UN, label);
}
#line 6782 "cg_relop.c"

static void ILRelational_ThenOp_79__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 705 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 6789 "cg_relop.c"

static void ILRelational_ThenOp_80__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 714 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE_UN, label);
}
#line 6796 "cg_relop.c"

static void ILRelational_ThenOp_81__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 705 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 6803 "cg_relop.c"

static void ILRelational_ThenOp_82__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 714 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE_UN, label);
}
#line 6810 "cg_relop.c"

static void ILRelational_ThenOp_83__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 705 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 6817 "cg_relop.c"

static void ILRelational_ThenOp_84__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 705 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 6824 "cg_relop.c"

static void ILRelational_ThenOp_85__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 705 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 6831 "cg_relop.c"

static void ILRelational_ThenOp_86__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 718 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.Decimal::op_LessThanOrEqual"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
	ILGenJump(info, IL_OP_BRTRUE, label);
}
#line 6842 "cg_relop.c"

static void ILRelational_ThenOp_87__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 705 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 6849 "cg_relop.c"

static void ILRelational_ThenOp_88__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 705 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 6856 "cg_relop.c"

static void ILRelational_ThenOp_89__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 705 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 6863 "cg_relop.c"

static void ILRelational_ThenOp_90__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 705 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 6870 "cg_relop.c"

static void ILRelational_ThenOp_91__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 705 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 6877 "cg_relop.c"

static void ILRelational_ThenOp_92__(ILGenInfo * info, ILNode_Le *node, ILMachineType commonType, ILLabel * label)
#line 705 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BLE, label);
}
#line 6884 "cg_relop.c"

static void ILRelational_ThenOp_93__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 730 "cg_relop.tc"
{
	/* Nothing to do here */
}
#line 6891 "cg_relop.c"

static void ILRelational_ThenOp_94__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 748 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 6898 "cg_relop.c"

static void ILRelational_ThenOp_95__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 748 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 6905 "cg_relop.c"

static void ILRelational_ThenOp_96__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 757 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT_UN, label);
}
#line 6912 "cg_relop.c"

static void ILRelational_ThenOp_97__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 748 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 6919 "cg_relop.c"

static void ILRelational_ThenOp_98__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 757 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT_UN, label);
}
#line 6926 "cg_relop.c"

static void ILRelational_ThenOp_99__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 757 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT_UN, label);
}
#line 6933 "cg_relop.c"

static void ILRelational_ThenOp_100__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 748 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 6940 "cg_relop.c"

static void ILRelational_ThenOp_101__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 757 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT_UN, label);
}
#line 6947 "cg_relop.c"

static void ILRelational_ThenOp_102__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 748 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 6954 "cg_relop.c"

static void ILRelational_ThenOp_103__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 757 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT_UN, label);
}
#line 6961 "cg_relop.c"

static void ILRelational_ThenOp_104__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 748 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 6968 "cg_relop.c"

static void ILRelational_ThenOp_105__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 757 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT_UN, label);
}
#line 6975 "cg_relop.c"

static void ILRelational_ThenOp_106__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 748 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 6982 "cg_relop.c"

static void ILRelational_ThenOp_107__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 748 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 6989 "cg_relop.c"

static void ILRelational_ThenOp_108__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 748 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 6996 "cg_relop.c"

static void ILRelational_ThenOp_109__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 761 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.Decimal::op_GreaterThan"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
	ILGenJump(info, IL_OP_BRTRUE, label);
}
#line 7007 "cg_relop.c"

static void ILRelational_ThenOp_110__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 748 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 7014 "cg_relop.c"

static void ILRelational_ThenOp_111__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 748 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 7021 "cg_relop.c"

static void ILRelational_ThenOp_112__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 748 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 7028 "cg_relop.c"

static void ILRelational_ThenOp_113__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 748 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 7035 "cg_relop.c"

static void ILRelational_ThenOp_114__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 748 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 7042 "cg_relop.c"

static void ILRelational_ThenOp_115__(ILGenInfo * info, ILNode_Gt *node, ILMachineType commonType, ILLabel * label)
#line 748 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGT, label);
}
#line 7049 "cg_relop.c"

static void ILRelational_ThenOp_116__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 773 "cg_relop.tc"
{
	/* Nothing to do here */
}
#line 7056 "cg_relop.c"

static void ILRelational_ThenOp_117__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 791 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 7063 "cg_relop.c"

static void ILRelational_ThenOp_118__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 791 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 7070 "cg_relop.c"

static void ILRelational_ThenOp_119__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 800 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE_UN, label);
}
#line 7077 "cg_relop.c"

static void ILRelational_ThenOp_120__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 791 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 7084 "cg_relop.c"

static void ILRelational_ThenOp_121__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 800 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE_UN, label);
}
#line 7091 "cg_relop.c"

static void ILRelational_ThenOp_122__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 800 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE_UN, label);
}
#line 7098 "cg_relop.c"

static void ILRelational_ThenOp_123__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 791 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 7105 "cg_relop.c"

static void ILRelational_ThenOp_124__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 800 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE_UN, label);
}
#line 7112 "cg_relop.c"

static void ILRelational_ThenOp_125__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 791 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 7119 "cg_relop.c"

static void ILRelational_ThenOp_126__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 800 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE_UN, label);
}
#line 7126 "cg_relop.c"

static void ILRelational_ThenOp_127__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 791 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 7133 "cg_relop.c"

static void ILRelational_ThenOp_128__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 800 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE_UN, label);
}
#line 7140 "cg_relop.c"

static void ILRelational_ThenOp_129__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 791 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 7147 "cg_relop.c"

static void ILRelational_ThenOp_130__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 791 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 7154 "cg_relop.c"

static void ILRelational_ThenOp_131__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 791 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 7161 "cg_relop.c"

static void ILRelational_ThenOp_132__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 804 "cg_relop.tc"
{
	ILGenCallByName(info,
		"bool [.library]System.Decimal::op_GreaterThanOrEqual"
			"(valuetype [.library]System.Decimal, "
			"valuetype [.library]System.Decimal)");
	ILGenJump(info, IL_OP_BRTRUE, label);
}
#line 7172 "cg_relop.c"

static void ILRelational_ThenOp_133__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 791 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 7179 "cg_relop.c"

static void ILRelational_ThenOp_134__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 791 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 7186 "cg_relop.c"

static void ILRelational_ThenOp_135__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 791 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 7193 "cg_relop.c"

static void ILRelational_ThenOp_136__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 791 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 7200 "cg_relop.c"

static void ILRelational_ThenOp_137__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 791 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 7207 "cg_relop.c"

static void ILRelational_ThenOp_138__(ILGenInfo * info, ILNode_Ge *node, ILMachineType commonType, ILLabel * label)
#line 791 "cg_relop.tc"
{
	ILGenJump(info, IL_OP_BGE, label);
}
#line 7214 "cg_relop.c"

void ILRelational_ThenOp(ILGenInfo * info, ILNode_Relational * node__, ILMachineType commonType, ILLabel * label)
{
	switch(node__->kind__)
	{
		case ILNode_Eq_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILRelational_ThenOp_1__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILRelational_ThenOp_2__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int8:
				{
					ILRelational_ThenOp_3__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILRelational_ThenOp_4__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int16:
				{
					ILRelational_ThenOp_5__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILRelational_ThenOp_6__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_Char:
				{
					ILRelational_ThenOp_7__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int32:
				{
					ILRelational_ThenOp_8__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILRelational_ThenOp_9__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int64:
				{
					ILRelational_ThenOp_10__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILRelational_ThenOp_11__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILRelational_ThenOp_12__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILRelational_ThenOp_13__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float32:
				{
					ILRelational_ThenOp_14__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float64:
				{
					ILRelational_ThenOp_15__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILRelational_ThenOp_16__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILRelational_ThenOp_17__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_String:
				{
					ILRelational_ThenOp_18__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILRelational_ThenOp_19__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILRelational_ThenOp_20__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILRelational_ThenOp_21__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILRelational_ThenOp_22__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILRelational_ThenOp_23__(info, (ILNode_Eq *)node__, commonType, label);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Ne_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILRelational_ThenOp_24__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILRelational_ThenOp_25__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int8:
				{
					ILRelational_ThenOp_26__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILRelational_ThenOp_27__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int16:
				{
					ILRelational_ThenOp_28__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILRelational_ThenOp_29__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_Char:
				{
					ILRelational_ThenOp_30__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int32:
				{
					ILRelational_ThenOp_31__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILRelational_ThenOp_32__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int64:
				{
					ILRelational_ThenOp_33__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILRelational_ThenOp_34__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILRelational_ThenOp_35__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILRelational_ThenOp_36__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float32:
				{
					ILRelational_ThenOp_37__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float64:
				{
					ILRelational_ThenOp_38__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILRelational_ThenOp_39__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILRelational_ThenOp_40__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_String:
				{
					ILRelational_ThenOp_41__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILRelational_ThenOp_42__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILRelational_ThenOp_43__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILRelational_ThenOp_44__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILRelational_ThenOp_45__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILRelational_ThenOp_46__(info, (ILNode_Ne *)node__, commonType, label);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Lt_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILRelational_ThenOp_47__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILRelational_ThenOp_48__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int8:
				{
					ILRelational_ThenOp_49__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILRelational_ThenOp_50__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int16:
				{
					ILRelational_ThenOp_51__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILRelational_ThenOp_52__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Char:
				{
					ILRelational_ThenOp_53__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int32:
				{
					ILRelational_ThenOp_54__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILRelational_ThenOp_55__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int64:
				{
					ILRelational_ThenOp_56__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILRelational_ThenOp_57__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILRelational_ThenOp_58__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILRelational_ThenOp_59__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float32:
				{
					ILRelational_ThenOp_60__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float64:
				{
					ILRelational_ThenOp_61__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILRelational_ThenOp_62__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILRelational_ThenOp_63__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_String:
				{
					ILRelational_ThenOp_64__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILRelational_ThenOp_65__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILRelational_ThenOp_66__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILRelational_ThenOp_67__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILRelational_ThenOp_68__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILRelational_ThenOp_69__(info, (ILNode_Lt *)node__, commonType, label);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Le_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILRelational_ThenOp_70__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILRelational_ThenOp_71__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int8:
				{
					ILRelational_ThenOp_72__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILRelational_ThenOp_73__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int16:
				{
					ILRelational_ThenOp_74__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILRelational_ThenOp_75__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_Char:
				{
					ILRelational_ThenOp_76__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int32:
				{
					ILRelational_ThenOp_77__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILRelational_ThenOp_78__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int64:
				{
					ILRelational_ThenOp_79__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILRelational_ThenOp_80__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILRelational_ThenOp_81__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILRelational_ThenOp_82__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float32:
				{
					ILRelational_ThenOp_83__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float64:
				{
					ILRelational_ThenOp_84__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILRelational_ThenOp_85__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILRelational_ThenOp_86__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_String:
				{
					ILRelational_ThenOp_87__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILRelational_ThenOp_88__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILRelational_ThenOp_89__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILRelational_ThenOp_90__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILRelational_ThenOp_91__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILRelational_ThenOp_92__(info, (ILNode_Le *)node__, commonType, label);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Gt_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILRelational_ThenOp_93__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILRelational_ThenOp_94__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int8:
				{
					ILRelational_ThenOp_95__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILRelational_ThenOp_96__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int16:
				{
					ILRelational_ThenOp_97__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILRelational_ThenOp_98__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Char:
				{
					ILRelational_ThenOp_99__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int32:
				{
					ILRelational_ThenOp_100__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILRelational_ThenOp_101__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int64:
				{
					ILRelational_ThenOp_102__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILRelational_ThenOp_103__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILRelational_ThenOp_104__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILRelational_ThenOp_105__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float32:
				{
					ILRelational_ThenOp_106__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float64:
				{
					ILRelational_ThenOp_107__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILRelational_ThenOp_108__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILRelational_ThenOp_109__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_String:
				{
					ILRelational_ThenOp_110__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILRelational_ThenOp_111__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILRelational_ThenOp_112__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILRelational_ThenOp_113__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILRelational_ThenOp_114__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILRelational_ThenOp_115__(info, (ILNode_Gt *)node__, commonType, label);
				}
				break;

				default: break;
			}
		}
		break;

		case ILNode_Ge_kind:
		{
			switch(commonType)
			{
				case ILMachineType_Void:
				{
					ILRelational_ThenOp_116__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_Boolean:
				{
					ILRelational_ThenOp_117__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int8:
				{
					ILRelational_ThenOp_118__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt8:
				{
					ILRelational_ThenOp_119__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int16:
				{
					ILRelational_ThenOp_120__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt16:
				{
					ILRelational_ThenOp_121__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_Char:
				{
					ILRelational_ThenOp_122__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int32:
				{
					ILRelational_ThenOp_123__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt32:
				{
					ILRelational_ThenOp_124__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_Int64:
				{
					ILRelational_ThenOp_125__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_UInt64:
				{
					ILRelational_ThenOp_126__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeInt:
				{
					ILRelational_ThenOp_127__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeUInt:
				{
					ILRelational_ThenOp_128__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float32:
				{
					ILRelational_ThenOp_129__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_Float64:
				{
					ILRelational_ThenOp_130__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_NativeFloat:
				{
					ILRelational_ThenOp_131__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_Decimal:
				{
					ILRelational_ThenOp_132__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_String:
				{
					ILRelational_ThenOp_133__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_ObjectRef:
				{
					ILRelational_ThenOp_134__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_UnmanagedPtr:
				{
					ILRelational_ThenOp_135__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedPtr:
				{
					ILRelational_ThenOp_136__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_TransientPtr:
				{
					ILRelational_ThenOp_137__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				case ILMachineType_ManagedValue:
				{
					ILRelational_ThenOp_138__(info, (ILNode_Ge *)node__, commonType, label);
				}
				break;

				default: break;
			}
		}
		break;

		default: break;
	}
}

